
# ----------------------------------------------------------------
# $Author: thm $
# $Date: 2015-06-02 10:29:56 +0200 (Tue, 02 Jun 2015) $
# $Rev: 343 $
# ----------------------------------------------------------------

InitModelDictionary <- function() {
  ## This is the collection of all needed climate model metainformation.
  ## It is needed for the models2wux function. Currently all ENSEMBLES and
  ## CMIP3 models are described.
  ##
  ## Returns:
  ##   A named list of climate model information.
  ##
  ## History:
  ##   2011-02-11 | original code (thm)
  ##   2011-05-12 | changed CMIP3 data. now all runs have been placed here
  ##                according to
  ##              http://www-]pcmdi.llnl.gov/ipcc/info_for_analysts.php#time_info
  ##                (thm)
  ##       ...    | a lot has happened in the past...
  ##   2012-08-29 | added parameter ts for some ENSEMBLES models, resolved
  ##                some typos and such things (msu)
  ##   2012-12-06 | finally merged wux trunk and timeseries branch (geh & thm)
  ##   2013-03-12 | added RemoUBA-Datasaet (seb)
  ##   2013-10-08 | start adding available EURO CORDEX data (thm)
  ##   2014-02-26 | updated WEGC-CCLM_reclipcentury to new dataset (seb)
  ##   2014-05-22 | started adding quantile-mapped EURO-CORDEX-11 simulations (seb)

  model.input = list(
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###++++++++++++++++++++++++    DATASET: E-OBS            ++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

################################################################################
    'E-OBS_v9' = list(
      rcm = "",
      gcm = "E-OBS",
      institute = "",
      emission.scenario = "",
      file.path.alt = list(
        air_temperature =  "/data/reloclim/rcd/e-obs/data/v9",
        precipitation_amount  =  "/data/reloclim/rcd/e-obs/data/v9"),
      ## file.path.default =  "/data/reloclim/rcd/e-obs/data/v9",
      file.name = list(
        air_temperature = '^tg_0.25deg_reg_v9.0.nc',
        precipitation_amount = '^rr_0.25deg_reg_v9.0.nc'),
      parameters = c(
        air_temperature = "tg",
        precipitation_amount = "rr"
        ),
      ## lonlat.var.name = c(longitude="longitude", latitude="latitude"),
      gridfile.path = "/data/reloclim/rcd/e-obs/data/",
      gridfile.filename = "eobs_0.25deg_reg_v5.0_landseamask.nc",
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc"
      ),


################################################################################
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###++++++++++++++++++++++++    DATASET: ERA40            ++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

################################################################################
    'ERA40' = list(
      rcm = "",
      gcm = "ERA40",
      institute = "ECMWF",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcu/geh/data/ensembles/gcm/ERA40",
      file.name = list(
        air_temperature = c(
          'era40_air_temperature_2m_1957-1960_dm.nc',
          'era40_air_temperature_2m_1961-1970_dm.nc',
          'era40_air_temperature_2m_1971-1980_dm.nc',
          'era40_air_temperature_2m_1981-1990_dm.nc',
          'era40_air_temperature_2m_1991-2000_dm.nc',
          'era40_air_temperature_2m_2001-2002_dm.nc'
          ),
        precipitation_amount = c(
          'era40_precipitation_amount_sfc_1957-1960_ds.nc',
          'era40_precipitation_amount_sfc_1961-1970_ds.nc',
          'era40_precipitation_amount_sfc_1971-1980_ds.nc',
          'era40_precipitation_amount_sfc_1981-1990_ds.nc',
          'era40_precipitation_amount_sfc_1991-2000_ds.nc',
          'era40_precipitation_amount_sfc_2001-2002_ds.nc'
          )),
      parameters = c(air_temperature = "t2m",
        precipitation_amount = "tp"),
      lonlat.var.name = c(longitude="longitude", latitude="latitude"),
      gridfile.path = "/data/koeppen/rcd/ecmwf/data/cordex_eu",
      gridfile.filename = "era40_surface_geopotential_sfc_fix.nc"
      ),
################################################################################


###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###++++++++++++++++++++++++    DATASET: CMIP5            ++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

### ----------------------------------------------------------------------
### ************************** SCENARIO: RCP45 ***************************
### ----------------------------------------------------------------------


################################################################################
    'ACCESS1-0-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "ACCESS1-0",
      gcm.run = 1,
      institute = "CSIRO-BOM",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_ACCESS1-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_ACCESS1-0_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_ACCESS1-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_ACCESS1-0_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/historical",
      gridfile.filename = "tas_Amon_ACCESS1-0_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'ACCESS1-3-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "ACCESS1-3",
      gcm.run = 1,
      institute = "CSIRO-BOM",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_ACCESS1-3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_ACCESS1-3_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_ACCESS1-3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_ACCESS1-3_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/historical",
      gridfile.filename = "tas_Amon_ACCESS1-3_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'BCC-CSM1-1-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "BCC-CSM1-1",
      gcm.run = 1,
      institute = "BCC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_bcc-csm1-1_rcp45_r1i1p1_200601-209912.nc", 
            "tas_Amon_bcc-csm1-1_rcp45_r1i1p1_210001-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_bcc-csm1-1_rcp45_r1i1p1_200601-209912.nc", 
            "pr_Amon_bcc-csm1-1_rcp45_r1i1p1_210001-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
      gridfile.filename = "tas_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'BCC-CSM1-1-m-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "BCC-CSM1-1-m",
      gcm.run = 1,
      institute = "BCC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_bcc-csm1-1-m_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_bcc-csm1-1-m_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
      gridfile.filename = "tas_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'BNU-ESM-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "BNU-ESM",
      gcm.run = 1,
      institute = "GCESS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_BNU-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_BNU-ESM_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_BNU-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_BNU-ESM_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/historical",
      gridfile.filename = "tas_Amon_BNU-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r10i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 10,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r10i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r10i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r10i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r10i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r10i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 1,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r1i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r1i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r1i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r1i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r1i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 2,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r2i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r2i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r2i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r2i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r2i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 3,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r3i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r3i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r3i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r3i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r3i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 4,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r4i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r4i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r4i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r4i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r4i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r5i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 5,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r5i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r5i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r5i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r5i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r5i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r6i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 6,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r6i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r6i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r6i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r6i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r6i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r7i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 7,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r7i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r7i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r7i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r7i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r7i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r8i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 8,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r8i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r8i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r8i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r8i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r8i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanCM4-r9i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanCM4",
      gcm.run = 9,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanCM4_historical_r9i1p1_196101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanCM4_rcp45_r9i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanCM4_historical_r9i1p1_196101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanCM4_rcp45_r9i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanCM4/historical",
      gridfile.filename = "tas_Amon_CanCM4_historical_r9i1p1_196101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 1,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp45_r1i1p1_200601-210012.nc", 
            "tas_Amon_CanESM2_rcp45_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp45_r1i1p1_200601-210012.nc", 
            "pr_Amon_CanESM2_rcp45_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 2,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp45_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp45_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 3,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp45_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp45_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 4,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp45_r4i1p1_200601-210012.nc", 
            "tas_Amon_CanESM2_rcp45_r4i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp45_r4i1p1_200601-210012.nc", 
            "pr_Amon_CanESM2_rcp45_r4i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r5i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 5,
      institute = "CCCma",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp45_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp45_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 1,
      institute = "NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp45_r1i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp45_r1i1p1_200601-210012.nc", 
            "tas_Amon_CCSM4_rcp45_r1i1p1_210101-229912.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp45_r1i1p1_200601-210012.nc", 
            "pr_Amon_CCSM4_rcp45_r1i1p1_210101-229912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 2,
      institute = "NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp45_r2i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp45_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp45_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 3,
      institute = "NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp45_r3i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp45_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp45_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 4,
      institute = "NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp45_r4i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp45_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp45_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r5i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 5,
      institute = "NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp45_r5i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp45_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp45_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r6i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 6,
      institute = "NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CCSM4_rcp45_r6i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp45_r6i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r6i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-BGC-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CESM1-BGC",
      gcm.run = 1,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-BGC_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-BGC_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-BGC_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-BGC_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/historical",
      gridfile.filename = "tas_Amon_CESM1-BGC_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 1,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp45_r1i1p1_200601-210012.nc", 
            "tas_Amon_CESM1-CAM5_rcp45_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp45_r1i1p1_200601-210012.nc", 
            "pr_Amon_CESM1-CAM5_rcp45_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 2,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp45_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp45_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 3,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp45_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp45_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-WACCM-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CESM1-WACCM",
      gcm.run = 2,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-WACCM_historical_r2i1p1_195501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-WACCM_rcp45_r2i1p1_200601-209912.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-WACCM_historical_r2i1p1_195501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-WACCM_rcp45_r2i1p1_200601-209912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
      gridfile.filename = "tas_Amon_CESM1-WACCM_historical_r2i1p1_195501-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-WACCM-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CESM1-WACCM",
      gcm.run = 3,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-WACCM_historical_r3i1p1_195501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-WACCM_rcp45_r3i1p1_200601-206512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-WACCM_historical_r3i1p1_195501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-WACCM_rcp45_r3i1p1_200601-206512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
      gridfile.filename = "tas_Amon_CESM1-WACCM_historical_r3i1p1_195501-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-WACCM-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CESM1-WACCM",
      gcm.run = 4,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-WACCM_historical_r4i1p1_195501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-WACCM_rcp45_r4i1p1_200601-206512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-WACCM_historical_r4i1p1_195501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-WACCM_rcp45_r4i1p1_200601-206512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
      gridfile.filename = "tas_Amon_CESM1-WACCM_historical_r4i1p1_195501-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CMCC-CM-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CMCC-CM",
      gcm.run = 1,
      institute = "CMCC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CMCC-CM_historical_r1i1p1_185001-185912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_186001-186912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_187001-187912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_188001-188912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_189001-189912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_190001-190912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_191001-191912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_192001-192912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_193001-193912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_194001-194912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_195001-195912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_196001-196912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_197001-197912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_198001-198912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_199001-199912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_200601-201012.nc", 
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_201101-202012.nc", 
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_202101-203012.nc", 
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_203101-204012.nc", 
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_204101-205012.nc", 
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_205101-206012.nc", 
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_206101-207012.nc", 
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_207101-208012.nc", 
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_208101-209012.nc", 
            "tas_Amon_CMCC-CM_rcp45_r1i1p1_209101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CMCC-CM_historical_r1i1p1_185001-185912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_186001-186912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_187001-187912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_188001-188912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_189001-189912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_190001-190912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_191001-191912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_192001-192912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_193001-193912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_194001-194912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_195001-195912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_196001-196912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_197001-197912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_198001-198912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_199001-199912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_200601-201012.nc", 
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_201101-202012.nc", 
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_202101-203012.nc", 
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_203101-204012.nc", 
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_204101-205012.nc", 
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_205101-206012.nc", 
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_206101-207012.nc", 
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_207101-208012.nc", 
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_208101-209012.nc", 
            "pr_Amon_CMCC-CM_rcp45_r1i1p1_209101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/historical",
      gridfile.filename = "tas_Amon_CMCC-CM_historical_r1i1p1_185001-185912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CMCC-CMS-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CMCC-CMS",
      gcm.run = 1,
      institute = "CMCC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CMCC-CMS_historical_r1i1p1_185001-185912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_186001-186912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_187001-187912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_188001-188912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_189001-189912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_190001-190912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_191001-191912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_192001-192912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_193001-193912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_194001-194912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_195001-195912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_196001-196912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_197001-197912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_198001-198912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_199001-199912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_200601-200912.nc", 
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_201001-201912.nc", 
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_202001-202912.nc", 
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_203001-203912.nc", 
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_204001-204912.nc", 
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_205001-205912.nc", 
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_206001-206912.nc", 
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_207001-207912.nc", 
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_208001-208912.nc", 
            "tas_Amon_CMCC-CMS_rcp45_r1i1p1_209001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CMCC-CMS_historical_r1i1p1_185001-185912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_186001-186912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_187001-187912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_188001-188912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_189001-189912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_190001-190912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_191001-191912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_192001-192912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_193001-193912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_194001-194912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_195001-195912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_196001-196912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_197001-197912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_198001-198912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_199001-199912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_200601-200912.nc", 
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_201001-201912.nc", 
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_202001-202912.nc", 
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_203001-203912.nc", 
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_204001-204912.nc", 
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_205001-205912.nc", 
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_206001-206912.nc", 
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_207001-207912.nc", 
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_208001-208912.nc", 
            "pr_Amon_CMCC-CMS_rcp45_r1i1p1_209001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/historical",
      gridfile.filename = "tas_Amon_CMCC-CMS_historical_r1i1p1_185001-185912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CNRM-CM5-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CNRM-CM5",
      gcm.run = 1,
      institute = "CNRM-CERFACS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CNRM-CM5_historical_r1i1p1_185001-189912.nc", 
            "tas_Amon_CNRM-CM5_historical_r1i1p1_190001-194912.nc", 
            "tas_Amon_CNRM-CM5_historical_r1i1p1_195001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CNRM-CM5_rcp45_r1i1p1_200601-205512.nc", 
            "tas_Amon_CNRM-CM5_rcp45_r1i1p1_205601-210012.nc", 
            "tas_Amon_CNRM-CM5_rcp45_r1i1p1_210101-215012.nc", 
            "tas_Amon_CNRM-CM5_rcp45_r1i1p1_215101-220012.nc", 
            "tas_Amon_CNRM-CM5_rcp45_r1i1p1_220101-225012.nc", 
            "tas_Amon_CNRM-CM5_rcp45_r1i1p1_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CNRM-CM5_historical_r1i1p1_185001-189912.nc", 
            "pr_Amon_CNRM-CM5_historical_r1i1p1_190001-194912.nc", 
            "pr_Amon_CNRM-CM5_historical_r1i1p1_195001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CNRM-CM5_rcp45_r1i1p1_200601-205512.nc", 
            "pr_Amon_CNRM-CM5_rcp45_r1i1p1_205601-210012.nc", 
            "pr_Amon_CNRM-CM5_rcp45_r1i1p1_210101-215012.nc", 
            "pr_Amon_CNRM-CM5_rcp45_r1i1p1_215101-220012.nc", 
            "pr_Amon_CNRM-CM5_rcp45_r1i1p1_220101-225012.nc", 
            "pr_Amon_CNRM-CM5_rcp45_r1i1p1_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
      gridfile.filename = "tas_Amon_CNRM-CM5_historical_r1i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r10i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 10,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r10i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r10i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 1,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r1i1p1_200601-210012.nc", 
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r1i1p1_200601-210012.nc", 
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 2,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r2i1p1_200601-210012.nc", 
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r2i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r2i1p1_200601-210012.nc", 
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r2i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 3,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r3i1p1_200601-210012.nc", 
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r3i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r3i1p1_200601-210012.nc", 
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r3i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 4,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r5i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 5,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r6i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 6,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r6i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r6i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r7i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 7,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r7i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r7i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r8i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 8,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r8i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r8i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r9i1p1_rcp45' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 9,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp45_r9i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp45_r9i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r12i1p1_rcp45' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 12,
      institute = "EC-EARTH",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r12i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r12i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r12i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp45_r12i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r12i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r12i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r12i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp45_r12i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r12i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r13i1p1_rcp45' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 13,
      institute = "EC-EARTH",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r13i1p1_195001-195912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_196001-196912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_197001-197912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_198001-198912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_199001-199912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_200001-200911.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_200601-200912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_201001-201912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_202001-202912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_203001-203912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_204001-204912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_205001-205912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_206001-206912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_207001-207912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_208001-208912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_209001-209912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r13i1p1_210001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r13i1p1_195001-195912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_196001-196912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_197001-197912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_198001-198912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_199001-199912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_200001-200911.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_200601-200912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_201001-201912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_202001-202912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_203001-203912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_204001-204912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_205001-205912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_206001-206912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_207001-207912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_208001-208912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_209001-209912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r13i1p1_210001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r13i1p1_195001-195912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r14i1p1_rcp45' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 14,
      institute = "EC-EARTH",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r14i1p1_195001-195912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_196001-196912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_197001-197912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_198001-198912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_199001-199912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_200001-200911.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_200601-200912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_201001-201912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_202001-202912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_203001-203912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_204001-204912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_205001-205912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_206001-206912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_207001-207912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_208001-208912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_209001-209912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r14i1p1_210001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r14i1p1_195001-195912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_196001-196912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_197001-197912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_198001-198912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_199001-199912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_200001-200911.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_200601-200912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_201001-201912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_202001-202912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_203001-203912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_204001-204912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_205001-205912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_206001-206912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_207001-207912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_208001-208912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_209001-209912.nc", 
            "pr_Amon_EC-EARTH_rcp45_r14i1p1_210001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r14i1p1_195001-195912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    ## WARNING, SCENAIO DATA FOR PRECIP NOT AVAILABLE!
    'EC-EARTH-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 1,
      institute = "EC-EARTH",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r1i1p1_185001-185912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_186001-186912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_187001-187912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_188001-188912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_189001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_190001-190912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_191001-191912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_192001-192912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_193001-193912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_194001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_195001-195912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_196001-196912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_197001-197912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_198001-198912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_199001-199912.nc", 
            "tas_Amon_EC-EARTH_historical_r1i1p1_200001-200911.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_200601-200912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_201001-201912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_202001-202912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_203001-203912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_204001-204912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_205001-205912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_206001-206912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_207001-207912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_208001-208912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_209001-209912.nc", 
            "tas_Amon_EC-EARTH_rcp45_r1i1p1_210001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_185001-185912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_186001-186912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_187001-187912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_188001-188912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_189001-189912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_190001-190912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_191001-191912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_192001-192912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_193001-193912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_194001-194912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_195001-195912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_196001-196912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_197001-197912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_198001-198912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_199001-199912.nc", 
            ## "pr_Amon_EC-EARTH_historical_r1i1p1_200001-200912.nc"
            NA
            ),
          scenario = c(
            NA
            ## "pr_Amon_EC-EARTH_rcp45_r1i1p1_200601-200912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r1i1p1_185001-185912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 2,
      institute = "EC-EARTH",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r2i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r2i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r2i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp45_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r2i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r2i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r2i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp45_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r2i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r6i1p1_rcp45' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 6,
      institute = "EC-EARTH",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r6i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r6i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r6i1p1_195001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp45_r6i1p1_200601-205012.nc", 
            "tas_Amon_EC-EARTH_rcp45_r6i1p1_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r6i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r6i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r6i1p1_195001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp45_r6i1p1_200601-205012.nc", 
            "pr_Amon_EC-EARTH_rcp45_r6i1p1_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r6i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    ## 'EC-EARTH-r7i1p1_rcp45' = list( 
    ##   rcm = "",
    ##   gcm = "EC-EARTH",
    ##   gcm.run = 7,
    ##   institute = "EC-EARTH",
    ##   emission.scenario = "rcp45",
    ##   file.path.alt = list(
    ##     air_temperature =
    ##     list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
    ##          scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45"),
    ##     precipitation_amount =
    ##     list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
    ##          scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c(
    ##         "tas_Amon_EC-EARTH_historical_r7i1p1_200601-204512.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r7i1p1_204601-208012.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r7i1p1_208101-210012.nc"
    ##         ),
    ##       scenario = c(
    ##         "tas_Amon_EC-EARTH_rcp45_r7i1p1_200601-205012.nc", 
    ##         "tas_Amon_EC-EARTH_rcp45_r7i1p1_205101-210012.nc"
    ##         )),
    ##     precipitation_amount = list(
    ##       historical = c(
    ##         "pr_Amon_EC-EARTH_historical_r7i1p1_200601-204512.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r7i1p1_204601-208012.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r7i1p1_208101-210012.nc"
    ##         ),
    ##       scenario = c(
    ##         "pr_Amon_EC-EARTH_rcp45_r7i1p1_200601-205012.nc", 
    ##         "pr_Amon_EC-EARTH_rcp45_r7i1p1_205101-210012.nc"
    ##        ))),
    ##   gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
    ##   gridfile.filename = "tas_Amon_EC-EARTH_historical_r7i1p1_200601-204512.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),

################################################################################
    'EC-EARTH-r8i1p1_rcp45' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 8,
      institute = "EC-EARTH",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r8i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r8i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r8i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp45_r8i1p1_200601-205012.nc", 
            "tas_Amon_EC-EARTH_rcp45_r8i1p1_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r8i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r8i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r8i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp45_r8i1p1_200601-205012.nc", 
            "pr_Amon_EC-EARTH_rcp45_r8i1p1_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r8i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r9i1p1_rcp45' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 9,
      institute = "EC-EARTH",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r9i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r9i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r9i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp45_r9i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r9i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r9i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r9i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp45_r9i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r9i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FGOALS-g2-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "FGOALS-g2",
      gcm.run = 1,
      institute = "LASG-CESS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FGOALS-g2_historical_r1i1p1_185001-185912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_186001-186912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_187001-187912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_188001-188912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_189001-189912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_190001-190912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_191001-191912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_192001-192912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_193001-193912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_194001-194912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_195001-195912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_196001-196912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_197001-197912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_198001-198912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_199001-199912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_200601-201512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_201601-202512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_202601-203512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_203601-204512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_204601-205512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_205601-206512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_206601-207512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_207601-208512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_208601-209512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_209601-210512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_210601-211512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_211601-212512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_212601-213512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_213601-214512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_214601-215512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_215601-216512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_216601-217512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_217601-218512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_218601-219512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_219601-220512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_220601-221512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_221601-222512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_222601-223512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_223601-224512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_224601-225512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_225601-226512.nc", 
            "tas_Amon_FGOALS-g2_rcp45_r1i1p1_226601-227512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FGOALS-g2_historical_r1i1p1_185001-185912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_186001-186912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_187001-187912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_188001-188912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_189001-189912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_190001-190912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_191001-191912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_192001-192912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_193001-193912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_194001-194912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_195001-195912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_196001-196912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_197001-197912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_198001-198912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_199001-199912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_200601-201512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_201601-202512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_202601-203512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_203601-204512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_204601-205512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_205601-206512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_206601-207512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_207601-208512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_208601-209512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_209601-210512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_210601-211512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_211601-212512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_212601-213512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_213601-214512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_214601-215512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_215601-216512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_216601-217512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_217601-218512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_218601-219512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_219601-220512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_220601-221512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_221601-222512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_222601-223512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_223601-224512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_224601-225512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_225601-226512.nc", 
            "pr_Amon_FGOALS-g2_rcp45_r1i1p1_226601-227512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/historical",
      gridfile.filename = "tas_Amon_FGOALS-g2_historical_r1i1p1_185001-185912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 1,
      institute = "FIO",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 2,
      institute = "FIO",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp45_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp45_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 3,
      institute = "FIO",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp45_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp45_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r10i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 10,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r10i1p1_200101-200512.nc"
            ## "tas_Amon_GFDL-CM2p1_historical_r10i1p1_200601-201012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r10i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r10i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r10i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r10i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r10i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r10i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r10i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r10i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r10i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r10i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r10i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r10i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r10i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r10i1p1_200101-200512.nc"
            ## "pr_Amon_GFDL-CM2p1_historical_r10i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r10i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r10i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r10i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r10i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r10i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r10i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r10i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r10i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r10i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r10i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r10i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r10i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r10i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r10i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r1i1p1_200101-200512.nc"
            ## "tas_Amon_GFDL-CM2p1_historical_r1i1p1_200601-201012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r1i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r1i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r1i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r1i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r1i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r1i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r1i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r1i1p1_200101-200512.nc"
            ## "pr_Amon_GFDL-CM2p1_historical_r1i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r1i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r1i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r1i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r1i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r1i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r1i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r1i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r1i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 2,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r2i1p1_200101-200512.nc"
            ## "tas_Amon_GFDL-CM2p1_historical_r2i1p1_200601-201012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r2i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r2i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r2i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r2i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r2i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r2i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r2i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r2i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r2i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r2i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r2i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r2i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r2i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r2i1p1_200101-200512.nc" 
            ## "pr_Amon_GFDL-CM2p1_historical_r2i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r2i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r2i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r2i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r2i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r2i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r2i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r2i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r2i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r2i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r2i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r2i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r2i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r2i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r2i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 3,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r3i1p1_200101-200512.nc" 
            ## "tas_Amon_GFDL-CM2p1_historical_r3i1p1_200601-201012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r3i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r3i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r3i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r3i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r3i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r3i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r3i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r3i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r3i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r3i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r3i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r3i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r3i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r3i1p1_200101-200512.nc"
            ## "pr_Amon_GFDL-CM2p1_historical_r3i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r3i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r3i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r3i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r3i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r3i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r3i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r3i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r3i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r3i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r3i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r3i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r3i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r3i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r3i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 4,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r4i1p1_200101-200512.nc"
            ## "tas_Amon_GFDL-CM2p1_historical_r4i1p1_200601-201012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r4i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r4i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r4i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r4i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r4i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r4i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r4i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r4i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r4i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r4i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r4i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r4i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r4i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r4i1p1_200101-200512.nc"
            ## "pr_Amon_GFDL-CM2p1_historical_r4i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r4i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r4i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r4i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r4i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r4i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r4i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r4i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r4i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r4i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r4i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r4i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r4i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r4i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r4i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r5i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 5,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r5i1p1_200101-200512.nc" 
            ## "tas_Amon_GFDL-CM2p1_historical_r5i1p1_200601-201012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r5i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r5i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r5i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r5i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r5i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r5i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r5i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r5i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r5i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r5i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r5i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r5i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r5i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r5i1p1_200101-200512.nc"
            ## "pr_Amon_GFDL-CM2p1_historical_r5i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r5i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r5i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r5i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r5i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r5i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r5i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r5i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r5i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r5i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r5i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r5i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r5i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r5i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r5i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r6i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 6,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r6i1p1_200101-200512.nc"
            ## "tas_Amon_GFDL-CM2p1_historical_r6i1p1_200601-201012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r6i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r6i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r6i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r6i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r6i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r6i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r6i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r6i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r6i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r6i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r6i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r6i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r6i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r6i1p1_200101-200512.nc"
            ## "pr_Amon_GFDL-CM2p1_historical_r6i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r6i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r6i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r6i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r6i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r6i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r6i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r6i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r6i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r6i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r6i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r6i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r6i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r6i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r6i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r7i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 7,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r7i1p1_200101-200512.nc"
            ## "tas_Amon_GFDL-CM2p1_historical_r7i1p1_200601-201012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r7i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r7i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r7i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r7i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r7i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r7i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r7i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r7i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r7i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r7i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r7i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r7i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r7i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r7i1p1_200101-200512.nc"
            ## "pr_Amon_GFDL-CM2p1_historical_r7i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r7i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r7i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r7i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r7i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r7i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r7i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r7i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r7i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r7i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r7i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r7i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r7i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r7i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r7i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r8i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 8,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r8i1p1_200101-200512.nc"
            ## "tas_Amon_GFDL-CM2p1_historical_r8i1p1_200601-201012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r8i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r8i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r8i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r8i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r8i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r8i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r8i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r8i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r8i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r8i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r8i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r8i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r8i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r8i1p1_200101-200512.nc"
            ## "pr_Amon_GFDL-CM2p1_historical_r8i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r8i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r8i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r8i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r8i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r8i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r8i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r8i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r8i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r8i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r8i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r8i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r8i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r8i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r8i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM2-1-r9i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM2-1",
      gcm.run = 9,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-CM2p1_historical_r9i1p1_200101-200512.nc"
            ## "tas_Amon_GFDL-CM2p1_historical_r9i1p1_200601-201012.nc",
            ## "tas_Amon_GFDL-CM2p1_historical_r9i1p1_201101-201512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r9i1p1_201601-202012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r9i1p1_202101-202512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r9i1p1_202601-203012.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r9i1p1_203101-203512.nc", 
            ## "tas_Amon_GFDL-CM2p1_historical_r9i1p1_203601-204012.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM2p1_rcp45_r9i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r9i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r9i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r9i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r9i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r9i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM2p1_rcp45_r9i1p1_203601-204012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-CM2p1_historical_r9i1p1_200101-200512.nc"
            ## "pr_Amon_GFDL-CM2p1_historical_r9i1p1_200601-201012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r9i1p1_201101-201512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r9i1p1_201601-202012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r9i1p1_202101-202512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r9i1p1_202601-203012.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r9i1p1_203101-203512.nc", 
            ## "pr_Amon_GFDL-CM2p1_historical_r9i1p1_203601-204012.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM2p1_rcp45_r9i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r9i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r9i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r9i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r9i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r9i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM2p1_rcp45_r9i1p1_203601-204012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM2.1/historical",
      gridfile.filename = "tas_Amon_GFDL-CM2p1_historical_r9i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM3-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-CM3",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_186501-186912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_187001-187412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_187501-187912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_188001-188412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_188501-188912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_189001-189412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_189501-189912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_190001-190412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_190501-190912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_191001-191412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_191501-191912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_192001-192412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_192501-192912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_193001-193412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_193501-193912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_194001-194412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_194501-194912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_195001-195412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_195501-195912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_196001-196412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_196501-196912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_197001-197412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_197501-197912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_198001-198412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_198501-198912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_199001-199412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_199501-199912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_200001-200412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_209601-210012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_210101-210512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_210601-211012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_211101-211512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_211601-212012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_212101-212512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_212601-213012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_213101-213512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_213601-214012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_214101-214512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_214601-215012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_215101-215512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_215601-216012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_216101-216512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_216601-217012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_217101-217512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_217601-218012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_218101-218512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_218601-219012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_219101-219512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_219601-220012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_220101-220512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_220601-221012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_221101-221512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_221601-222012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_222101-222512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_222601-223012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_223101-223512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_223601-224012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_224101-224512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_224601-225012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_225101-225512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_225601-226012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_226101-226512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_226601-227012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_227101-227512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_227601-228012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_228101-228512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_228601-229012.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_229101-229512.nc", 
            "tas_Amon_GFDL-CM3_rcp45_r1i1p1_229601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_186501-186912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_187001-187412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_187501-187912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_188001-188412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_188501-188912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_189001-189412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_189501-189912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_190001-190412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_190501-190912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_191001-191412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_191501-191912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_192001-192412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_192501-192912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_193001-193412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_193501-193912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_194001-194412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_194501-194912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_195001-195412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_195501-195912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_196001-196412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_196501-196912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_197001-197412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_197501-197912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_198001-198412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_198501-198912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_199001-199412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_199501-199912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_200001-200412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_209601-210012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_210101-210512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_210601-211012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_211101-211512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_211601-212012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_212101-212512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_212601-213012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_213101-213512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_213601-214012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_214101-214512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_214601-215012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_215101-215512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_215601-216012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_216101-216512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_216601-217012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_217101-217512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_217601-218012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_218101-218512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_218601-219012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_219101-219512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_219601-220012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_220101-220512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_220601-221012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_221101-221512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_221601-222012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_222101-222512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_222601-223012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_223101-223512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_223601-224012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_224101-224512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_224601-225012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_225101-225512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_225601-226012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_226101-226512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_226601-227012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_227101-227512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_227601-228012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_228101-228512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_228601-229012.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_229101-229512.nc", 
            "pr_Amon_GFDL-CM3_rcp45_r1i1p1_229601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
      gridfile.filename = "tas_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-ESM2G-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-ESM2G",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp45_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp45_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
      gridfile.filename = "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-ESM2M-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GFDL-ESM2M",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_209601-210012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_210101-210512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_210601-211012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_211101-211512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_211601-212012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_212101-212512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_212601-213012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_213101-213512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_213601-214012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_214101-214512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_214601-215012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_215101-215512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_215601-216012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_216101-216512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_216601-217012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_217101-217512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_217601-218012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_218101-218512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_218601-219012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_219101-219512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp45_r1i1p1_219601-220012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp45_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
      gridfile.filename = "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p1_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r1i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p1_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p1_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p1_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p1_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p1_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p1_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r1i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p1_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p1_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p1_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p1_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p1_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p2_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r1i1p2_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p2_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p2_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p2_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p2_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p2_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p2_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r1i1p2_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p2_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p2_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p2_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p2_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p2_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p3_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r1i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p3_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p3_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p3_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p3_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r1i1p3_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p3_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r1i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p3_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p3_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p3_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p3_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r1i1p3_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r2i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r2i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r2i1p1_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r2i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p1_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p1_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p1_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p1_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p1_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r2i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r2i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r2i1p1_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r2i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p1_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p1_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p1_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p1_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p1_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r2i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r2i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r2i1p2_185001-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r2i1p2_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r2i1p2_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p2_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p2_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p2_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p2_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p2_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r2i1p2_185001-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r2i1p2_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r2i1p2_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p2_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p2_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p2_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p2_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p2_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r2i1p2_185001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r2i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r2i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r2i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r2i1p3_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r2i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p3_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p3_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p3_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p3_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r2i1p3_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r2i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r2i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r2i1p3_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r2i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p3_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p3_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p3_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p3_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r2i1p3_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r2i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 3,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r3i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r3i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r3i1p1_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r3i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p1_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p1_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p1_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p1_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p1_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r3i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r3i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r3i1p1_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r3i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p1_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p1_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p1_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p1_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p1_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r3i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r3i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 3,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r3i1p2_185001-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r3i1p2_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r3i1p2_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p2_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p2_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p2_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p2_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p2_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r3i1p2_185001-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r3i1p2_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r3i1p2_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p2_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p2_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p2_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p2_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p2_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r3i1p2_185001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r3i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 3,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r3i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r3i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r3i1p3_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r3i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p3_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p3_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p3_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p3_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r3i1p3_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r3i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r3i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r3i1p3_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r3i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p3_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p3_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p3_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p3_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r3i1p3_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r3i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 4,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r4i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r4i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r4i1p1_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r4i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p1_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p1_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p1_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p1_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p1_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r4i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r4i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r4i1p1_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r4i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p1_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p1_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p1_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p1_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p1_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r4i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r4i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 4,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r4i1p2_185001-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r4i1p2_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r4i1p2_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p2_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p2_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p2_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p2_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p2_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r4i1p2_185001-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r4i1p2_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r4i1p2_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p2_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p2_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p2_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p2_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p2_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r4i1p2_185001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r4i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 4,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r4i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r4i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r4i1p3_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r4i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p3_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p3_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p3_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p3_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r4i1p3_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r4i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r4i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r4i1p3_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r4i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p3_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p3_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p3_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p3_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r4i1p3_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r4i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r5i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 5,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r5i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r5i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r5i1p1_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r5i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p1_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p1_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p1_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p1_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p1_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r5i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r5i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r5i1p1_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r5i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p1_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p1_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p1_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p1_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p1_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r5i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r5i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 5,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r5i1p2_185001-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r5i1p2_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r5i1p2_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p2_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p2_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p2_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p2_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p2_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r5i1p2_185001-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r5i1p2_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r5i1p2_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p2_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p2_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p2_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p2_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p2_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r5i1p2_185001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r5i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 5,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r5i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r5i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r5i1p3_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r5i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p3_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p3_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p3_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p3_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r5i1p3_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r5i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r5i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r5i1p3_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r5i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p3_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p3_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p3_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p3_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r5i1p3_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r5i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r6i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 6,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r6i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r6i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r6i1p3_195101-200012.nc", 
            "tas_Amon_GISS-E2-H_historical_r6i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp45_r6i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp45_r6i1p3_205101-209912.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r6i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r6i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r6i1p3_195101-200012.nc", 
            "pr_Amon_GISS-E2-H_historical_r6i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp45_r6i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp45_r6i1p3_205101-209912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r6i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-CC-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-H-CC",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H-CC_historical_r1i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H-CC_historical_r1i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H-CC_historical_r1i1p1_195101-201012.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H-CC_rcp45_r1i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H-CC_rcp45_r1i1p1_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H-CC_historical_r1i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H-CC_historical_r1i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H-CC_historical_r1i1p1_195101-201012.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H-CC_rcp45_r1i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H-CC_rcp45_r1i1p1_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H-CC_historical_r1i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p1_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p1_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p2_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p2_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r1i1p3_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r1i1p3_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r2i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p1_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r2i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p1_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r2i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r2i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r2i1p2_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p2_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p2_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p2_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p2_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p2_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p2_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p2_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r2i1p2_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p2_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p2_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p2_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p2_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p2_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p2_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p2_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r2i1p2_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r2i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r2i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r2i1p3_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r2i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r2i1p3_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r2i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 3,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r3i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p1_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r3i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p1_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r3i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r3i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 3,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r3i1p2_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p2_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p2_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p2_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p2_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p2_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p2_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p2_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r3i1p2_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p2_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p2_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p2_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p2_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p2_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p2_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p2_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r3i1p2_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r3i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 3,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r3i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r3i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r3i1p3_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r3i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r3i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r3i1p3_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r3i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 4,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r4i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p1_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r4i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p1_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r4i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r4i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 4,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r4i1p2_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p2_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p2_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p2_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p2_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p2_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p2_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p2_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r4i1p2_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p2_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p2_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p2_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p2_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p2_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p2_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p2_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r4i1p2_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r4i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 4,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r4i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r4i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r4i1p3_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r4i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r4i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r4i1p3_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r4i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r5i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 5,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r5i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p1_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r5i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p1_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r5i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r5i1p2_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 5,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r5i1p2_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p2_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p2_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p2_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p2_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p2_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p2_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p2_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r5i1p2_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p2_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p2_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p2_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p2_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p2_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p2_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p2_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r5i1p2_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r5i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 5,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r5i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r5i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r5i1p3_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r5i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r5i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r5i1p3_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r5i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r6i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 6,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r6i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r6i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r6i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r6i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r6i1p1_207601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r6i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r6i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r6i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r6i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r6i1p1_207601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r6i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r6i1p3_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 6,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r6i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r6i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp45_r6i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r6i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r6i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp45_r6i1p3_207601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r6i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r6i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp45_r6i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r6i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r6i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp45_r6i1p3_207601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r6i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-CC-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "GISS-E2-R-CC",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_200101-201012.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R-CC_rcp45_r1i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R-CC_rcp45_r1i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R-CC_rcp45_r1i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R-CC_rcp45_r1i1p1_207601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_200101-201012.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R-CC_rcp45_r1i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R-CC_rcp45_r1i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R-CC_rcp45_r1i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R-CC_rcp45_r1i1p1_207601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r10i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 10,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r10i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r10i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r10i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r10i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r10i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r10i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r10i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r10i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r10i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r10i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r10i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r10i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r10i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r10i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r10i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r10i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r10i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 1,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r1i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r1i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r1i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r1i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r1i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r1i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r1i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r1i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r1i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r1i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r1i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r1i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r1i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r1i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r1i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r1i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r1i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 2,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r2i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r2i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r2i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r2i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r2i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r2i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r2i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r2i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r2i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r2i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r2i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r2i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r2i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r2i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r2i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 3,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r3i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r3i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r3i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r3i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r3i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r3i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r3i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r3i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r3i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r3i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r3i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r3i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r3i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r3i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r3i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 4,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r4i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r4i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r4i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r4i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r4i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r4i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r4i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r4i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r4i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r4i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r4i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r4i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r4i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r4i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r4i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r4i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r4i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r5i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 5,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r5i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r5i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r5i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r5i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r5i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r5i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r5i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r5i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r5i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r5i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r5i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r5i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r5i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r5i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r5i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r5i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r5i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r6i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 6,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r6i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r6i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r6i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r6i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r6i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r6i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r6i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r6i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r6i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r6i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r6i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r6i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r6i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r6i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r6i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r6i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r6i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r7i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 7,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r7i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r7i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r7i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r7i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r7i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r7i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r7i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r7i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r7i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r7i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r7i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r7i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r7i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r7i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r7i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r7i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r7i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r8i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 8,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r8i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r8i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r8i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r8i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r8i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r8i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r8i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r8i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r8i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r8i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r8i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r8i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r8i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r8i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r8i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r8i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r8i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadCM3-r9i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadCM3",
      gcm.run = 9,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadCM3_historical_r9i1p1_185912-188411.nc", 
            "tas_Amon_HadCM3_historical_r9i1p1_188412-190911.nc", 
            "tas_Amon_HadCM3_historical_r9i1p1_190912-193411.nc", 
            "tas_Amon_HadCM3_historical_r9i1p1_193412-195911.nc", 
            "tas_Amon_HadCM3_historical_r9i1p1_195912-198411.nc", 
            "tas_Amon_HadCM3_historical_r9i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadCM3_rcp45_r9i1p1_200601-203012.nc", 
            "tas_Amon_HadCM3_rcp45_r9i1p1_203101-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadCM3_historical_r9i1p1_185912-188411.nc", 
            "pr_Amon_HadCM3_historical_r9i1p1_188412-190911.nc", 
            "pr_Amon_HadCM3_historical_r9i1p1_190912-193411.nc", 
            "pr_Amon_HadCM3_historical_r9i1p1_193412-195911.nc", 
            "pr_Amon_HadCM3_historical_r9i1p1_195912-198411.nc", 
            "pr_Amon_HadCM3_historical_r9i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadCM3_rcp45_r9i1p1_200601-203012.nc", 
            "pr_Amon_HadCM3_rcp45_r9i1p1_203101-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadCM3/historical",
      gridfile.filename = "tas_Amon_HadCM3_historical_r9i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-AO-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadGEM2-AO",
      gcm.run = 1,
      institute = "NIMR/KMA",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_HadGEM2-AO_rcp45_r1i1p1_200601-209912.nc", 
            "tas_Amon_HadGEM2-AO_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc"
            ),
          scenario = c(
##            "pr_Amon_HadGEM2-AO_rcp45_r1i1p1_200601-209912.nc", 
            "pr_Amon_HadGEM2-AO_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
      gridfile.filename = "tas_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-CC-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadGEM2-CC",
      gcm.run = 1,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-CC_rcp45_r1i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-CC_rcp45_r1i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-CC_rcp45_r1i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-CC_rcp45_r1i1p1_208012-209912.nc", 
            "tas_Amon_HadGEM2-CC_rcp45_r1i1p1_210001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-CC_rcp45_r1i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-CC_rcp45_r1i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-CC_rcp45_r1i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-CC_rcp45_r1i1p1_208012-209912.nc", 
            "pr_Amon_HadGEM2-CC_rcp45_r1i1p1_210001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
      gridfile.filename = "tas_Amon_HadGEM2-CC_historical_r1i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 1,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_208012-209911.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_209912-212411.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_212412-214911.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_214912-217411.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_217412-219911.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_219912-222411.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_222412-224911.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_224912-227411.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_227412-229911.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r1i1p1_229912-229912.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_208012-209911.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_209912-212411.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_212412-214911.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_214912-217411.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_217412-219911.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_219912-222411.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_222412-224911.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_224912-227411.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_227412-229911.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r1i1p1_229912-229912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 2,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp45_r2i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r2i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r2i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r2i1p1_208012-210011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r2i1p1_210012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp45_r2i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r2i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r2i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r2i1p1_208012-210011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r2i1p1_210012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 3,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp45_r3i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r3i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r3i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r3i1p1_208012-210011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r3i1p1_210012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp45_r3i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r3i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r3i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r3i1p1_208012-210011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r3i1p1_210012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 4,
      institute = "MOHC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp45_r4i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r4i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r4i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r4i1p1_208012-210011.nc", 
            "tas_Amon_HadGEM2-ES_rcp45_r4i1p1_210012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp45_r4i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r4i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r4i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r4i1p1_208012-210011.nc", 
            "pr_Amon_HadGEM2-ES_rcp45_r4i1p1_210012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'INM-CM4-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "INM-CM4",
      gcm.run = 1,
      institute = "INM",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_inmcm4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_inmcm4_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_inmcm4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_inmcm4_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/historical",
      gridfile.filename = "tas_Amon_inmcm4_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp45_r1i1p1_200601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp45_r1i1p1_200601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 2,
      institute = "IPSL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp45_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp45_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 3,
      institute = "IPSL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp45_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp45_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 4,
      institute = "IPSL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp45_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp45_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-MR-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-MR_rcp45_r1i1p1_200601-210012.nc", 
            "tas_Amon_IPSL-CM5A-MR_rcp45_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-MR_rcp45_r1i1p1_200601-210012.nc", 
            "pr_Amon_IPSL-CM5A-MR_rcp45_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5B-LR-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "IPSL-CM5B-LR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5B-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5B-LR_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5B-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5B-LR_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5B-LR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC4h-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC4h",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC4h_historical_r1i1p1_195001-195012.nc", 
            "tas_Amon_MIROC4h_historical_r1i1p1_195101-196012.nc", 
            "tas_Amon_MIROC4h_historical_r1i1p1_196101-197012.nc", 
            "tas_Amon_MIROC4h_historical_r1i1p1_197101-198012.nc", 
            "tas_Amon_MIROC4h_historical_r1i1p1_198101-199012.nc", 
            "tas_Amon_MIROC4h_historical_r1i1p1_199101-200012.nc", 
            "tas_Amon_MIROC4h_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC4h_rcp45_r1i1p1_200601-201512.nc", 
            "tas_Amon_MIROC4h_rcp45_r1i1p1_201601-202512.nc", 
            "tas_Amon_MIROC4h_rcp45_r1i1p1_202601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC4h_historical_r1i1p1_195001-195012.nc", 
            "pr_Amon_MIROC4h_historical_r1i1p1_195101-196012.nc", 
            "pr_Amon_MIROC4h_historical_r1i1p1_196101-197012.nc", 
            "pr_Amon_MIROC4h_historical_r1i1p1_197101-198012.nc", 
            "pr_Amon_MIROC4h_historical_r1i1p1_198101-199012.nc", 
            "pr_Amon_MIROC4h_historical_r1i1p1_199101-200012.nc", 
            "pr_Amon_MIROC4h_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC4h_rcp45_r1i1p1_200601-201512.nc", 
            "pr_Amon_MIROC4h_rcp45_r1i1p1_201601-202512.nc", 
            "pr_Amon_MIROC4h_rcp45_r1i1p1_202601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/historical",
      gridfile.filename = "tas_Amon_MIROC4h_historical_r1i1p1_195001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC4h-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC4h",
      gcm.run = 2,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC4h_historical_r2i1p1_195001-195012.nc", 
            "tas_Amon_MIROC4h_historical_r2i1p1_195101-196012.nc", 
            "tas_Amon_MIROC4h_historical_r2i1p1_196101-197012.nc", 
            "tas_Amon_MIROC4h_historical_r2i1p1_197101-198012.nc", 
            "tas_Amon_MIROC4h_historical_r2i1p1_198101-199012.nc", 
            "tas_Amon_MIROC4h_historical_r2i1p1_199101-200012.nc", 
            "tas_Amon_MIROC4h_historical_r2i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC4h_rcp45_r2i1p1_200601-201512.nc", 
            "tas_Amon_MIROC4h_rcp45_r2i1p1_201601-202512.nc", 
            "tas_Amon_MIROC4h_rcp45_r2i1p1_202601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC4h_historical_r2i1p1_195001-195012.nc", 
            "pr_Amon_MIROC4h_historical_r2i1p1_195101-196012.nc", 
            "pr_Amon_MIROC4h_historical_r2i1p1_196101-197012.nc", 
            "pr_Amon_MIROC4h_historical_r2i1p1_197101-198012.nc", 
            "pr_Amon_MIROC4h_historical_r2i1p1_198101-199012.nc", 
            "pr_Amon_MIROC4h_historical_r2i1p1_199101-200012.nc", 
            "pr_Amon_MIROC4h_historical_r2i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC4h_rcp45_r2i1p1_200601-201512.nc", 
            "pr_Amon_MIROC4h_rcp45_r2i1p1_201601-202512.nc", 
            "pr_Amon_MIROC4h_rcp45_r2i1p1_202601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/historical",
      gridfile.filename = "tas_Amon_MIROC4h_historical_r2i1p1_195001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC4h-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC4h",
      gcm.run = 3,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC4h_historical_r3i1p1_195001-195012.nc", 
            "tas_Amon_MIROC4h_historical_r3i1p1_195101-196012.nc", 
            "tas_Amon_MIROC4h_historical_r3i1p1_196101-197012.nc", 
            "tas_Amon_MIROC4h_historical_r3i1p1_197101-198012.nc", 
            "tas_Amon_MIROC4h_historical_r3i1p1_198101-199012.nc", 
            "tas_Amon_MIROC4h_historical_r3i1p1_199101-200012.nc", 
            "tas_Amon_MIROC4h_historical_r3i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC4h_rcp45_r3i1p1_200601-201512.nc", 
            "tas_Amon_MIROC4h_rcp45_r3i1p1_201601-202512.nc", 
            "tas_Amon_MIROC4h_rcp45_r3i1p1_202601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC4h_historical_r3i1p1_195001-195012.nc", 
            "pr_Amon_MIROC4h_historical_r3i1p1_195101-196012.nc", 
            "pr_Amon_MIROC4h_historical_r3i1p1_196101-197012.nc", 
            "pr_Amon_MIROC4h_historical_r3i1p1_197101-198012.nc", 
            "pr_Amon_MIROC4h_historical_r3i1p1_198101-199012.nc", 
            "pr_Amon_MIROC4h_historical_r3i1p1_199101-200012.nc", 
            "pr_Amon_MIROC4h_historical_r3i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC4h_rcp45_r3i1p1_200601-201512.nc", 
            "pr_Amon_MIROC4h_rcp45_r3i1p1_201601-202512.nc", 
            "pr_Amon_MIROC4h_rcp45_r3i1p1_202601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC4h/historical",
      gridfile.filename = "tas_Amon_MIROC4h_historical_r3i1p1_195001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 2,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r2i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp45_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r2i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp45_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r2i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 3,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r3i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp45_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r3i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp45_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r3i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r4i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 4,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r4i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp45_r4i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r4i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp45_r4i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r4i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r5i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 5,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r5i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp45_r5i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r5i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp45_r5i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r5i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC-ESM-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC-ESM",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC-ESM_rcp45_r1i1p1_200601-210012.nc", 
            "tas_Amon_MIROC-ESM_rcp45_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC-ESM_rcp45_r1i1p1_200601-210012.nc", 
            "pr_Amon_MIROC-ESM_rcp45_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
      gridfile.filename = "tas_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC-ESM-CHEM-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MIROC-ESM-CHEM",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC-ESM-CHEM_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC-ESM-CHEM_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
      gridfile.filename = "tas_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-LR-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      institute = "MPI-M",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-LR_rcp45_r1i1p1_200601-210012.nc", 
            "tas_Amon_MPI-ESM-LR_rcp45_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-LR_rcp45_r1i1p1_200601-210012.nc", 
            "pr_Amon_MPI-ESM-LR_rcp45_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-LR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-LR-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MPI-ESM-LR",
      gcm.run = 2,
      institute = "MPI-M",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-LR_rcp45_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-LR_rcp45_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-LR_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-LR-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MPI-ESM-LR",
      gcm.run = 3,
      institute = "MPI-M",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-LR_rcp45_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-LR_rcp45_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-LR_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-MR-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MPI-ESM-MR",
      gcm.run = 1,
      institute = "MPI-M",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-MR_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-MR_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-MR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-MR-r2i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MPI-ESM-MR",
      gcm.run = 2,
      institute = "MPI-M",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-MR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-MR_rcp45_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-MR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-MR_rcp45_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-MR_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-MR-r3i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MPI-ESM-MR",
      gcm.run = 3,
      institute = "MPI-M",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-MR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-MR_rcp45_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-MR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-MR_rcp45_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-MR_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MRI-CGCM3-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "MRI-CGCM3",
      gcm.run = 1,
      institute = "MRI",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MRI-CGCM3_rcp45_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MRI-CGCM3_rcp45_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
      gridfile.filename = "tas_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'NorESM1-M-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "NorESM1-M",
      gcm.run = 1,
      institute = "NCC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_NorESM1-M_rcp45_r1i1p1_200601-210012.nc", 
            "tas_Amon_NorESM1-M_rcp45_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_NorESM1-M_rcp45_r1i1p1_200601-210012.nc", 
            "pr_Amon_NorESM1-M_rcp45_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
      gridfile.filename = "tas_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'NorESM1-ME-r1i1p1_rcp45' = list( 
      rcm = "",
      gcm = "NorESM1-ME",
      gcm.run = 1,
      institute = "NCC",
      emission.scenario = "rcp45",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/rcp45"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/rcp45")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_NorESM1-ME_rcp45_r1i1p1_200601-210212.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_NorESM1-ME_rcp45_r1i1p1_200601-210212.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
      gridfile.filename = "tas_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
##     'CSIRO-Mk3L-1-2-r1i2p1_rcp45' = list( 
##       rcm = "",
##       gcm = "CSIRO-Mk3L-1-2",
##       gcm.run = 1,
##       institute = "CSIRO-QCCCE",
##       emission.scenario = "rcp45",
##       file.path.alt = list(
##         air_temperature =
##         list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/historical",
##              scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/rcp45"),
##         precipitation_amount =
##         list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/historical",
##              scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/rcp45")),
##       file.name = list(
##         air_temperature = list(
##           historical = c(
##             "tas_Amon_CSIRO-Mk3L-1-2_historical_r1i2p1_185101-200512.nc"
##             ),
##           scenario = c(
##             "tas_Amon_CSIRO-Mk3L-1-2_rcp45_r1i2p1_200601-230012.nc"
##             )),
##         precipitation_amount = list(
##           historical = c(
##             "pr_Amon_CSIRO-Mk3L-1-2_historical_r1i2p1_185101-200512.nc"
##             ),
##           scenario = c(
##             "pr_Amon_CSIRO-Mk3L-1-2_rcp45_r1i2p1_200601-230012.nc"
##            ))),
##       gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/historical",
##       gridfile.filename = "tas_Amon_CSIRO-Mk3L-1-2_historical_r1i2p1_185101-200512.nc",
##       resolution = "",
##       what.timesteps = "monthly"
##       ),

## ################################################################################
##     'CSIRO-Mk3L-1-2-r2i2p1_rcp45' = list( 
##       rcm = "",
##       gcm = "CSIRO-Mk3L-1-2",
##       gcm.run = 2,
##       institute = "CSIRO-QCCCE",
##       emission.scenario = "rcp45",
##       file.path.alt = list(
##         air_temperature =
##         list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/historical",
##              scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/rcp45"),
##         precipitation_amount =
##         list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/historical",
##              scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/rcp45")),
##       file.name = list(
##         air_temperature = list(
##           historical = c(
##             "tas_Amon_CSIRO-Mk3L-1-2_historical_r2i2p1_185101-200512.nc"
##             ),
##           scenario = c(
##             "tas_Amon_CSIRO-Mk3L-1-2_rcp45_r2i2p1_200601-230012.nc"
##             )),
##         precipitation_amount = list(
##           historical = c(
##             "pr_Amon_CSIRO-Mk3L-1-2_historical_r2i2p1_185101-200512.nc"
##             ),
##           scenario = c(
##             "pr_Amon_CSIRO-Mk3L-1-2_rcp45_r2i2p1_200601-230012.nc"
##            ))),
##       gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/historical",
##       gridfile.filename = "tas_Amon_CSIRO-Mk3L-1-2_historical_r2i2p1_185101-200512.nc",
##       resolution = "",
##       what.timesteps = "monthly"
##       ),

## ################################################################################
##     'CSIRO-Mk3L-1-2-r3i2p1_rcp45' = list( 
##       rcm = "",
##       gcm = "CSIRO-Mk3L-1-2",
##       gcm.run = 3,
##       institute = "CSIRO-QCCCE",
##       emission.scenario = "rcp45",
##       file.path.alt = list(
##         air_temperature =
##         list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/historical",
##              scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/rcp45"),
##         precipitation_amount =
##         list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/historical",
##              scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/rcp45")),
##       file.name = list(
##         air_temperature = list(
##           historical = c(
##             "tas_Amon_CSIRO-Mk3L-1-2_historical_r3i2p1_185101-200512.nc"
##             ),
##           scenario = c(
##             "tas_Amon_CSIRO-Mk3L-1-2_rcp45_r3i2p1_200601-230012.nc"
##             )),
##         precipitation_amount = list(
##           historical = c(
##             "pr_Amon_CSIRO-Mk3L-1-2_historical_r3i2p1_185101-200512.nc"
##             ),
##           scenario = c(
##             "pr_Amon_CSIRO-Mk3L-1-2_rcp45_r3i2p1_200601-230012.nc"
##            ))),
##       gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3L-1-2/historical",
##       gridfile.filename = "tas_Amon_CSIRO-Mk3L-1-2_historical_r3i2p1_185101-200512.nc",
##       resolution = "",
##       what.timesteps = "monthly"
##       ),
## acrnonyms: , 
##  ACCESS1-0-r1i1p1_rcp45, 
##  ACCESS1-3-r1i1p1_rcp45, 
##  BCC-CSM1-1-r1i1p1_rcp45, 
##  BCC-CSM1-1-m-r1i1p1_rcp45, 
##  BNU-ESM-r1i1p1_rcp45, 
##  CanCM4-r10i1p1_rcp45, 
##  CanCM4-r1i1p1_rcp45, 
##  CanCM4-r2i1p1_rcp45, 
##  CanCM4-r3i1p1_rcp45, 
##  CanCM4-r4i1p1_rcp45, 
##  CanCM4-r5i1p1_rcp45, 
##  CanCM4-r6i1p1_rcp45, 
##  CanCM4-r7i1p1_rcp45, 
##  CanCM4-r8i1p1_rcp45, 
##  CanCM4-r9i1p1_rcp45, 
##  CanESM2-r1i1p1_rcp45, 
##  CanESM2-r2i1p1_rcp45, 
##  CanESM2-r3i1p1_rcp45, 
##  CanESM2-r4i1p1_rcp45, 
##  CanESM2-r5i1p1_rcp45, 
##  CCSM4-r1i1p1_rcp45, 
##  CCSM4-r2i1p1_rcp45, 
##  CCSM4-r3i1p1_rcp45, 
##  CCSM4-r4i1p1_rcp45, 
##  CCSM4-r5i1p1_rcp45, 
##  CCSM4-r6i1p1_rcp45, 
##  CESM1-BGC-r1i1p1_rcp45, 
##  CESM1-CAM5-r1i1p1_rcp45, 
##  CESM1-CAM5-r2i1p1_rcp45, 
##  CESM1-CAM5-r3i1p1_rcp45, 
##  CESM1-WACCM-r2i1p1_rcp45, 
##  CESM1-WACCM-r3i1p1_rcp45, 
##  CESM1-WACCM-r4i1p1_rcp45, 
##  CMCC-CM-r1i1p1_rcp45, 
##  CMCC-CMS-r1i1p1_rcp45, 
##  CNRM-CM5-r1i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r10i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r1i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r2i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r3i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r4i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r5i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r6i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r7i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r8i1p1_rcp45, 
##  CSIRO-Mk3-6-0-r9i1p1_rcp45, 
##  EC-EARTH-r12i1p1_rcp45, 
##  EC-EARTH-r13i1p1_rcp45, 
##  EC-EARTH-r14i1p1_rcp45, 
##  EC-EARTH-r1i1p1_rcp45, 
##  EC-EARTH-r2i1p1_rcp45, 
##  EC-EARTH-r6i1p1_rcp45, 
##  EC-EARTH-r7i1p1_rcp45, 
##  EC-EARTH-r8i1p1_rcp45, 
##  EC-EARTH-r9i1p1_rcp45, 
##  FGOALS-g2-r1i1p1_rcp45, 
##  FIO-ESM-r1i1p1_rcp45, 
##  FIO-ESM-r2i1p1_rcp45, 
##  FIO-ESM-r3i1p1_rcp45, 
##  GFDL-CM2-1-r10i1p1_rcp45, 
##  GFDL-CM2-1-r1i1p1_rcp45, 
##  GFDL-CM2-1-r2i1p1_rcp45, 
##  GFDL-CM2-1-r3i1p1_rcp45, 
##  GFDL-CM2-1-r4i1p1_rcp45, 
##  GFDL-CM2-1-r5i1p1_rcp45, 
##  GFDL-CM2-1-r6i1p1_rcp45, 
##  GFDL-CM2-1-r7i1p1_rcp45, 
##  GFDL-CM2-1-r8i1p1_rcp45, 
##  GFDL-CM2-1-r9i1p1_rcp45, 
##  GFDL-CM3-r1i1p1_rcp45, 
##  GFDL-ESM2G-r1i1p1_rcp45, 
##  GFDL-ESM2M-r1i1p1_rcp45, 
##  GISS-E2-H-r1i1p1_rcp45, 
##  GISS-E2-H-r1i1p2_rcp45, 
##  GISS-E2-H-r1i1p3_rcp45, 
##  GISS-E2-H-r2i1p1_rcp45, 
##  GISS-E2-H-r2i1p2_rcp45, 
##  GISS-E2-H-r2i1p3_rcp45, 
##  GISS-E2-H-r3i1p1_rcp45, 
##  GISS-E2-H-r3i1p2_rcp45, 
##  GISS-E2-H-r3i1p3_rcp45, 
##  GISS-E2-H-r4i1p1_rcp45, 
##  GISS-E2-H-r4i1p2_rcp45, 
##  GISS-E2-H-r4i1p3_rcp45, 
##  GISS-E2-H-r5i1p1_rcp45, 
##  GISS-E2-H-r5i1p2_rcp45, 
##  GISS-E2-H-r5i1p3_rcp45, 
##  GISS-E2-H-r6i1p3_rcp45, 
##  GISS-E2-H-CC-r1i1p1_rcp45, 
##  GISS-E2-R-r1i1p1_rcp45, 
##  GISS-E2-R-r1i1p2_rcp45, 
##  GISS-E2-R-r1i1p3_rcp45, 
##  GISS-E2-R-r2i1p1_rcp45, 
##  GISS-E2-R-r2i1p2_rcp45, 
##  GISS-E2-R-r2i1p3_rcp45, 
##  GISS-E2-R-r3i1p1_rcp45, 
##  GISS-E2-R-r3i1p2_rcp45, 
##  GISS-E2-R-r3i1p3_rcp45, 
##  GISS-E2-R-r4i1p1_rcp45, 
##  GISS-E2-R-r4i1p2_rcp45, 
##  GISS-E2-R-r4i1p3_rcp45, 
##  GISS-E2-R-r5i1p1_rcp45, 
##  GISS-E2-R-r5i1p2_rcp45, 
##  GISS-E2-R-r5i1p3_rcp45, 
##  GISS-E2-R-r6i1p1_rcp45, 
##  GISS-E2-R-r6i1p3_rcp45, 
##  GISS-E2-R-CC-r1i1p1_rcp45, 
##  HadCM3-r10i1p1_rcp45, 
##  HadCM3-r1i1p1_rcp45, 
##  HadCM3-r2i1p1_rcp45, 
##  HadCM3-r3i1p1_rcp45, 
##  HadCM3-r4i1p1_rcp45, 
##  HadCM3-r5i1p1_rcp45, 
##  HadCM3-r6i1p1_rcp45, 
##  HadCM3-r7i1p1_rcp45, 
##  HadCM3-r8i1p1_rcp45, 
##  HadCM3-r9i1p1_rcp45, 
##  HadGEM2-AO-r1i1p1_rcp45, 
##  HadGEM2-CC-r1i1p1_rcp45, 
##  HadGEM2-ES-r1i1p1_rcp45, 
##  HadGEM2-ES-r2i1p1_rcp45, 
##  HadGEM2-ES-r3i1p1_rcp45, 
##  HadGEM2-ES-r4i1p1_rcp45, 
##  INM-CM4-r1i1p1_rcp45, 
##  IPSL-CM5A-LR-r1i1p1_rcp45, 
##  IPSL-CM5A-LR-r2i1p1_rcp45, 
##  IPSL-CM5A-LR-r3i1p1_rcp45, 
##  IPSL-CM5A-LR-r4i1p1_rcp45, 
##  IPSL-CM5A-MR-r1i1p1_rcp45, 
##  IPSL-CM5B-LR-r1i1p1_rcp45, 
##  MIROC4h-r1i1p1_rcp45, 
##  MIROC4h-r2i1p1_rcp45, 
##  MIROC4h-r3i1p1_rcp45, 
##  MIROC5-r1i1p1_rcp45, 
##  MIROC5-r2i1p1_rcp45, 
##  MIROC5-r3i1p1_rcp45, 
##  MIROC5-r4i1p1_rcp45, 
##  MIROC5-r5i1p1_rcp45, 
##  MIROC-ESM-r1i1p1_rcp45, 
##  MIROC-ESM-CHEM-r1i1p1_rcp45, 
##  MPI-ESM-LR-r1i1p1_rcp45, 
##  MPI-ESM-LR-r2i1p1_rcp45, 
##  MPI-ESM-LR-r3i1p1_rcp45, 
##  MPI-ESM-MR-r1i1p1_rcp45, 
##  MPI-ESM-MR-r2i1p1_rcp45, 
##  MPI-ESM-MR-r3i1p1_rcp45, 
##  MRI-CGCM3-r1i1p1_rcp45, 
##  NorESM1-M-r1i1p1_rcp45, 
##  NorESM1-ME-r1i1p1_rcp45, 
##  CSIRO-Mk3L-1-2-r1i2p1_rcp45, 
##  CSIRO-Mk3L-1-2-r2i2p1_rcp45, 
##  CSIRO-Mk3L-1-2-r3i2p1_rcp45
### ----------------------------------------------------------------------
### ************************** SCENARIO: RCP85 ***************************
### ----------------------------------------------------------------------

################################################################################
    'ACCESS1-0-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "ACCESS1-0",
      gcm.run = 1,
      institute = "CSIRO-BOM",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_ACCESS1-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_ACCESS1-0_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_ACCESS1-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_ACCESS1-0_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.0/historical",
      gridfile.filename = "tas_Amon_ACCESS1-0_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'ACCESS1-3-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "ACCESS1-3",
      gcm.run = 1,
      institute = "CSIRO-BOM",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_ACCESS1-3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_ACCESS1-3_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_ACCESS1-3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_ACCESS1-3_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/ACCESS1.3/historical",
      gridfile.filename = "tas_Amon_ACCESS1-3_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'BCC-CSM1-1-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "BCC-CSM1-1",
      gcm.run = 1,
      institute = "BCC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_bcc-csm1-1_rcp85_r1i1p1_200601-209912.nc", 
            "tas_Amon_bcc-csm1-1_rcp85_r1i1p1_210001-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_bcc-csm1-1_rcp85_r1i1p1_200601-209912.nc", 
            "pr_Amon_bcc-csm1-1_rcp85_r1i1p1_210001-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
      gridfile.filename = "tas_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'BCC-CSM1-1-m-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "BCC-CSM1-1-m",
      gcm.run = 1,
      institute = "BCC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_bcc-csm1-1-m_rcp85_r1i1p1_200601-209912.nc", 
            "tas_Amon_bcc-csm1-1-m_rcp85_r1i1p1_210001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_bcc-csm1-1-m_rcp85_r1i1p1_200601-209912.nc", 
            "pr_Amon_bcc-csm1-1-m_rcp85_r1i1p1_210001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
      gridfile.filename = "tas_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'BNU-ESM-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "BNU-ESM",
      gcm.run = 1,
      institute = "GCESS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_BNU-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_BNU-ESM_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_BNU-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_BNU-ESM_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/historical",
      gridfile.filename = "tas_Amon_BNU-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 1,
      institute = "CCCma",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 2,
      institute = "CCCma",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp85_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp85_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 3,
      institute = "CCCma",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp85_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp85_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r4i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 4,
      institute = "CCCma",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp85_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp85_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r5i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 5,
      institute = "CCCma",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp85_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp85_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 1,
      institute = "NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CCSM4_rcp85_r1i1p1_200601-210012.nc", 
            "tas_Amon_CCSM4_rcp85_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp85_r1i1p1_200601-210012.nc", 
            "pr_Amon_CCSM4_rcp85_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 2,
      institute = "NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp85_r2i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp85_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp85_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 3,
      institute = "NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp85_r3i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp85_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp85_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r4i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 4,
      institute = "NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp85_r4i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp85_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp85_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r5i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 5,
      institute = "NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp85_r5i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp85_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp85_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r6i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 6,
      institute = "NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CCSM4_rcp85_r6i1p1_200501-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp85_r6i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r6i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-BGC-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CESM1-BGC",
      gcm.run = 1,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-BGC_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-BGC_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-BGC_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-BGC_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(BGC)/historical",
      gridfile.filename = "tas_Amon_CESM1-BGC_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 1,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 2,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp85_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp85_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 3,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp85_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp85_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-WACCM-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CESM1-WACCM",
      gcm.run = 2,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-WACCM_historical_r2i1p1_195501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-WACCM_rcp85_r2i1p1_200601-209912.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-WACCM_historical_r2i1p1_195501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-WACCM_rcp85_r2i1p1_200601-209912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
      gridfile.filename = "tas_Amon_CESM1-WACCM_historical_r2i1p1_195501-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-WACCM-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CESM1-WACCM",
      gcm.run = 3,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-WACCM_historical_r3i1p1_195501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-WACCM_rcp85_r3i1p1_200601-205512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-WACCM_historical_r3i1p1_195501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-WACCM_rcp85_r3i1p1_200601-205512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
      gridfile.filename = "tas_Amon_CESM1-WACCM_historical_r3i1p1_195501-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-WACCM-r4i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CESM1-WACCM",
      gcm.run = 4,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-WACCM_historical_r4i1p1_195501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-WACCM_rcp85_r4i1p1_200601-205012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-WACCM_historical_r4i1p1_195501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-WACCM_rcp85_r4i1p1_200601-205012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(WACCM)/historical",
      gridfile.filename = "tas_Amon_CESM1-WACCM_historical_r4i1p1_195501-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CMCC-CESM-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CMCC-CESM",
      gcm.run = 1,
      institute = "CMCC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CESM/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CESM/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CMCC-CESM_historical_r1i1p1_185001-185412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_185501-185912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_186001-186412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_186501-186912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_187001-187412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_187501-187912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_188001-188412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_188501-188912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_189001-189412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_189501-189912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_190001-190412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_190501-190912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_191001-191412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_191501-191912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_192001-192412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_192501-192912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_193001-193412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_193501-193912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_194001-194412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_194501-194912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_195001-195412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_195501-195912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_196001-196412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_196501-196912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_197001-197412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_197501-197912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_198001-198412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_198501-198912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_199001-199412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_199501-199912.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_200001-200412.nc", 
            "tas_Amon_CMCC-CESM_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_200001-200412.nc", 
##            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_200501-200512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_200601-201512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_201601-202512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_202601-203512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_203601-204512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_204601-205512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_205601-206512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_206601-207512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_207601-208512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_208601-209512.nc", 
            "tas_Amon_CMCC-CESM_rcp85_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CMCC-CESM_historical_r1i1p1_185001-185412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_185501-185912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_186001-186412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_186501-186912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_187001-187412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_187501-187912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_188001-188412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_188501-188912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_189001-189412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_189501-189912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_190001-190412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_190501-190912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_191001-191412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_191501-191912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_192001-192412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_192501-192912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_193001-193412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_193501-193912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_194001-194412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_194501-194912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_195001-195412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_195501-195912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_196001-196412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_196501-196912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_197001-197412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_197501-197912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_198001-198412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_198501-198912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_199001-199412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_199501-199912.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_200001-200412.nc", 
            "pr_Amon_CMCC-CESM_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
##            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_200001-200412.nc", 
##            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_200501-200512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_200601-201512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_201601-202512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_202601-203512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_203601-204512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_204601-205512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_205601-206512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_206601-207512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_207601-208512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_208601-209512.nc", 
            "pr_Amon_CMCC-CESM_rcp85_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CESM/historical",
      gridfile.filename = "tas_Amon_CMCC-CESM_historical_r1i1p1_185001-185412.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CMCC-CM-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CMCC-CM",
      gcm.run = 1,
      institute = "CMCC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CMCC-CM_historical_r1i1p1_185001-185912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_186001-186912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_187001-187912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_188001-188912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_189001-189912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_190001-190912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_191001-191912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_192001-192912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_193001-193912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_194001-194912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_195001-195912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_196001-196912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_197001-197912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_198001-198912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_199001-199912.nc", 
            "tas_Amon_CMCC-CM_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_200601-201012.nc", 
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_201101-202012.nc", 
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_202101-203012.nc", 
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_203101-204012.nc", 
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_204101-205012.nc", 
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_205101-206012.nc", 
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_206101-207012.nc", 
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_207101-208012.nc", 
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_208101-209012.nc", 
            "tas_Amon_CMCC-CM_rcp85_r1i1p1_209101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CMCC-CM_historical_r1i1p1_185001-185912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_186001-186912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_187001-187912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_188001-188912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_189001-189912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_190001-190912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_191001-191912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_192001-192912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_193001-193912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_194001-194912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_195001-195912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_196001-196912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_197001-197912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_198001-198912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_199001-199912.nc", 
            "pr_Amon_CMCC-CM_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_200601-201012.nc", 
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_201101-202012.nc", 
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_202101-203012.nc", 
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_203101-204012.nc", 
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_204101-205012.nc", 
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_205101-206012.nc", 
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_206101-207012.nc", 
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_207101-208012.nc", 
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_208101-209012.nc", 
            "pr_Amon_CMCC-CM_rcp85_r1i1p1_209101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CM/historical",
      gridfile.filename = "tas_Amon_CMCC-CM_historical_r1i1p1_185001-185912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CMCC-CMS-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CMCC-CMS",
      gcm.run = 1,
      institute = "CMCC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CMCC-CMS_historical_r1i1p1_185001-185912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_186001-186912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_187001-187912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_188001-188912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_189001-189912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_190001-190912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_191001-191912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_192001-192912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_193001-193912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_194001-194912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_195001-195912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_196001-196912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_197001-197912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_198001-198912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_199001-199912.nc", 
            "tas_Amon_CMCC-CMS_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_200601-200912.nc", 
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_201001-201912.nc", 
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_202001-202912.nc", 
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_203001-203912.nc", 
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_204001-204912.nc", 
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_205001-205912.nc", 
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_206001-206912.nc", 
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_207001-207912.nc", 
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_208001-208912.nc", 
            "tas_Amon_CMCC-CMS_rcp85_r1i1p1_209001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CMCC-CMS_historical_r1i1p1_185001-185912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_186001-186912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_187001-187912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_188001-188912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_189001-189912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_190001-190912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_191001-191912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_192001-192912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_193001-193912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_194001-194912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_195001-195912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_196001-196912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_197001-197912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_198001-198912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_199001-199912.nc", 
            "pr_Amon_CMCC-CMS_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_200601-200912.nc", 
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_201001-201912.nc", 
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_202001-202912.nc", 
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_203001-203912.nc", 
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_204001-204912.nc", 
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_205001-205912.nc", 
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_206001-206912.nc", 
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_207001-207912.nc", 
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_208001-208912.nc", 
            "pr_Amon_CMCC-CMS_rcp85_r1i1p1_209001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CMCC-CMS/historical",
      gridfile.filename = "tas_Amon_CMCC-CMS_historical_r1i1p1_185001-185912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CNRM-CM5-r10i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CNRM-CM5",
      gcm.run = 10,
      institute = "CNRM-CERFACS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CNRM-CM5_historical_r10i1p1_185001-189912.nc", 
            "tas_Amon_CNRM-CM5_historical_r10i1p1_190001-194912.nc", 
            "tas_Amon_CNRM-CM5_historical_r10i1p1_195001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CNRM-CM5_rcp85_r10i1p1_200601-205512.nc", 
            "tas_Amon_CNRM-CM5_rcp85_r10i1p1_205601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CNRM-CM5_historical_r10i1p1_185001-189912.nc", 
            "pr_Amon_CNRM-CM5_historical_r10i1p1_190001-194912.nc", 
            "pr_Amon_CNRM-CM5_historical_r10i1p1_195001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CNRM-CM5_rcp85_r10i1p1_200601-205512.nc", 
            "pr_Amon_CNRM-CM5_rcp85_r10i1p1_205601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
      gridfile.filename = "tas_Amon_CNRM-CM5_historical_r10i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CNRM-CM5-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CNRM-CM5",
      gcm.run = 1,
      institute = "CNRM-CERFACS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CNRM-CM5_historical_r1i1p1_185001-189912.nc", 
            "tas_Amon_CNRM-CM5_historical_r1i1p1_190001-194912.nc", 
            "tas_Amon_CNRM-CM5_historical_r1i1p1_195001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CNRM-CM5_rcp85_r1i1p1_200601-205512.nc", 
            "tas_Amon_CNRM-CM5_rcp85_r1i1p1_205601-210012.nc", 
            "tas_Amon_CNRM-CM5_rcp85_r1i1p1_210101-215012.nc", 
            "tas_Amon_CNRM-CM5_rcp85_r1i1p1_215101-220012.nc", 
            "tas_Amon_CNRM-CM5_rcp85_r1i1p1_220101-225012.nc", 
            "tas_Amon_CNRM-CM5_rcp85_r1i1p1_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CNRM-CM5_historical_r1i1p1_185001-189912.nc", 
            "pr_Amon_CNRM-CM5_historical_r1i1p1_190001-194912.nc", 
            "pr_Amon_CNRM-CM5_historical_r1i1p1_195001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CNRM-CM5_rcp85_r1i1p1_200601-205512.nc", 
            "pr_Amon_CNRM-CM5_rcp85_r1i1p1_205601-210012.nc", 
            "pr_Amon_CNRM-CM5_rcp85_r1i1p1_210101-215012.nc", 
            "pr_Amon_CNRM-CM5_rcp85_r1i1p1_215101-220012.nc", 
            "pr_Amon_CNRM-CM5_rcp85_r1i1p1_220101-225012.nc", 
            "pr_Amon_CNRM-CM5_rcp85_r1i1p1_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
      gridfile.filename = "tas_Amon_CNRM-CM5_historical_r1i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CNRM-CM5-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CNRM-CM5",
      gcm.run = 2,
      institute = "CNRM-CERFACS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CNRM-CM5_historical_r2i1p1_185001-189912.nc", 
            "tas_Amon_CNRM-CM5_historical_r2i1p1_190001-194912.nc", 
            "tas_Amon_CNRM-CM5_historical_r2i1p1_195001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CNRM-CM5_rcp85_r2i1p1_200601-205512.nc", 
            "tas_Amon_CNRM-CM5_rcp85_r2i1p1_205601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CNRM-CM5_historical_r2i1p1_185001-189912.nc", 
            "pr_Amon_CNRM-CM5_historical_r2i1p1_190001-194912.nc", 
            "pr_Amon_CNRM-CM5_historical_r2i1p1_195001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CNRM-CM5_rcp85_r2i1p1_200601-205512.nc", 
            "pr_Amon_CNRM-CM5_rcp85_r2i1p1_205601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
      gridfile.filename = "tas_Amon_CNRM-CM5_historical_r2i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CNRM-CM5-r4i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CNRM-CM5",
      gcm.run = 4,
      institute = "CNRM-CERFACS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CNRM-CM5_historical_r4i1p1_185001-189912.nc", 
            "tas_Amon_CNRM-CM5_historical_r4i1p1_190001-194912.nc", 
            "tas_Amon_CNRM-CM5_historical_r4i1p1_195001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CNRM-CM5_rcp85_r4i1p1_200601-205512.nc", 
            "tas_Amon_CNRM-CM5_rcp85_r4i1p1_205601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CNRM-CM5_historical_r4i1p1_185001-189912.nc", 
            "pr_Amon_CNRM-CM5_historical_r4i1p1_190001-194912.nc", 
            "pr_Amon_CNRM-CM5_historical_r4i1p1_195001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CNRM-CM5_rcp85_r4i1p1_200601-205512.nc", 
            "pr_Amon_CNRM-CM5_rcp85_r4i1p1_205601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
      gridfile.filename = "tas_Amon_CNRM-CM5_historical_r4i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CNRM-CM5-r6i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CNRM-CM5",
      gcm.run = 6,
      institute = "CNRM-CERFACS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CNRM-CM5_historical_r6i1p1_185001-189912.nc", 
            "tas_Amon_CNRM-CM5_historical_r6i1p1_190001-194912.nc", 
            "tas_Amon_CNRM-CM5_historical_r6i1p1_195001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CNRM-CM5_rcp85_r6i1p1_200601-205512.nc", 
            "tas_Amon_CNRM-CM5_rcp85_r6i1p1_205601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CNRM-CM5_historical_r6i1p1_185001-189912.nc", 
            "pr_Amon_CNRM-CM5_historical_r6i1p1_190001-194912.nc", 
            "pr_Amon_CNRM-CM5_historical_r6i1p1_195001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CNRM-CM5_rcp85_r6i1p1_200601-205512.nc", 
            "pr_Amon_CNRM-CM5_rcp85_r6i1p1_205601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
      gridfile.filename = "tas_Amon_CNRM-CM5_historical_r6i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r10i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 10,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r10i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r10i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 1,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r1i1p1_200601-210012.nc", 
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r1i1p1_200601-210012.nc", 
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 2,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r2i1p1_200601-210012.nc", 
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r2i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r2i1p1_200601-210012.nc", 
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r2i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 3,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r3i1p1_200601-210012.nc", 
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r3i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r3i1p1_200601-210012.nc", 
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r3i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r4i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 4,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r5i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 5,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r6i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 6,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r6i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r6i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r7i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 7,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r7i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r7i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r8i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 8,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r8i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r8i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r9i1p1_rcp85' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 9,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp85_r9i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp85_r9i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r12i1p1_rcp85' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 12,
      institute = "EC-EARTH",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r12i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r12i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r12i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp85_r12i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r12i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r12i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r12i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp85_r12i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r12i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r13i1p1_rcp85' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 13,
      institute = "EC-EARTH",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r13i1p1_195001-195912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_196001-196912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_197001-197912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_198001-198912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_199001-199912.nc", 
            "tas_Amon_EC-EARTH_historical_r13i1p1_200001-200911.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_200601-200912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_201001-201912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_202001-202912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_203001-203912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_204001-204912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_205001-205912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_206001-206912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_207001-207912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_208001-208912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_209001-209912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r13i1p1_210001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r13i1p1_195001-195912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_196001-196912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_197001-197912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_198001-198912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_199001-199912.nc", 
            "pr_Amon_EC-EARTH_historical_r13i1p1_200001-200911.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_200601-200912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_201001-201912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_202001-202912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_203001-203912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_204001-204912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_205001-205912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_206001-206912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_207001-207912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_208001-208912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_209001-209912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r13i1p1_210001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r13i1p1_195001-195912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r14i1p1_rcp85' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 14,
      institute = "EC-EARTH",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r14i1p1_195001-195912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_196001-196912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_197001-197912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_198001-198912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_199001-199912.nc", 
            "tas_Amon_EC-EARTH_historical_r14i1p1_200001-200911.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_200601-200912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_201001-201912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_202001-202912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_203001-203912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_204001-204912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_205001-205912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_206001-206912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_207001-207912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_208001-208912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_209001-209912.nc", 
            "tas_Amon_EC-EARTH_rcp85_r14i1p1_210001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r14i1p1_195001-195912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_196001-196912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_197001-197912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_198001-198912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_199001-199912.nc", 
            "pr_Amon_EC-EARTH_historical_r14i1p1_200001-200911.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_200601-200912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_201001-201912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_202001-202912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_203001-203912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_204001-204912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_205001-205912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_206001-206912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_207001-207912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_208001-208912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_209001-209912.nc", 
            "pr_Amon_EC-EARTH_rcp85_r14i1p1_210001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r14i1p1_195001-195912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    ## 'EC-EARTH-r1i1p1_rcp85' = list( 
    ##   rcm = "",
    ##   gcm = "EC-EARTH",
    ##   gcm.run = 1,
    ##   institute = "EC-EARTH",
    ##   emission.scenario = "rcp85",
    ##   file.path.alt = list(
    ##     air_temperature =
    ##     list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
    ##          scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85"),
    ##     precipitation_amount =
    ##     list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
    ##          scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c(
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_185001-185912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_186001-186912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_187001-187912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_188001-188912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_189001-189912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_190001-190912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_191001-191912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_192001-192912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_193001-193912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_194001-194912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_195001-195912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_196001-196912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_197001-197912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_198001-198912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_199001-199912.nc", 
    ##         "tas_Amon_EC-EARTH_historical_r1i1p1_200001-200911.nc"
    ##         ),
    ##       scenario = c(
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_200601-200912.nc", 
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_201001-201912.nc", 
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_202001-202912.nc", 
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_203001-203912.nc", 
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_204001-204912.nc", 
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_205001-205912.nc", 
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_206001-206912.nc", 
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_207001-207912.nc", 
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_208001-208912.nc", 
    ##         "tas_Amon_EC-EARTH_rcp85_r1i1p1_209001-209912.nc"
    ##         )),
    ##     precipitation_amount = list(
    ##       historical = c(
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_185001-185912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_186001-186912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_187001-187912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_188001-188912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_189001-189912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_190001-190912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_191001-191912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_192001-192912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_193001-193912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_194001-194912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_195001-195912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_196001-196912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_197001-197912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_198001-198912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_199001-199912.nc", 
    ##         "pr_Amon_EC-EARTH_historical_r1i1p1_200001-200912.nc"
    ##         ),
    ##       scenario = c(
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_200601-200912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_201001-201912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_202001-202912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_203001-203912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_204001-204912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_205001-205912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_206001-206912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_207001-207912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_208001-208912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_209001-209912.nc", 
    ##         "pr_Amon_EC-EARTH_rcp85_r1i1p1_210001-210012.nc"
    ##        ))),
    ##   gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
    ##   gridfile.filename = "tas_Amon_EC-EARTH_historical_r1i1p1_185001-185912.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),

################################################################################
    'EC-EARTH-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 2,
      institute = "EC-EARTH",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r2i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r2i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r2i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp85_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r2i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r2i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r2i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp85_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r2i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r6i1p1_rcp85' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 6,
      institute = "EC-EARTH",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r6i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r6i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r6i1p1_195001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp85_r6i1p1_200601-205012.nc", 
            "tas_Amon_EC-EARTH_rcp85_r6i1p1_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r6i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r6i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r6i1p1_195001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp85_r6i1p1_200601-205012.nc", 
            "pr_Amon_EC-EARTH_rcp85_r6i1p1_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r6i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r8i1p1_rcp85' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 8,
      institute = "EC-EARTH",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r8i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r8i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r8i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp85_r8i1p1_200601-205012.nc", 
            "tas_Amon_EC-EARTH_rcp85_r8i1p1_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r8i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r8i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r8i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp85_r8i1p1_200601-205012.nc", 
            "pr_Amon_EC-EARTH_rcp85_r8i1p1_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r8i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r9i1p1_rcp85' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 9,
      institute = "EC-EARTH",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r9i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r9i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r9i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp85_r9i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r9i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r9i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r9i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp85_r9i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r9i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FGOALS-g2-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "FGOALS-g2",
      gcm.run = 1,
      institute = "LASG-CESS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FGOALS-g2_historical_r1i1p1_185001-185912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_186001-186912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_187001-187912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_188001-188912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_189001-189912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_190001-190912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_191001-191912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_192001-192912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_193001-193912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_194001-194912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_195001-195912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_196001-196912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_197001-197912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_198001-198912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_199001-199912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_200601-201512.nc", 
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_201601-202512.nc", 
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_202601-203512.nc", 
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_203601-204512.nc", 
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_204601-205512.nc", 
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_205601-206512.nc", 
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_206601-207512.nc", 
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_207601-208512.nc", 
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_208601-209512.nc", 
            "tas_Amon_FGOALS-g2_rcp85_r1i1p1_209601-210112.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FGOALS-g2_historical_r1i1p1_185001-185912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_186001-186912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_187001-187912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_188001-188912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_189001-189912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_190001-190912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_191001-191912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_192001-192912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_193001-193912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_194001-194912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_195001-195912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_196001-196912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_197001-197912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_198001-198912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_199001-199912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_200601-201512.nc", 
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_201601-202512.nc", 
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_202601-203512.nc", 
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_203601-204512.nc", 
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_204601-205512.nc", 
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_205601-206512.nc", 
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_206601-207512.nc", 
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_207601-208512.nc", 
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_208601-209512.nc", 
            "pr_Amon_FGOALS-g2_rcp85_r1i1p1_209601-210112.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/historical",
      gridfile.filename = "tas_Amon_FGOALS-g2_historical_r1i1p1_185001-185912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 1,
      institute = "FIO",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 2,
      institute = "FIO",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp85_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp85_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 3,
      institute = "FIO",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp85_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp85_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM3-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "GFDL-CM3",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_186501-186912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_187001-187412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_187501-187912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_188001-188412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_188501-188912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_189001-189412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_189501-189912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_190001-190412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_190501-190912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_191001-191412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_191501-191912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_192001-192412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_192501-192912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_193001-193412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_193501-193912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_194001-194412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_194501-194912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_195001-195412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_195501-195912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_196001-196412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_196501-196912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_197001-197412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_197501-197912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_198001-198412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_198501-198912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_199001-199412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_199501-199912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_200001-200412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-CM3_rcp85_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_186501-186912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_187001-187412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_187501-187912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_188001-188412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_188501-188912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_189001-189412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_189501-189912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_190001-190412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_190501-190912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_191001-191412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_191501-191912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_192001-192412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_192501-192912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_193001-193412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_193501-193912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_194001-194412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_194501-194912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_195001-195412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_195501-195912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_196001-196412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_196501-196912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_197001-197412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_197501-197912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_198001-198412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_198501-198912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_199001-199412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_199501-199912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_200001-200412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-CM3_rcp85_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
      gridfile.filename = "tas_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-ESM2G-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "GFDL-ESM2G",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp85_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp85_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
      gridfile.filename = "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-ESM2M-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "GFDL-ESM2M",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_209601-210012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_210101-210512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_210601-211012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_211101-211512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_211601-212012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_212101-212512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_212601-213012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_213101-213512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_213601-214012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_214101-214512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_214601-215012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_215101-215512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_215601-216012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_216101-216512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_216601-217012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_217101-217512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_217601-218012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_218101-218512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_218601-219012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_219101-219512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp85_r1i1p1_219601-220012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp85_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
      gridfile.filename = "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p1_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp85_r1i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p1_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p1_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p1_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p1_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p1_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p1_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp85_r1i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p1_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p1_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p1_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p1_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p1_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p2_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p2_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp85_r1i1p2_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p2_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p2_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p2_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p2_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p2_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p2_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp85_r1i1p2_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p2_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p2_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p2_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p2_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p2_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p3_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p3_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp85_r1i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p3_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p3_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p3_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p3_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r1i1p3_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p3_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp85_r1i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p3_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p3_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p3_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p3_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r1i1p3_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r2i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r2i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r2i1p1_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp85_r2i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r2i1p1_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r2i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r2i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r2i1p1_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp85_r2i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r2i1p1_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r2i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r2i1p3_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r2i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r2i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r2i1p3_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp85_r2i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp85_r2i1p3_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r2i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r2i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r2i1p3_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp85_r2i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp85_r2i1p3_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r2i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-CC-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-H-CC",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H-CC_historical_r1i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H-CC_historical_r1i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H-CC_historical_r1i1p1_195101-201012.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H-CC_rcp85_r1i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H-CC_rcp85_r1i1p1_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H-CC_historical_r1i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H-CC_historical_r1i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H-CC_historical_r1i1p1_195101-201012.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H-CC_rcp85_r1i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H-CC_rcp85_r1i1p1_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H-CC/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H-CC_historical_r1i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p1_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p1_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p2_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p2_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p2_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p3_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r1i1p3_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r1i1p3_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r2i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp85_r2i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r2i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r2i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r2i1p1_207601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r2i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp85_r2i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r2i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r2i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r2i1p1_207601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r2i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r2i1p3_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 2,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r2i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r2i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp85_r2i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r2i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r2i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp85_r2i1p3_207601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r2i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r2i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp85_r2i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r2i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r2i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp85_r2i1p3_207601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r2i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-CC-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "GISS-E2-R-CC",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_200101-201012.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R-CC_rcp85_r1i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R-CC_rcp85_r1i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R-CC_rcp85_r1i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R-CC_rcp85_r1i1p1_207601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R-CC_historical_r1i1p1_200101-201012.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R-CC_rcp85_r1i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R-CC_rcp85_r1i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R-CC_rcp85_r1i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R-CC_rcp85_r1i1p1_207601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R-CC/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R-CC_historical_r1i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-AO-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "HadGEM2-AO",
      gcm.run = 1,
      institute = "NIMR/KMA",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_HadGEM2-AO_rcp85_r1i1p1_200601-209912.nc", 
            "tas_Amon_HadGEM2-AO_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc"
            ),
          scenario = c(
##            "pr_Amon_HadGEM2-AO_rcp85_r1i1p1_200601-209912.nc", 
            "pr_Amon_HadGEM2-AO_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
      gridfile.filename = "tas_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-CC-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "HadGEM2-CC",
      gcm.run = 1,
      institute = "MOHC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-CC_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-CC_rcp85_r1i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r1i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r1i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r1i1p1_208012-209912.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r1i1p1_210001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-CC_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-CC_rcp85_r1i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r1i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r1i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r1i1p1_208012-209912.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r1i1p1_210001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
      gridfile.filename = "tas_Amon_HadGEM2-CC_historical_r1i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-CC-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "HadGEM2-CC",
      gcm.run = 2,
      institute = "MOHC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-CC_historical_r2i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-CC_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-CC_rcp85_r2i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r2i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r2i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r2i1p1_208012-209912.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-CC_historical_r2i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-CC_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-CC_rcp85_r2i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r2i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r2i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r2i1p1_208012-209912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
      gridfile.filename = "tas_Amon_HadGEM2-CC_historical_r2i1p1_195912-198411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-CC-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "HadGEM2-CC",
      gcm.run = 3,
      institute = "MOHC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-CC_historical_r3i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-CC_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-CC_rcp85_r3i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r3i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r3i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-CC_rcp85_r3i1p1_208012-209912.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-CC_historical_r3i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-CC_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-CC_rcp85_r3i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r3i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r3i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-CC_rcp85_r3i1p1_208012-209912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-CC/historical",
      gridfile.filename = "tas_Amon_HadGEM2-CC_historical_r3i1p1_195912-198411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 1,
      institute = "MOHC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_208012-209911.nc", 
            ## "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_208012-209912.nc", file too much...
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_209912-212411.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_212412-214911.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_214912-217411.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_217412-219911.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_219912-222411.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_222412-224911.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_224912-227411.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_227412-229911.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r1i1p1_229912-229912.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_208012-209911.nc", 
            ## "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_208012-209912.nc", file too much...
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_209912-212411.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_212412-214911.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_214912-217411.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_217412-219911.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_219912-222411.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_222412-224911.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_224912-227411.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_227412-229911.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r1i1p1_229912-229912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 2,
      institute = "MOHC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp85_r2i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r2i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r2i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r2i1p1_208012-210011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r2i1p1_210012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp85_r2i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r2i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r2i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r2i1p1_208012-210011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r2i1p1_210012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 3,
      institute = "MOHC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp85_r3i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r3i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r3i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r3i1p1_208012-210011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r3i1p1_210012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp85_r3i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r3i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r3i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r3i1p1_208012-210011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r3i1p1_210012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r4i1p1_rcp85' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 4,
      institute = "MOHC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp85_r4i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r4i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r4i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r4i1p1_208012-210011.nc", 
            "tas_Amon_HadGEM2-ES_rcp85_r4i1p1_210012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp85_r4i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r4i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r4i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r4i1p1_208012-210011.nc", 
            "pr_Amon_HadGEM2-ES_rcp85_r4i1p1_210012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'INM-CM4-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "INM-CM4",
      gcm.run = 1,
      institute = "INM",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_inmcm4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_inmcm4_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_inmcm4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_inmcm4_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/INM-CM4/historical",
      gridfile.filename = "tas_Amon_inmcm4_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp85_r1i1p1_200601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp85_r1i1p1_200601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 2,
      institute = "IPSL",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp85_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp85_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 3,
      institute = "IPSL",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp85_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp85_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r4i1p1_rcp85' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 4,
      institute = "IPSL",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp85_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp85_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-MR-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-MR_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-MR_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5B-LR-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "IPSL-CM5B-LR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5B-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5B-LR_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5B-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5B-LR_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5B-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5B-LR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 2,
      institute = "MIROC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r2i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp85_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r2i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp85_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r2i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 3,
      institute = "MIROC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r3i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp85_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r3i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp85_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r3i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r4i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 4,
      institute = "MIROC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r4i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp85_r4i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r4i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp85_r4i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r4i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r5i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 5,
      institute = "MIROC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r5i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp85_r5i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r5i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp85_r5i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r5i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC-ESM-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MIROC-ESM",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC-ESM_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC-ESM_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
      gridfile.filename = "tas_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC-ESM-CHEM-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MIROC-ESM-CHEM",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC-ESM-CHEM_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC-ESM-CHEM_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
      gridfile.filename = "tas_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-LR-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      institute = "MPI-M",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-LR_rcp85_r1i1p1_200601-210012.nc", 
            "tas_Amon_MPI-ESM-LR_rcp85_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-LR_rcp85_r1i1p1_200601-210012.nc", 
            "pr_Amon_MPI-ESM-LR_rcp85_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-LR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-LR-r2i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MPI-ESM-LR",
      gcm.run = 2,
      institute = "MPI-M",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-LR_rcp85_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-LR_rcp85_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-LR_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-LR-r3i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MPI-ESM-LR",
      gcm.run = 3,
      institute = "MPI-M",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-LR_rcp85_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-LR_rcp85_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-LR_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-MR-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MPI-ESM-MR",
      gcm.run = 1,
      institute = "MPI-M",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-MR_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-MR_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-MR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MRI-CGCM3-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MRI-CGCM3",
      gcm.run = 1,
      institute = "MRI",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MRI-CGCM3_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MRI-CGCM3_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
      gridfile.filename = "tas_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'NorESM1-M-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "NorESM1-M",
      gcm.run = 1,
      institute = "NCC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_NorESM1-M_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_NorESM1-M_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
      gridfile.filename = "tas_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'NorESM1-ME-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "NorESM1-ME",
      gcm.run = 1,
      institute = "NCC",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_NorESM1-ME_rcp85_r1i1p1_200601-204412.nc", 
            "tas_Amon_NorESM1-ME_rcp85_r1i1p1_204501-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_NorESM1-ME_rcp85_r1i1p1_200601-204412.nc", 
            "pr_Amon_NorESM1-ME_rcp85_r1i1p1_204501-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
      gridfile.filename = "tas_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MRI-ESM1-r1i1p1_rcp85' = list( 
      rcm = "",
      gcm = "MRI-ESM1",
      gcm.run = 1,
      institute = "MRI",
      emission.scenario = "rcp85",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-ESM1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-ESM1/rcp85"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-ESM1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-ESM1/rcp85")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MRI-ESM1_historical_r1i1p1_185101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MRI-ESM1_rcp85_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MRI-ESM1_historical_r1i1p1_185101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MRI-ESM1_rcp85_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-ESM1/historical",
      gridfile.filename = "tas_Amon_MRI-ESM1_historical_r1i1p1_185101-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),
## acrnonyms: , 
##  ACCESS1-0-r1i1p1_rcp85, 
##  ACCESS1-3-r1i1p1_rcp85, 
##  BCC-CSM1-1-r1i1p1_rcp85, 
##  BCC-CSM1-1-m-r1i1p1_rcp85, 
##  BNU-ESM-r1i1p1_rcp85, 
##  CanESM2-r1i1p1_rcp85, 
##  CanESM2-r2i1p1_rcp85, 
##  CanESM2-r3i1p1_rcp85, 
##  CanESM2-r4i1p1_rcp85, 
##  CanESM2-r5i1p1_rcp85, 
##  CCSM4-r1i1p1_rcp85, 
##  CCSM4-r2i1p1_rcp85, 
##  CCSM4-r3i1p1_rcp85, 
##  CCSM4-r4i1p1_rcp85, 
##  CCSM4-r5i1p1_rcp85, 
##  CCSM4-r6i1p1_rcp85, 
##  CESM1-BGC-r1i1p1_rcp85, 
##  CESM1-CAM5-r1i1p1_rcp85, 
##  CESM1-CAM5-r2i1p1_rcp85, 
##  CESM1-CAM5-r3i1p1_rcp85, 
##  CESM1-WACCM-r2i1p1_rcp85, 
##  CESM1-WACCM-r3i1p1_rcp85, 
##  CESM1-WACCM-r4i1p1_rcp85, 
##  CMCC-CESM-r1i1p1_rcp85, 
##  CMCC-CM-r1i1p1_rcp85, 
##  CMCC-CMS-r1i1p1_rcp85, 
##  CNRM-CM5-r10i1p1_rcp85, 
##  CNRM-CM5-r1i1p1_rcp85, 
##  CNRM-CM5-r2i1p1_rcp85, 
##  CNRM-CM5-r4i1p1_rcp85, 
##  CNRM-CM5-r6i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r10i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r1i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r2i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r3i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r4i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r5i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r6i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r7i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r8i1p1_rcp85, 
##  CSIRO-Mk3-6-0-r9i1p1_rcp85, 
##  EC-EARTH-r12i1p1_rcp85, 
##  EC-EARTH-r13i1p1_rcp85, 
##  EC-EARTH-r14i1p1_rcp85, 
##  EC-EARTH-r1i1p1_rcp85, 
##  EC-EARTH-r2i1p1_rcp85, 
##  EC-EARTH-r6i1p1_rcp85, 
##  EC-EARTH-r8i1p1_rcp85, 
##  EC-EARTH-r9i1p1_rcp85, 
##  FGOALS-g2-r1i1p1_rcp85, 
##  FIO-ESM-r1i1p1_rcp85, 
##  FIO-ESM-r2i1p1_rcp85, 
##  FIO-ESM-r3i1p1_rcp85, 
##  GFDL-CM3-r1i1p1_rcp85, 
##  GFDL-ESM2G-r1i1p1_rcp85, 
##  GFDL-ESM2M-r1i1p1_rcp85, 
##  GISS-E2-H-r1i1p1_rcp85, 
##  GISS-E2-H-r1i1p2_rcp85, 
##  GISS-E2-H-r1i1p3_rcp85, 
##  GISS-E2-H-r2i1p1_rcp85, 
##  GISS-E2-H-r2i1p3_rcp85, 
##  GISS-E2-H-CC-r1i1p1_rcp85, 
##  GISS-E2-R-r1i1p1_rcp85, 
##  GISS-E2-R-r1i1p2_rcp85, 
##  GISS-E2-R-r1i1p3_rcp85, 
##  GISS-E2-R-r2i1p1_rcp85, 
##  GISS-E2-R-r2i1p3_rcp85, 
##  GISS-E2-R-CC-r1i1p1_rcp85, 
##  HadGEM2-AO-r1i1p1_rcp85, 
##  HadGEM2-CC-r1i1p1_rcp85, 
##  HadGEM2-CC-r2i1p1_rcp85, 
##  HadGEM2-CC-r3i1p1_rcp85, 
##  HadGEM2-ES-r1i1p1_rcp85, 
##  HadGEM2-ES-r2i1p1_rcp85, 
##  HadGEM2-ES-r3i1p1_rcp85, 
##  HadGEM2-ES-r4i1p1_rcp85, 
##  INM-CM4-r1i1p1_rcp85, 
##  IPSL-CM5A-LR-r1i1p1_rcp85, 
##  IPSL-CM5A-LR-r2i1p1_rcp85, 
##  IPSL-CM5A-LR-r3i1p1_rcp85, 
##  IPSL-CM5A-LR-r4i1p1_rcp85, 
##  IPSL-CM5A-MR-r1i1p1_rcp85, 
##  IPSL-CM5B-LR-r1i1p1_rcp85, 
##  MIROC5-r1i1p1_rcp85, 
##  MIROC5-r2i1p1_rcp85, 
##  MIROC5-r3i1p1_rcp85, 
##  MIROC5-r4i1p1_rcp85, 
##  MIROC5-r5i1p1_rcp85, 
##  MIROC-ESM-r1i1p1_rcp85, 
##  MIROC-ESM-CHEM-r1i1p1_rcp85, 
##  MPI-ESM-LR-r1i1p1_rcp85, 
##  MPI-ESM-LR-r2i1p1_rcp85, 
##  MPI-ESM-LR-r3i1p1_rcp85, 
##  MPI-ESM-MR-r1i1p1_rcp85, 
##  MRI-CGCM3-r1i1p1_rcp85, 
##  NorESM1-M-r1i1p1_rcp85, 
##  NorESM1-ME-r1i1p1_rcp85, 
##  MRI-ESM1-r1i1p1_rcp85
### ----------------------------------------------------------------------
### ************************** SCENARIO: RCP26 ***************************
### ----------------------------------------------------------------------

################################################################################
    'BCC-CSM1-1-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "BCC-CSM1-1",
      gcm.run = 1,
      institute = "BCC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_bcc-csm1-1_rcp26_r1i1p1_200601-209912.nc", 
            "tas_Amon_bcc-csm1-1_rcp26_r1i1p1_210001-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_bcc-csm1-1_rcp26_r1i1p1_200601-209912.nc", 
            "pr_Amon_bcc-csm1-1_rcp26_r1i1p1_210001-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
      gridfile.filename = "tas_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'BCC-CSM1-1-m-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "BCC-CSM1-1-m",
      gcm.run = 1,
      institute = "BCC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_bcc-csm1-1-m_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_bcc-csm1-1-m_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
      gridfile.filename = "tas_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'BNU-ESM-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "BNU-ESM",
      gcm.run = 1,
      institute = "GCESS",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_BNU-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_BNU-ESM_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_BNU-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_BNU-ESM_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BNU-ESM/historical",
      gridfile.filename = "tas_Amon_BNU-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 1,
      institute = "CCCma",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp26_r1i1p1_200601-210012.nc", 
            "tas_Amon_CanESM2_rcp26_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp26_r1i1p1_200601-210012.nc", 
            "pr_Amon_CanESM2_rcp26_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r2i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 2,
      institute = "CCCma",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp26_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp26_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r3i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 3,
      institute = "CCCma",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp26_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp26_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r4i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 4,
      institute = "CCCma",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp26_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp26_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CanESM2-r5i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CanESM2",
      gcm.run = 5,
      institute = "CCCma",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CanESM2_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CanESM2_rcp26_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CanESM2_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CanESM2_rcp26_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CanESM2/historical",
      gridfile.filename = "tas_Amon_CanESM2_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 1,
      institute = "NCAR",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp26_r1i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp26_r1i1p1_200601-210012.nc", 
            "tas_Amon_CCSM4_rcp26_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp26_r1i1p1_200601-210012.nc", 
            "pr_Amon_CCSM4_rcp26_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r2i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 2,
      institute = "NCAR",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp26_r2i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp26_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp26_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r3i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 3,
      institute = "NCAR",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp26_r3i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp26_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp26_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r4i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 4,
      institute = "NCAR",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp26_r4i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp26_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp26_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r5i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 5,
      institute = "NCAR",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp26_r5i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp26_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp26_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r6i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 6,
      institute = "NCAR",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CCSM4_rcp26_r6i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp26_r6i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r6i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 1,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp26_r1i1p1_200601-210012.nc", 
            "tas_Amon_CESM1-CAM5_rcp26_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp26_r1i1p1_200601-210012.nc", 
            "pr_Amon_CESM1-CAM5_rcp26_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r2i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 2,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp26_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp26_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r3i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 3,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp26_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp26_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CNRM-CM5-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CNRM-CM5",
      gcm.run = 1,
      institute = "CNRM-CERFACS",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CNRM-CM5_historical_r1i1p1_185001-189912.nc", 
            "tas_Amon_CNRM-CM5_historical_r1i1p1_190001-194912.nc", 
            "tas_Amon_CNRM-CM5_historical_r1i1p1_195001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CNRM-CM5_rcp26_r1i1p1_200601-205512.nc", 
            "tas_Amon_CNRM-CM5_rcp26_r1i1p1_205601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CNRM-CM5_historical_r1i1p1_185001-189912.nc", 
            "pr_Amon_CNRM-CM5_historical_r1i1p1_190001-194912.nc", 
            "pr_Amon_CNRM-CM5_historical_r1i1p1_195001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CNRM-CM5_rcp26_r1i1p1_200601-205512.nc", 
            "pr_Amon_CNRM-CM5_rcp26_r1i1p1_205601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CNRM-CM5/historical",
      gridfile.filename = "tas_Amon_CNRM-CM5_historical_r1i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r10i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 10,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r10i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r10i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 1,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r2i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 2,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r3i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 3,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r4i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 4,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r5i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 5,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r6i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 6,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r6i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r6i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r7i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 7,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r7i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r7i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r8i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 8,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r8i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r8i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r9i1p1_rcp26' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 9,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp26_r9i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp26_r9i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r12i1p1_rcp26' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 12,
      institute = "EC-EARTH",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r12i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r12i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r12i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp26_r12i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r12i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r12i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r12i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp26_r12i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r12i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'EC-EARTH-r8i1p1_rcp26' = list( 
      rcm = "",
      gcm = "EC-EARTH",
      gcm.run = 8,
      institute = "EC-EARTH",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_EC-EARTH_historical_r8i1p1_185001-189912.nc", 
            "tas_Amon_EC-EARTH_historical_r8i1p1_190001-194912.nc", 
            "tas_Amon_EC-EARTH_historical_r8i1p1_195001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_EC-EARTH_rcp26_r8i1p1_200601-205012.nc", 
            "tas_Amon_EC-EARTH_rcp26_r8i1p1_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_EC-EARTH_historical_r8i1p1_185001-189912.nc", 
            "pr_Amon_EC-EARTH_historical_r8i1p1_190001-194912.nc", 
            "pr_Amon_EC-EARTH_historical_r8i1p1_195001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_EC-EARTH_rcp26_r8i1p1_200601-205012.nc", 
            "pr_Amon_EC-EARTH_rcp26_r8i1p1_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/EC-EARTH/historical",
      gridfile.filename = "tas_Amon_EC-EARTH_historical_r8i1p1_185001-189912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FGOALS-g2-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "FGOALS-g2",
      gcm.run = 1,
      institute = "LASG-CESS",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FGOALS-g2_historical_r1i1p1_185001-185912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_186001-186912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_187001-187912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_188001-188912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_189001-189912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_190001-190912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_191001-191912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_192001-192912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_193001-193912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_194001-194912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_195001-195912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_196001-196912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_197001-197912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_198001-198912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_199001-199912.nc", 
            "tas_Amon_FGOALS-g2_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_200601-201512.nc", 
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_201601-202512.nc", 
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_202601-203512.nc", 
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_203601-204512.nc", 
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_204601-205512.nc", 
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_205601-206512.nc", 
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_206601-207512.nc", 
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_207601-208512.nc", 
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_208601-209512.nc", 
            "tas_Amon_FGOALS-g2_rcp26_r1i1p1_209601-210112.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FGOALS-g2_historical_r1i1p1_185001-185912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_186001-186912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_187001-187912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_188001-188912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_189001-189912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_190001-190912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_191001-191912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_192001-192912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_193001-193912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_194001-194912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_195001-195912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_196001-196912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_197001-197912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_198001-198912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_199001-199912.nc", 
            "pr_Amon_FGOALS-g2_historical_r1i1p1_200001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_200601-201512.nc", 
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_201601-202512.nc", 
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_202601-203512.nc", 
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_203601-204512.nc", 
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_204601-205512.nc", 
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_205601-206512.nc", 
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_206601-207512.nc", 
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_207601-208512.nc", 
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_208601-209512.nc", 
            "pr_Amon_FGOALS-g2_rcp26_r1i1p1_209601-210112.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-g2/historical",
      gridfile.filename = "tas_Amon_FGOALS-g2_historical_r1i1p1_185001-185912.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FGOALS-s2-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "FGOALS-s2",
      gcm.run = 1,
      institute = "LASG-IAP",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FGOALS-s2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FGOALS-s2_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FGOALS-s2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FGOALS-s2_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/historical",
      gridfile.filename = "tas_Amon_FGOALS-s2_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 1,
      institute = "FIO",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r2i1p1_rcp26' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 2,
      institute = "FIO",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp26_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp26_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r3i1p1_rcp26' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 3,
      institute = "FIO",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp26_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp26_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM3-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "GFDL-CM3",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_186501-186912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_187001-187412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_187501-187912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_188001-188412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_188501-188912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_189001-189412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_189501-189912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_190001-190412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_190501-190912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_191001-191412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_191501-191912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_192001-192412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_192501-192912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_193001-193412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_193501-193912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_194001-194412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_194501-194912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_195001-195412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_195501-195912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_196001-196412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_196501-196912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_197001-197412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_197501-197912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_198001-198412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_198501-198912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_199001-199412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_199501-199912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_200001-200412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-CM3_rcp26_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_186501-186912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_187001-187412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_187501-187912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_188001-188412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_188501-188912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_189001-189412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_189501-189912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_190001-190412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_190501-190912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_191001-191412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_191501-191912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_192001-192412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_192501-192912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_193001-193412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_193501-193912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_194001-194412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_194501-194912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_195001-195412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_195501-195912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_196001-196412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_196501-196912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_197001-197412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_197501-197912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_198001-198412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_198501-198912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_199001-199412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_199501-199912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_200001-200412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-CM3_rcp26_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
      gridfile.filename = "tas_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-ESM2G-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "GFDL-ESM2G",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp26_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp26_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
      gridfile.filename = "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-ESM2M-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "GFDL-ESM2M",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp26_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp26_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
      gridfile.filename = "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p1_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp26_r1i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p1_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p1_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p1_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p1_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p1_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p1_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp26_r1i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p1_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p1_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p1_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p1_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p1_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p2_rcp26' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p2_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp26_r1i1p2_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p2_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p2_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p2_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p2_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p2_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p2_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp26_r1i1p2_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p2_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p2_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p2_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p2_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p2_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p3_rcp26' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p3_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp26_r1i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p3_205101-210012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p3_210101-215012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p3_215101-220012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p3_220101-225012.nc", 
            "tas_Amon_GISS-E2-H_rcp26_r1i1p3_225101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p3_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp26_r1i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p3_205101-210012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p3_210101-215012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p3_215101-220012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p3_220101-225012.nc", 
            "pr_Amon_GISS-E2-H_rcp26_r1i1p3_225101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p1_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p1_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p2_rcp26' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p2_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p2_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p3_rcp26' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_207601-210012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_210101-212512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_212601-215012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_215101-217512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_217601-220012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_220101-222512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_222601-225012.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_225101-227512.nc", 
            "tas_Amon_GISS-E2-R_rcp26_r1i1p3_227601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_207601-210012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_210101-212512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_212601-215012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_215101-217512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_217601-220012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_220101-222512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_222601-225012.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_225101-227512.nc", 
            "pr_Amon_GISS-E2-R_rcp26_r1i1p3_227601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-AO-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "HadGEM2-AO",
      gcm.run = 1,
      institute = "NIMR/KMA",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_HadGEM2-AO_rcp26_r1i1p1_200601-209912.nc", 
            "tas_Amon_HadGEM2-AO_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc"
            ),
          scenario = c(
##            "pr_Amon_HadGEM2-AO_rcp26_r1i1p1_200601-209912.nc", 
            "pr_Amon_HadGEM2-AO_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
      gridfile.filename = "tas_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 1,
      institute = "MOHC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_208012-209911.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_209912-212411.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_212412-214911.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_214912-217411.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_217412-219911.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_219912-222411.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_222412-224911.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_224912-227411.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_227412-229911.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r1i1p1_229912-229912.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_208012-209911.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_209912-212411.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_212412-214911.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_214912-217411.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_217412-219911.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_219912-222411.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_222412-224911.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_224912-227411.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_227412-229911.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r1i1p1_229912-229912.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r2i1p1_rcp26' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 2,
      institute = "MOHC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp26_r2i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r2i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r2i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r2i1p1_208012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp26_r2i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r2i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r2i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r2i1p1_208012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r3i1p1_rcp26' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 3,
      institute = "MOHC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp26_r3i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r3i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r3i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r3i1p1_208012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp26_r3i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r3i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r3i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r3i1p1_208012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r4i1p1_rcp26' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 4,
      institute = "MOHC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp26_r4i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r4i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r4i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp26_r4i1p1_208012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp26_r4i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r4i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r4i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp26_r4i1p1_208012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp26_r1i1p1_200601-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp26_r1i1p1_200601-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r2i1p1_rcp26' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 2,
      institute = "IPSL",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp26_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp26_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r3i1p1_rcp26' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 3,
      institute = "IPSL",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp26_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp26_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r4i1p1_rcp26' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 4,
      institute = "IPSL",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp26_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp26_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-MR-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-MR_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-MR_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r2i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 2,
      institute = "MIROC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r2i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp26_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r2i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp26_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r2i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r3i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 3,
      institute = "MIROC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r3i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp26_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r3i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp26_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r3i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r4i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 4,
      institute = "MIROC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r4i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp26_r4i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r4i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp26_r4i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r4i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r5i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 5,
      institute = "MIROC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r5i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp26_r5i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r5i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp26_r5i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r5i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC-ESM-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MIROC-ESM",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC-ESM_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC-ESM_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
      gridfile.filename = "tas_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC-ESM-CHEM-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MIROC-ESM-CHEM",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC-ESM-CHEM_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC-ESM-CHEM_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
      gridfile.filename = "tas_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-LR-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      institute = "MPI-M",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-LR_rcp26_r1i1p1_200601-210012.nc", 
            "tas_Amon_MPI-ESM-LR_rcp26_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-LR_rcp26_r1i1p1_200601-210012.nc", 
            "pr_Amon_MPI-ESM-LR_rcp26_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-LR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-LR-r2i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MPI-ESM-LR",
      gcm.run = 2,
      institute = "MPI-M",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-LR_rcp26_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-LR_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-LR_rcp26_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-LR_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-LR-r3i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MPI-ESM-LR",
      gcm.run = 3,
      institute = "MPI-M",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-LR_rcp26_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-LR_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-LR_rcp26_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-LR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-LR_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MPI-ESM-MR-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MPI-ESM-MR",
      gcm.run = 1,
      institute = "MPI-M",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MPI-ESM-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MPI-ESM-MR_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MPI-ESM-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MPI-ESM-MR_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MPI-ESM-MR/historical",
      gridfile.filename = "tas_Amon_MPI-ESM-MR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MRI-CGCM3-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "MRI-CGCM3",
      gcm.run = 1,
      institute = "MRI",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MRI-CGCM3_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MRI-CGCM3_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
      gridfile.filename = "tas_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'NorESM1-M-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "NorESM1-M",
      gcm.run = 1,
      institute = "NCC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_NorESM1-M_rcp26_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_NorESM1-M_rcp26_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
      gridfile.filename = "tas_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'NorESM1-ME-r1i1p1_rcp26' = list( 
      rcm = "",
      gcm = "NorESM1-ME",
      gcm.run = 1,
      institute = "NCC",
      emission.scenario = "rcp26",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/rcp26"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/rcp26")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_NorESM1-ME_rcp26_r1i1p1_200601-206012.nc", 
            "tas_Amon_NorESM1-ME_rcp26_r1i1p1_206101-210112.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_NorESM1-ME_rcp26_r1i1p1_200601-206012.nc", 
            "pr_Amon_NorESM1-ME_rcp26_r1i1p1_206101-210112.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
      gridfile.filename = "tas_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),
## acrnonyms: , 
##  BCC-CSM1-1-r1i1p1_rcp26, 
##  BCC-CSM1-1-m-r1i1p1_rcp26, 
##  BNU-ESM-r1i1p1_rcp26, 
##  CanESM2-r1i1p1_rcp26, 
##  CanESM2-r2i1p1_rcp26, 
##  CanESM2-r3i1p1_rcp26, 
##  CanESM2-r4i1p1_rcp26, 
##  CanESM2-r5i1p1_rcp26, 
##  CCSM4-r1i1p1_rcp26, 
##  CCSM4-r2i1p1_rcp26, 
##  CCSM4-r3i1p1_rcp26, 
##  CCSM4-r4i1p1_rcp26, 
##  CCSM4-r5i1p1_rcp26, 
##  CCSM4-r6i1p1_rcp26, 
##  CESM1-CAM5-r1i1p1_rcp26, 
##  CESM1-CAM5-r2i1p1_rcp26, 
##  CESM1-CAM5-r3i1p1_rcp26, 
##  CNRM-CM5-r1i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r10i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r1i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r2i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r3i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r4i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r5i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r6i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r7i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r8i1p1_rcp26, 
##  CSIRO-Mk3-6-0-r9i1p1_rcp26, 
##  EC-EARTH-r12i1p1_rcp26, 
##  EC-EARTH-r8i1p1_rcp26, 
##  FGOALS-g2-r1i1p1_rcp26, 
##  FGOALS-s2-r1i1p1_rcp26, 
##  FIO-ESM-r1i1p1_rcp26, 
##  FIO-ESM-r2i1p1_rcp26, 
##  FIO-ESM-r3i1p1_rcp26, 
##  GFDL-CM3-r1i1p1_rcp26, 
##  GFDL-ESM2G-r1i1p1_rcp26, 
##  GFDL-ESM2M-r1i1p1_rcp26, 
##  GISS-E2-H-r1i1p1_rcp26, 
##  GISS-E2-H-r1i1p2_rcp26, 
##  GISS-E2-H-r1i1p3_rcp26, 
##  GISS-E2-R-r1i1p1_rcp26, 
##  GISS-E2-R-r1i1p2_rcp26, 
##  GISS-E2-R-r1i1p3_rcp26, 
##  HadGEM2-AO-r1i1p1_rcp26, 
##  HadGEM2-ES-r1i1p1_rcp26, 
##  HadGEM2-ES-r2i1p1_rcp26, 
##  HadGEM2-ES-r3i1p1_rcp26, 
##  HadGEM2-ES-r4i1p1_rcp26, 
##  IPSL-CM5A-LR-r1i1p1_rcp26, 
##  IPSL-CM5A-LR-r2i1p1_rcp26, 
##  IPSL-CM5A-LR-r3i1p1_rcp26, 
##  IPSL-CM5A-LR-r4i1p1_rcp26, 
##  IPSL-CM5A-MR-r1i1p1_rcp26, 
##  MIROC5-r1i1p1_rcp26, 
##  MIROC5-r2i1p1_rcp26, 
##  MIROC5-r3i1p1_rcp26, 
##  MIROC5-r4i1p1_rcp26, 
##  MIROC5-r5i1p1_rcp26, 
##  MIROC-ESM-r1i1p1_rcp26, 
##  MIROC-ESM-CHEM-r1i1p1_rcp26, 
##  MPI-ESM-LR-r1i1p1_rcp26, 
##  MPI-ESM-LR-r2i1p1_rcp26, 
##  MPI-ESM-LR-r3i1p1_rcp26, 
##  MPI-ESM-MR-r1i1p1_rcp26, 
##  MRI-CGCM3-r1i1p1_rcp26, 
##  NorESM1-M-r1i1p1_rcp26, 
##  NorESM1-ME-r1i1p1_rcp26

##########################################################################

### ----------------------------------------------------------------------
### ************************** SCENARIO: RCP60 ***************************
### ----------------------------------------------------------------------

################################################################################
    'BCC-CSM1-1-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "BCC-CSM1-1",
      gcm.run = 1,
      institute = "BCC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_bcc-csm1-1_rcp60_r1i1p1_200601-209912.nc", 
            "tas_Amon_bcc-csm1-1_rcp60_r1i1p1_210001-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_bcc-csm1-1_rcp60_r1i1p1_200601-209912.nc", 
            "pr_Amon_bcc-csm1-1_rcp60_r1i1p1_210001-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1/historical",
      gridfile.filename = "tas_Amon_bcc-csm1-1_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'BCC-CSM1-1-m-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "BCC-CSM1-1-m",
      gcm.run = 1,
      institute = "BCC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_bcc-csm1-1-m_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_bcc-csm1-1-m_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/BCC-CSM1.1(m)/historical",
      gridfile.filename = "tas_Amon_bcc-csm1-1-m_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 1,
      institute = "NCAR",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp60_r1i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp60_r1i1p1_200601-210012.nc", 
            "tas_Amon_CCSM4_rcp60_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp60_r1i1p1_200601-210012.nc", 
            "pr_Amon_CCSM4_rcp60_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r2i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 2,
      institute = "NCAR",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp60_r2i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp60_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp60_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r3i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 3,
      institute = "NCAR",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp60_r3i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp60_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp60_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r4i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 4,
      institute = "NCAR",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp60_r4i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp60_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp60_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r5i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 5,
      institute = "NCAR",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
##            "tas_Amon_CCSM4_rcp60_r5i1p1_200501-210012.nc", 
            "tas_Amon_CCSM4_rcp60_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp60_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CCSM4-r6i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CCSM4",
      gcm.run = 6,
      institute = "NCAR",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CCSM4_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CCSM4_rcp60_r6i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CCSM4_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CCSM4_rcp60_r6i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CCSM4/historical",
      gridfile.filename = "tas_Amon_CCSM4_historical_r6i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 1,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp60_r1i1p1_200601-210012.nc", 
            "tas_Amon_CESM1-CAM5_rcp60_r1i1p1_210101-230012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp60_r1i1p1_200601-210012.nc", 
            "pr_Amon_CESM1-CAM5_rcp60_r1i1p1_210101-230012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r2i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 2,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp60_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp60_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CESM1-CAM5-r3i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CESM1-CAM5",
      gcm.run = 3,
      institute = "NSF-DOE-NCAR",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CESM1-CAM5_rcp60_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CESM1-CAM5_rcp60_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CESM1(CAM5)/historical",
      gridfile.filename = "tas_Amon_CESM1-CAM5_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r10i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 10,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r10i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r10i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r10i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 1,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r2i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 2,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r3i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 3,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r4i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 4,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r4i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r4i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r4i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r5i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 5,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r5i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r5i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r5i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r6i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 6,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r6i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r6i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r6i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r7i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 7,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r7i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r7i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r7i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r8i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 8,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r8i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r8i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r8i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'CSIRO-Mk3-6-0-r9i1p1_rcp60' = list( 
      rcm = "",
      gcm = "CSIRO-Mk3-6-0",
      gcm.run = 9,
      institute = "CSIRO-QCCCE",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_CSIRO-Mk3-6-0_rcp60_r9i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_CSIRO-Mk3-6-0_rcp60_r9i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/CSIRO-Mk3.6.0/historical",
      gridfile.filename = "tas_Amon_CSIRO-Mk3-6-0_historical_r9i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FGOALS-s2-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "FGOALS-s2",
      gcm.run = 1,
      institute = "LASG-IAP",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FGOALS-s2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FGOALS-s2_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FGOALS-s2_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FGOALS-s2_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FGOALS-s2/historical",
      gridfile.filename = "tas_Amon_FGOALS-s2_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 1,
      institute = "FIO",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r2i1p1_rcp60' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 2,
      institute = "FIO",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp60_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp60_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r2i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'FIO-ESM-r3i1p1_rcp60' = list( 
      rcm = "",
      gcm = "FIO-ESM",
      gcm.run = 3,
      institute = "FIO",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_FIO-ESM_rcp60_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_FIO-ESM_rcp60_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/FIO-ESM/historical",
      gridfile.filename = "tas_Amon_FIO-ESM_historical_r3i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-CM3-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "GFDL-CM3",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_186501-186912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_187001-187412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_187501-187912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_188001-188412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_188501-188912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_189001-189412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_189501-189912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_190001-190412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_190501-190912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_191001-191412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_191501-191912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_192001-192412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_192501-192912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_193001-193412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_193501-193912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_194001-194412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_194501-194912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_195001-195412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_195501-195912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_196001-196412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_196501-196912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_197001-197412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_197501-197912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_198001-198412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_198501-198912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_199001-199412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_199501-199912.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_200001-200412.nc", 
            "tas_Amon_GFDL-CM3_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-CM3_rcp60_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_186501-186912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_187001-187412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_187501-187912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_188001-188412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_188501-188912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_189001-189412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_189501-189912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_190001-190412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_190501-190912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_191001-191412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_191501-191912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_192001-192412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_192501-192912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_193001-193412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_193501-193912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_194001-194412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_194501-194912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_195001-195412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_195501-195912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_196001-196412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_196501-196912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_197001-197412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_197501-197912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_198001-198412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_198501-198912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_199001-199412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_199501-199912.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_200001-200412.nc", 
            "pr_Amon_GFDL-CM3_historical_r1i1p1_200501-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-CM3_rcp60_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-CM3/historical",
      gridfile.filename = "tas_Amon_GFDL-CM3_historical_r1i1p1_186001-186412.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-ESM2G-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "GFDL-ESM2G",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-ESM2G_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-ESM2G_rcp60_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-ESM2G_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-ESM2G_rcp60_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2G/historical",
      gridfile.filename = "tas_Amon_GFDL-ESM2G_historical_r1i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GFDL-ESM2M-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "GFDL-ESM2M",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186601-187012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_187101-187512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_187601-188012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_188101-188512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_188601-189012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_189101-189512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_189601-190012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_190101-190512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_190601-191012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_191101-191512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_191601-192012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_192101-192512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_192601-193012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_193101-193512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_193601-194012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_194101-194512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_194601-195012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_195101-195512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_195601-196012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_196101-196512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_196601-197012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_197101-197512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_197601-198012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_198101-198512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_198601-199012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_199101-199512.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_199601-200012.nc", 
            "tas_Amon_GFDL-ESM2M_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_200601-201012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_201101-201512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_201601-202012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_202101-202512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_202601-203012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_203101-203512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_203601-204012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_204101-204512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_204601-205012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_205101-205512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_205601-206012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_206101-206512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_206601-207012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_207101-207512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_207601-208012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_208101-208512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_208601-209012.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_209101-209512.nc", 
            "tas_Amon_GFDL-ESM2M_rcp60_r1i1p1_209601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_186601-187012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_187101-187512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_187601-188012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_188101-188512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_188601-189012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_189101-189512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_189601-190012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_190101-190512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_190601-191012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_191101-191512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_191601-192012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_192101-192512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_192601-193012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_193101-193512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_193601-194012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_194101-194512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_194601-195012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_195101-195512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_195601-196012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_196101-196512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_196601-197012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_197101-197512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_197601-198012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_198101-198512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_198601-199012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_199101-199512.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_199601-200012.nc", 
            "pr_Amon_GFDL-ESM2M_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_200601-201012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_201101-201512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_201601-202012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_202101-202512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_202601-203012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_203101-203512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_203601-204012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_204101-204512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_204601-205012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_205101-205512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_205601-206012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_206101-206512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_206601-207012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_207101-207512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_207601-208012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_208101-208512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_208601-209012.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_209101-209512.nc", 
            "pr_Amon_GFDL-ESM2M_rcp60_r1i1p1_209601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GFDL-ESM2M/historical",
      gridfile.filename = "tas_Amon_GFDL-ESM2M_historical_r1i1p1_186101-186512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p1_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p1_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp60_r1i1p1_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp60_r1i1p1_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p1_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p1_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp60_r1i1p1_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp60_r1i1p1_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p1_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p2_rcp60' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p2_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp60_r1i1p2_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp60_r1i1p2_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p2_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp60_r1i1p2_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp60_r1i1p2_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p2_185001-195012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-H-r1i1p3_rcp60' = list( 
      rcm = "",
      gcm = "GISS-E2-H",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p3_190101-195012.nc", 
            "tas_Amon_GISS-E2-H_historical_r1i1p3_195101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-H_rcp60_r1i1p3_200601-205012.nc", 
            "tas_Amon_GISS-E2-H_rcp60_r1i1p3_205101-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p3_190101-195012.nc", 
            "pr_Amon_GISS-E2-H_historical_r1i1p3_195101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-H_rcp60_r1i1p3_200601-205012.nc", 
            "pr_Amon_GISS-E2-H_rcp60_r1i1p3_205101-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-H/historical",
      gridfile.filename = "tas_Amon_GISS-E2-H_historical_r1i1p3_185001-190012.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp60_r1i1p1_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp60_r1i1p1_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp60_r1i1p1_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp60_r1i1p1_207601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p1_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp60_r1i1p1_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp60_r1i1p1_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp60_r1i1p1_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp60_r1i1p1_207601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p1_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p2_rcp60' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p2_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp60_r1i1p2_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp60_r1i1p2_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp60_r1i1p2_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp60_r1i1p2_207601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p2_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp60_r1i1p2_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp60_r1i1p2_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp60_r1i1p2_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp60_r1i1p2_207601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p2_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'GISS-E2-R-r1i1p3_rcp60' = list( 
      rcm = "",
      gcm = "GISS-E2-R",
      gcm.run = 1,
      institute = "NASA GISS",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_187601-190012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_190101-192512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_192601-195012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_195101-197512.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_197601-200012.nc", 
            "tas_Amon_GISS-E2-R_historical_r1i1p3_200101-200512.nc"
            ),
          scenario = c(
            "tas_Amon_GISS-E2-R_rcp60_r1i1p3_200601-202512.nc", 
            "tas_Amon_GISS-E2-R_rcp60_r1i1p3_202601-205012.nc", 
            "tas_Amon_GISS-E2-R_rcp60_r1i1p3_205101-207512.nc", 
            "tas_Amon_GISS-E2-R_rcp60_r1i1p3_207601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_187601-190012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_190101-192512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_192601-195012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_195101-197512.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_197601-200012.nc", 
            "pr_Amon_GISS-E2-R_historical_r1i1p3_200101-200512.nc"
            ),
          scenario = c(
            "pr_Amon_GISS-E2-R_rcp60_r1i1p3_200601-202512.nc", 
            "pr_Amon_GISS-E2-R_rcp60_r1i1p3_202601-205012.nc", 
            "pr_Amon_GISS-E2-R_rcp60_r1i1p3_205101-207512.nc", 
            "pr_Amon_GISS-E2-R_rcp60_r1i1p3_207601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/GISS-E2-R/historical",
      gridfile.filename = "tas_Amon_GISS-E2-R_historical_r1i1p3_185001-187512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-AO-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "HadGEM2-AO",
      gcm.run = 1,
      institute = "NIMR/KMA",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-AO_rcp60_r1i1p1_200601-209912.nc" 
##            "tas_Amon_HadGEM2-AO_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-AO_rcp60_r1i1p1_200601-209912.nc" 
##            "pr_Amon_HadGEM2-AO_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-AO/historical",
      gridfile.filename = "tas_Amon_HadGEM2-AO_historical_r1i1p1_186001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 1,
      institute = "MOHC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp60_r1i1p1_200512-201111.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r1i1p1_201112-203611.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r1i1p1_203612-206111.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r1i1p1_206112-208611.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r1i1p1_208612-209911.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r1i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp60_r1i1p1_200512-201111.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r1i1p1_201112-203611.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r1i1p1_203612-206111.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r1i1p1_206112-208611.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r1i1p1_208612-209911.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r1i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r2i1p1_rcp60' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 2,
      institute = "MOHC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp60_r2i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r2i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r2i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r2i1p1_208012-210011.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r2i1p1_210012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r2i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp60_r2i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r2i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r2i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r2i1p1_208012-210011.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r2i1p1_210012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r2i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r3i1p1_rcp60' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 3,
      institute = "MOHC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp60_r3i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r3i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r3i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r3i1p1_208012-210011.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r3i1p1_210012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r3i1p1_198412-200512.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp60_r3i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r3i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r3i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r3i1p1_208012-210011.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r3i1p1_210012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r3i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'HadGEM2-ES-r4i1p1_rcp60' = list( 
      rcm = "",
      gcm = "HadGEM2-ES",
      gcm.run = 4,
      institute = "MOHC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_188412-190911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_190912-193411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_193412-195911.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_195912-198411.nc", 
            "tas_Amon_HadGEM2-ES_historical_r4i1p1_198412-200511.nc"
            ),
          scenario = c(
            "tas_Amon_HadGEM2-ES_rcp60_r4i1p1_200512-203011.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r4i1p1_203012-205511.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r4i1p1_205512-208011.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r4i1p1_208012-210011.nc", 
            "tas_Amon_HadGEM2-ES_rcp60_r4i1p1_210012-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_188412-190911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_190912-193411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_193412-195911.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_195912-198411.nc", 
            "pr_Amon_HadGEM2-ES_historical_r4i1p1_198412-200511.nc"
            ),
          scenario = c(
            "pr_Amon_HadGEM2-ES_rcp60_r4i1p1_200512-203011.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r4i1p1_203012-205511.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r4i1p1_205512-208011.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r4i1p1_208012-210011.nc", 
            "pr_Amon_HadGEM2-ES_rcp60_r4i1p1_210012-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/HadGEM2-ES/historical",
      gridfile.filename = "tas_Amon_HadGEM2-ES_historical_r4i1p1_185912-188411.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-LR-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-LR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-LR_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-LR_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-LR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-LR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'IPSL-CM5A-MR-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_IPSL-CM5A-MR_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_IPSL-CM5A-MR_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/IPSL-CM5A-MR/historical",
      gridfile.filename = "tas_Amon_IPSL-CM5A-MR_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r1i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r1i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r2i1p1_rcp60' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 2,
      institute = "MIROC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r2i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp60_r2i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r2i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp60_r2i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r2i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r3i1p1_rcp60' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 3,
      institute = "MIROC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r3i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp60_r3i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r3i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp60_r3i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r3i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r4i1p1_rcp60' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 4,
      institute = "MIROC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r4i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp60_r4i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r4i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp60_r4i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r4i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC5-r5i1p1_rcp60' = list( 
      rcm = "",
      gcm = "MIROC5",
      gcm.run = 5,
      institute = "MIROC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC5_historical_r5i1p1_185001-201212.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC5_rcp60_r5i1p1_200601-203512.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC5_historical_r5i1p1_185001-201212.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC5_rcp60_r5i1p1_200601-203512.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC5/historical",
      gridfile.filename = "tas_Amon_MIROC5_historical_r5i1p1_185001-201212.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC-ESM-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "MIROC-ESM",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC-ESM_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC-ESM_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM/historical",
      gridfile.filename = "tas_Amon_MIROC-ESM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MIROC-ESM-CHEM-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "MIROC-ESM-CHEM",
      gcm.run = 1,
      institute = "MIROC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MIROC-ESM-CHEM_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MIROC-ESM-CHEM_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MIROC-ESM-CHEM/historical",
      gridfile.filename = "tas_Amon_MIROC-ESM-CHEM_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'MRI-CGCM3-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "MRI-CGCM3",
      gcm.run = 1,
      institute = "MRI",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_MRI-CGCM3_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_MRI-CGCM3_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/MRI-CGCM3/historical",
      gridfile.filename = "tas_Amon_MRI-CGCM3_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'NorESM1-M-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "NorESM1-M",
      gcm.run = 1,
      institute = "NCC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_NorESM1-M_rcp60_r1i1p1_200601-210012.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_NorESM1-M_rcp60_r1i1p1_200601-210012.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-M/historical",
      gridfile.filename = "tas_Amon_NorESM1-M_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),

################################################################################
    'NorESM1-ME-r1i1p1_rcp60' = list( 
      rcm = "",
      gcm = "NorESM1-ME",
      gcm.run = 1,
      institute = "NCC",
      emission.scenario = "rcp60",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/rcp60"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
             scenario =  "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/rcp60")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "tas_Amon_NorESM1-ME_rcp60_r1i1p1_200601-205012.nc", 
            "tas_Amon_NorESM1-ME_rcp60_r1i1p1_205101-210112.nc"
            )),
        precipitation_amount = list(
          historical = c(
            "pr_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc"
            ),
          scenario = c(
            "pr_Amon_NorESM1-ME_rcp60_r1i1p1_200601-205012.nc", 
            "pr_Amon_NorESM1-ME_rcp60_r1i1p1_205101-210112.nc"
           ))),
      gridfile.path = "/data/reloclim/rcm/CMIP5_update_2013_02_07/NorESM1-ME/historical",
      gridfile.filename = "tas_Amon_NorESM1-ME_historical_r1i1p1_185001-200512.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),
## acrnonyms: , 
##  BCC-CSM1-1-r1i1p1_rcp60, 
##  BCC-CSM1-1-m-r1i1p1_rcp60, 
##  CCSM4-r1i1p1_rcp60, 
##  CCSM4-r2i1p1_rcp60, 
##  CCSM4-r3i1p1_rcp60, 
##  CCSM4-r4i1p1_rcp60, 
##  CCSM4-r5i1p1_rcp60, 
##  CCSM4-r6i1p1_rcp60, 
##  CESM1-CAM5-r1i1p1_rcp60, 
##  CESM1-CAM5-r2i1p1_rcp60, 
##  CESM1-CAM5-r3i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r10i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r1i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r2i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r3i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r4i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r5i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r6i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r7i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r8i1p1_rcp60, 
##  CSIRO-Mk3-6-0-r9i1p1_rcp60, 
##  FGOALS-s2-r1i1p1_rcp60, 
##  FIO-ESM-r1i1p1_rcp60, 
##  FIO-ESM-r2i1p1_rcp60, 
##  FIO-ESM-r3i1p1_rcp60, 
##  GFDL-CM3-r1i1p1_rcp60, 
##  GFDL-ESM2G-r1i1p1_rcp60, 
##  GFDL-ESM2M-r1i1p1_rcp60, 
##  GISS-E2-H-r1i1p1_rcp60, 
##  GISS-E2-H-r1i1p2_rcp60, 
##  GISS-E2-H-r1i1p3_rcp60, 
##  GISS-E2-R-r1i1p1_rcp60, 
##  GISS-E2-R-r1i1p2_rcp60, 
##  GISS-E2-R-r1i1p3_rcp60, 
##  HadGEM2-AO-r1i1p1_rcp60, 
##  HadGEM2-ES-r1i1p1_rcp60, 
##  HadGEM2-ES-r2i1p1_rcp60, 
##  HadGEM2-ES-r3i1p1_rcp60, 
##  HadGEM2-ES-r4i1p1_rcp60, 
##  IPSL-CM5A-LR-r1i1p1_rcp60, 
##  IPSL-CM5A-MR-r1i1p1_rcp60, 
##  MIROC5-r1i1p1_rcp60, 
##  MIROC5-r2i1p1_rcp60, 
##  MIROC5-r3i1p1_rcp60, 
##  MIROC5-r4i1p1_rcp60, 
##  MIROC5-r5i1p1_rcp60, 
##  MIROC-ESM-r1i1p1_rcp60, 
##  MIROC-ESM-CHEM-r1i1p1_rcp60, 
##  MRI-CGCM3-r1i1p1_rcp60, 
##  NorESM1-M-r1i1p1_rcp60, 
##  NorESM1-ME-r1i1p1_rcp60

################################################################################



###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++++++++++DATASET: SCHOENER ENSEMBLES QM+++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

###########################################################################
    'METO-HC_HadRM3Q0_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "HadRM3",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'METO-HC_HadRM3Q16_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "HadRM3",
      gcm = "HadCM3Q16",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'METO-HC_HadRM3Q3_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "HadRM3",
      gcm = "HadCM3Q3",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'ETHZ-CLM_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "CLM",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/ETHZ/CLM/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/ETHZ/CLM/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'METNOHIRHAM_HadCM3Q0_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/METNO/HIRHAM/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/METNO/HIRHAM/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'METNOHIRHAM_BCM_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "BCCR-BCM2.0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/METNO/HIRHAM/BCM_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/METNO/HIRHAM/BCM_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'ICTP-REGCM3_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "RegCM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'MPI-M-REMO_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "REMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/MPI/REMO/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/MPI/REMO/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'C4IRCA3_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "RCA3",
      gcm = "HadCM3Q16",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/C4I/RCA/HadCM3Q16_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/C4I/RCA/HadCM3Q16_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'CNRM-RM5.1_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "RM5.1",
      gcm = "ARPEGE",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'CNRM-RM4.5_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "RM4.5",
      gcm = "ARPEGE",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/CNRM/ALADIN/ARPEGE4.5_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/CNRM/ALADIN/ARPEGE4.5_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'DMI-HIRHAM5_ARPEGE_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "ARPEGE",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/DMI/HIRHAM/ARPEGE_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/DMI/HIRHAM/ARPEGE_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'DMI-HIRHAM5_ECHAM5_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'DMI-HIRHAM5_BCM_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "BCCR-BCM2.0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/DMI/HIRHAM/BCM_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/DMI/HIRHAM/BCM_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'GKSS-CCLM4.8_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "CLM",
      gcm = "IPSL-CM4",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/GKSS/CLM/IPSL_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/GKSS/CLM/IPSL_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'KNMI-RACMO2_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "RACMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/KNMI/RACMO/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/KNMI/RACMO/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'OURANOSMRCC4.2.1_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "CRCM",
      gcm = "CGCM3",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/OURANOS/CRCM/CGCM3_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/OURANOS/CRCM/CGCM3_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'SMHIRCA_BCM_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "BCCR-BCM2.0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/SMHI/RCA/BCM_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/SMHI/RCA/BCM_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'SMHIRCA_ECHAM5-r3_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/SMHI/RCA/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/SMHI/RCA/ECHAM5-r3_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'SMHIRCA_HadCM3Q3_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "HadCM3Q3",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/SMHI/RCA/HadCM3Q3_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/SMHI/RCA/HadCM3Q3_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'UCLM-PROMES_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "PROMES",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/UCLM/PROMES/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/UCLM/PROMES/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'VMGO-RRCM_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "RRCM",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/VMGO/RRCM/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/VMGO/RRCM/HadCM3Q0_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
################################################################################
    'AIT-CCLM_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "CCLM",
      gcm = "HadCM3",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/AIT/CCLM/HadCM3_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/AIT/CCLM/HadCM3_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),
#################################################################################
    'WEGC-CCLM_QM_SCHOENER' = list(
      institute = "WEGC",
      rcm = "CCLM",
      gcm = "ECHAM5",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/KWF/WEGC/CCLM/ECHAM5-r2_A1B/postproc/QM_SCHOENER",
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc',
        surface_snow_height  = 'WICE_SnowModel_sst_24hc_[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/KWF/WEGC/CCLM/ECHAM5-r2_A1B/postproc/QM_SCHOENER",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1984.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc",
        surface_snow_height = "sst_24hc"),
      resolution = "1km"
      ),

###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++ DATASET: ENSEMBLES QM ECAv2.0 ++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

################################################################################
    'METO-HC_HadRM3Q0_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "HadRM3",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'METO-HC_HadRM3Q16_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "HadRM3",
      gcm = "HadCM3Q16",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'METO-HC_HadRM3Q3_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "HadRM3",
      gcm = "HadCM3Q3",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'ETHZ-CLM_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "CLM",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'METNOHIRHAM_HadCM3Q0_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'METNOHIRHAM_BCM_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "BCCR-BCM2.0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/BCM_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/BCM_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/BCM_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'ICTP-REGCM3_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "RegCM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'MPI-M-REMO_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "REMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'C4IRCA3_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "RCA3",
      gcm = "HadCM3Q16",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'CNRM-RM5.1_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "RM5.1",
      gcm = "ARPEGE",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'CNRM-RM4.5_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "RM4.5",
      gcm = "ARPEGE",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE4.5_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE4.5_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE4.5_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'DMI-HIRHAM5_ARPEGE_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "ARPEGE",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'DMI-HIRHAM5_ECHAM5_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'DMI-HIRHAM5_BCM_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "BCCR-BCM2.0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'GKSS-CCLM4.8_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "CLM",
      gcm = "IPSL-CM4",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/GKSS/CLM/IPSL_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/GKSS/CLM/IPSL_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/GKSS/CLM/IPSL_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'KNMI-RACMO2_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "RACMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'OURANOSMRCC4.2.1_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "CRCM",
      gcm = "CGCM3",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/OURANOS/CRCM/CGCM3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/OURANOS/CRCM/CGCM3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/OURANOS/CRCM/CGCM3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'SMHIRCA_BCM_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "BCCR-BCM2.0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'SMHIRCA_ECHAM5-r3_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'SMHIRCA_HadCM3Q3_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "HadCM3Q3",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'UCLM-PROMES_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "PROMES",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/UCLM/PROMES/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/UCLM/PROMES/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/UCLM/PROMES/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'VMGO-RRCM_QM_ECAv2.0' = list(
      institute = "WEGC",
      rcm = "RRCM",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/VMGO/RRCM/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/VMGO/RRCM/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}-[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}-[0-9]{4}.nc'
        ),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/VMGO/RRCM/HadCM3Q0_A1B/postproc/QM_EOBSv2.0_A1Bcalib6190",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971-1980.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################



###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++ DATASET: ENSEMBLES QM ECAv5.0 ++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    ## land sea-mask is actually unnecessary here, as quantile-mapped
    ## data are on E-OBS grid anyway, having missing values above
    ## water...

################################################################################
    'METO-HC_HadRM3Q0_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "HadRM3",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'METO-HC_HadRM3Q16_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "HadRM3",
      gcm = "HadCM3Q16",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'METO-HC_HadRM3Q3_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "HadRM3",
      gcm = "HadCM3Q3",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'ETHZ-CLM_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "CLM",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'ICTP-REGCM3_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "RegCM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'MPI-M-REMO_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "REMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'C4IRCA3_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "RCA3",
      gcm = "HadCM3Q16",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'CNRM-RM5.1_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "RM5.1",
      gcm = "ARPEGE",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'DMI-HIRHAM5_ARPEGE_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "ARPEGE",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'DMI-HIRHAM5_ECHAM5_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'DMI-HIRHAM5_BCM_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "HIRHAM",
      gcm = "BCCR-BCM2.0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'KNMI-RACMO2_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "RACMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'SMHIRCA_BCM_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "BCCR-BCM2.0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'SMHIRCA_ECHAM5-r3_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'SMHIRCA_HadCM3Q3_QM_ECAv5.0' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "HadCM3Q3",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510"),
      file.name = list(
        air_temperature      = 'WICE_QuantileMapping_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_QuantileMapping_pr_24hc_[0-9]{4}.nc'
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/postproc/QM_EOBSv5.0_A1Bcalib6510",
      gridfile.filename = "WICE_QuantileMapping_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################



###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++ DATASET: ENSEMBLES RM ECAv5.0 ++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


################################################################################
    'METO-HC_HadRM3Q0_RM_ECAv5.0' = list(
      institute = "METO-HC",
      rcm = "HadRM3",
      gcm = "HadCM3Q0",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/regridded_to_EOBSv5.0",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'METO-HC_HadRM3Q16_RM_ECAv5.0' = list(
      institute = "METO-HC",
      rcm = "HadRM3",
      gcm = "HadCM3Q16",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/regridded_to_EOBSv5.0",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'METO-HC_HadRM3Q3_RM_ECAv5.0' = list(
      institute = "METO-HC",
      rcm = "HadRM3",
      gcm = "HadCM3Q3",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/regridded_to_EOBSv5.0",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'ETHZ-CLM_RM_ECAv5.0' = list(
      institute = "ETHZ",
      rcm = "CLM",
      gcm = "HadCM3Q0",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/postproc/regridded_to_EOBSv5.0",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'ICTP-REGCM3_RM_ECAv5.0' = list(
      institute = "ICTP",
      rcm = "RegCM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0",
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'MPI-M-REMO_RM_ECAv5.0' = list(
      institute = "MPI",
      rcm = "REMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
       land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
     gridfile.path = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'C4IRCA3_RM_ECAv5.0' = list(
      institute = "C4I",
      rcm = "RCA3",
      gcm = "HadCM3Q16",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
       land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
     gridfile.path = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'CNRM-RM5.1_RM_ECAv5.0' = list(
      institute = "CNRM",
      rcm = "RM5.1",
      gcm = "ARPEGE",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'DMI-HIRHAM5_ARPEGE_RM_ECAv5.0' = list(
      institute = "DMI",
      rcm = "HIRHAM",
      gcm = "ARPEGE",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
       land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
     gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'DMI-HIRHAM5_ECHAM5_RM_ECAv5.0' = list(
      institute = "DMI",
      rcm = "HIRHAM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'DMI-HIRHAM5_BCM_RM_ECAv5.0' = list(
      institute = "DMI",
      rcm = "HIRHAM",
      gcm = "BCCR-BCM2.0",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
       land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
     gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'KNMI-RACMO2_RM_ECAv5.0' = list(
      institute = "KNMI",
      rcm = "RACMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'SMHIRCA_BCM_RM_ECAv5.0' = list(
      institute = "SMHI",
      rcm = "RCA",
      gcm = "BCCR-BCM2.0",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
       land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
     gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'SMHIRCA_ECHAM5-r3_RM_ECAv5.0' = list(
      institute = "SMHI",
      rcm = "RCA",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
       land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
     gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################
    'SMHIRCA_HadCM3Q3_RM_ECAv5.0' = list(
      institute = "SMHI",
      rcm = "RCA",
      gcm = "HadCM3Q3",
      corrected.data = "FALSE",
      emission.scenario = "A1B",
      file.path.alt = c(
        air_temperature = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/postproc/regridded_to_EOBSv5.0", 
        precipitation_amount = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/postproc/regridded_to_EOBSv5.0"),
      file.name = list(
        air_temperature      = 'WICE_regridded_tas_dm_[0-9]{4}.nc',
        precipitation_amount = 'WICE_regridded_pr_24hc_[0-9]{4}.nc'
        ),
       land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
     gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/postproc/regridded_to_EOBSv5.0",
      gridfile.filename = "WICE_regridded_tas_dm_1971.nc",
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      resolution = "25km"
      ),
################################################################################



#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+++++++++++++++++++++++++++++DATASET: ADAPT.AT++++++++++++++++++++++++++++
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    'SMHIRCA_BCM_ADAPT.AT_QM' = list(
      institute = "WEGC",
      rcm = "RCA",
      gcm = "BCCR-BCM2.0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/koeppen/rcm/adapt.at/SMHI/RCA/BCM_A1B/postproc/QM",
      file.name = list(
        air_temperature = c(
          'tas_dm_QM_SMHIRCA_A1B_BCM_1961-2050.nc'
          ),
        precipitation_amount = c(
          'pr_24hc_QM_SMHIRCA_A1B_BCM_1961-2050.nc'
          )),
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      gridfile.path = "/data/koeppen/rcm/adapt.at/SMHI/RCA/BCM_A1B/postproc/QM",
      gridfile.filename = "tas_dm_QM_SMHIRCA_A1B_BCM_1961-2050.nc",
      resolution = "1km"
      ),
###########################################################################
    'ICTP-REGCM3_ADAPT.AT_QM' = list(
      institute = "WEGC",
      rcm = "RegCM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/koeppen/rcm/adapt.at/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM",
      file.name = list(
        air_temperature = c(
          'tas_dm_QM_ICTP-REGCM3_A1B_ECHAM5_r3_1951-2050.nc'
          ),
        precipitation_amount = c(
          'pr_24hc_QM_ICTP-REGCM3_A1B_ECHAM5_r3_1951-2050.nc'
          )),
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      gridfile.path = "/data/koeppen/rcm/adapt.at/ICTP/RegCM/ECHAM5-r3_A1B/postproc/QM",
      gridfile.filename = "tas_dm_QM_ICTP-REGCM3_A1B_ECHAM5_r3_1951-2050.nc",
      resolution = "1km"
      ),
###########################################################################
    'CNRM-RM4.5_ADAPT.AT_QM' = list(
      institute = "WEGC",
      rcm = "Aladin4.5",
      gcm = "ARPEGE",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/koeppen/rcm/adapt.at/CNRM/ALADIN/ARPEGE4.5_A1B/postproc/QM",
      file.name = list(
        air_temperature = c(
          'tas_dm_QM_CNRM-RM4.5_A1B_1951-2050.nc'
          ),
        precipitation_amount = c(
          'pr_24hc_QM_CNRM-RM4.5_A1B_1951-2050.nc'
          )),
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      gridfile.path = "/data/koeppen/rcm/adapt.at/CNRM/ALADIN/ARPEGE4.5_A1B/postproc/QM",
      gridfile.filename = "tas_dm_QM_CNRM-RM4.5_A1B_1951-2050.nc",
      resolution = "1km"
      ),
###########################################################################
    'ETHZ-CLM_ADAPT.AT_QM' = list(
      institute = "WEGC",
      rcm = "CCLM",
      gcm = "HadCM3Q0",
      corrected.data = "TRUE",
      emission.scenario = "A1B",
      file.path.default = "/data/koeppen/rcm/EnergClim/ETHZ/CLM/A1B/postproc/QM",
      file.name = list(
        air_temperature = c(
          'tas_dm_QM_ETHZ-CLM_A1B_1951-2050.nc'
          ),
        precipitation_amount = c(
          'pr_24hc_QM_ETHZ-CLM_A1B_1951-2050.nc'
          )),
      parameters = c(air_temperature = "tas_dm", precipitation_amount = "pr_24hc"),
      gridfile.path = "/data/koeppen/rcm/EnergClim/ETHZ/CLM/A1B/postproc/QM",
      gridfile.filename = "tas_dm_QM_ETHZ-CLM_A1B_1951-2050.nc",
      resolution = "1km"
      ),
###########################################################################


###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###++++++++++++++++++++++++++DATASET: reclip:century+++++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###########################################################################
    'WEGC-CCLM_reclipcentury' = list(
      institute = "WEGC",
      rcm = "CCLM",
      gcm = "ECHAM5",
      emission.scenario = "A1B",
      file.path.default = list(
        historical = '/data/reloclim-tmp/rcm/RECLIP-CENTURY/WEGC/CCLM/ECHAM5/data/daily',
        scenario = '/data/reloclim-tmp/rcm/RECLIP-CENTURY/WEGC/CCLM/ECHAM5/data/daily'),
      file.name = list(
        air_temperature = c(
           historical = list(
          'tas_reclip:century_ECHAM5_historical_2_CCLM4_COSMO4.8_CLM17_day_(19550101-19551231|19[5-9]60101-19[6-9]01231|19[6-9]10101-19[6-9]51231|19960101-19991231).nc'
             ),
          scenario = c('tas_reclip:century_ECHAM5_A1B_2_CCLM4_COSMO4.8_CLM17_day_(20000101-20001231|20[0-9]10101-20[0-9]51231|20[0-9]60101-20[0-9]01231|20960101-21001231).nc'
            )
            ),
         
        precipitation_amount = list(
          historical = c(
            'pr_reclip:century_ECHAM5_historical_2_CCLM4_COSMO4.8_CLM17_day_(19550101-19551231|19[5-9]60101-19[6-9]01231|19[6-9]10101-19[6-9]51231|19960101-19991231).nc'
          ),
          scenario = c(
            'pr_reclip:century_ECHAM5_A1B_2_CCLM4_COSMO4.8_CLM17_day_(20000101-20001231|20[0-9]10101-20[0-9]51231|20[0-9]60101-20[0-9]01231|20960101-21001231).nc' 
            )
          ),
        global_radiation = list(
          historical = c(
            'rsds_reclip:century_ECHAM5_historical_2_CCLM4_COSMO4.8_CLM17_day_(19550101-19551231|19[5-9]60101-19[6-9]01231|19[6-9]10101-19[6-9]51231|19960101-19991231).nc'
          ),
          scenario = c(
            'rsds_reclip:century_ECHAM5_A1B_2_CCLM4_COSMO4.8_CLM17_day_(20000101-20001231|20[0-9]10101-20[0-9]51231|20[0-9]60101-20[0-9]01231|20960101-21001231).nc'
            )
          ),
        wind_speed = list(
          historical = c(
            'sfcWind_reclip:century_ECHAM5_historical_2_CCLM4_COSMO4.8_CLM17_day_(19550101-19551231|19[5-9]60101-19[6-9]01231|19[6-9]10101-19[6-9]51231|19960101-19991231).nc'
          ),
          scenario = c(
            'sfcWind_reclip:century_ECHAM5_A1B_2_CCLM4_COSMO4.8_CLM17_day_(20000101-20001231|20[0-9]10101-20[0-9]51231|20[0-9]60101-20[0-9]01231|20960101-21001231).nc'
            )
          ),
        relative_humidity = list(
          historical = c(
            'hurs_reclip:century_ECHAM5_historical_2_CCLM4_COSMO4.8_CLM17_day_(19550101-19551231|19[5-9]60101-19[6-9]01231|19[6-9]10101-19[6-9]51231|19960101-19991231).nc'
          ),
          scenario = c(
            'hurs_reclip:century_ECHAM5_A1B_2_CCLM4_COSMO4.8_CLM17_day_(20000101-20001231|20[0-9]10101-20[0-9]51231|20[0-9]60101-20[0-9]01231|20960101-21001231).nc'
            )
          )
        ),
     
     
      parameters = c(
        air_temperature = "tas",
        precipitation_amount = "pr",
        global_radiation = 'rsds',
        wind_speed = "sfcWind",
        relative_humidity = "hurs"),
      gridfile.path = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
      gridfile.filename = "WEGC-CCLM_ECHAM5-A1Br2_FIX_10km_orog.nc",
      resolution = "10km"
      ),
###########################################################################
    'AIT-CCLM_reclipcentury' = list(
      institute = "AIT",
      rcm = "CCLM",
      gcm = "HADCM3",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/reclip.century/AIT/CCLM/HadCM3_A1B/direct",
      file.name = list(
        air_temperature = c(
          'AIT-CCLM_HADCM3-A1B_DM_10km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_tas.nc'
          ),
        precipitation_amount = c(
          'AIT-CCLM_HADCM3-A1B_DS_10km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_prt.nc'
          ),
        global_radiation = c(
          'AIT-CCLM_HADCM3-A1B_DM_10km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_rsds.nc'
          ),
        wind_speed = c(
          'AIT-CCLM_HADCM3-A1B_DM_10km_(19[5-8]1_19[6-9]0|1991_2000|20[0-9]1_20[0-9]0|2091_2099)_wss.nc'
          ),
        relative_humidity = c(
          'AIT-CCLM_HADCM3-A1B_DM_10km_(19[5-8]1_19[6-9]0|1991_2000|20[0-9]1_20[0-9]0|2091_2099)_hurs.nc'
          )),
      parameters = c(
        air_temperature = "tas",
        precipitation_amount = "prt",
        global_radiation = 'rsds',
        wind_speed = "wss",
        relative_humidity = "hurs"),
      gridfile.path = "/data/reloclim/rcm/reclip.century/AIT/CCLM/HadCM3_A1B/direct",
      gridfile.filename = "AIT-CCLM_HadCM3-A1B_FIX_10km_orog.nc",
      resolution = "10km"
      ),
###########################################################################
    'ZAMG-CCLM-B1_reclipcentury' = list(
      institute = "ZAMG",
      rcm = "CCLM",
      gcm = "ECHAM5",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_B1/direct"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_B1/direct"),
        global_radiation = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_B1/direct"),
        relative_humidity = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_B1/direct"),
        wind_speed = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_B1/direct")
        ),
      file.name = list(
        air_temperature = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DD_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_tas.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_B1_DM_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_tas.nc'
            )),
        precipitation_amount = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DS_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_prt.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_B1_DS_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_prt.nc'
            )),
        global_radiation = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DD_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_rsds.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_B1_DM_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_rsds.nc'
            )),
        relative_humidity = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DD_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_hur.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_B1_DM_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_hurs.nc'
            )),
        wind_speed = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DD_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_wss.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_B1_DM_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_wss.nc'
            ))
          ),
      parameters = c(
        air_temperature = "tas",
        precipitation_amount = "prt",
        global_radiation = "rsds",
        wind_speed = "wss",
        relative_humidity = "hurs"),
      gridfile.path = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
      gridfile.filename = "WEGC-CCLM_ECHAM5-A1Br2_FIX_10km_orog.nc",
      resolution = "10km"
      ),
###########################################################################
    'ZAMG-CCLM-A2_reclipcentury' = list(
      institute = "ZAMG",
      rcm = "CCLM",
      gcm = "ECHAM5",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_A2/direct"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_A2/direct"),
        global_radiation = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_A2/direct"),
        relative_humidity = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_A2/direct"),
        wind_speed = list(
          historical = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
          scenario = "/data/reloclim/rcm/reclip.century/ZAMG/CCLM/ECHAM5_A2/direct")
        ),
      file.name = list(
        air_temperature = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DD_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_tas.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_A2_DM_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_tas.nc'
            )),
        precipitation_amount = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DS_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_prt.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_A2_DS_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_prt.nc'
            )),
        global_radiation = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DD_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_rsds.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_A2_DM_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_rsds.nc'
            )),
        relative_humidity = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DD_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_hur.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_A2_DM_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_hurs.nc'
            )),
        wind_speed = list(
          historical = c(
            'WEGC-CCLM_ECHAM5-A1Br2_DD_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_wss.nc'
            ),
          scenario = c(
            'ZAMG-CCLM_A2_DM_10km_(19[6-8]1-19[7-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2099)_wss.nc'
            ))
        ),
      parameters = c(
        air_temperature = "tas",
        precipitation_amount = "prt",
        global_radiation = "rsds",
        wind_speed = "wss",
        relative_humidity = "hurs"),
      gridfile.path = "/data/reloclim/rcm/reclip.century/WEGC/CCLM/ECHAM5_A1B/direct",
      gridfile.filename = "WEGC-CCLM_ECHAM5-A1Br2_FIX_10km_orog.nc",
      resolution = "10km"
      ),
###########################################################################
    ## 'BOKU-MM5_reclipcentury' = list(
    ##   institute = "BOKU",
    ##   rcm = "MM5",
    ##   gcm = "ECHAM5",
    ##   emission.scenario = "A1B",
    ##   file.path.default = "/data/reloclim/rcm/reclip.century/BOKU/MM5/ECHAM5_A1B/direct",
    ##   file.name = list(
    ##     air_temperature = c(
    ##       'BOKU-MM5_ECHAM5-A1Br2_DD_10km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_tas.nc'
    ##       ),
    ##     precipitation_amount = c(
    ##       'BOKU-MM5_ECHAM5-A1Br2_DD_10km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_prt.nc'
    ##       ),
    ##     global_radiation = c(
    ##       'BOKU-MM5_ECHAM5-A1Br2_DD_10km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_rsds.nc'
    ##       ),
    ##     wind_speed = c(
    ##       'BOKU-MM5_ECHAM5-A1Br2_DD_10km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_wss.nc'
    ##       ),
    ##     relative_humidity = c(
    ##       'BOKU-MM5_ECHAM5-A1Br2_DD_10km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-20[0-9]0|2091-2100)_hurs.nc'
    ##       )),
    ##   parameters = c(air_temperature = "tas", precipitation_amount = "prt", global_radiation = 'rsds',
    ##     wind_speed = "wss", relative_humidity = "hurs"),
    ##   gridfile.path = "/data/reloclim/rcm/reclip.century/BOKU/MM5/ECHAM5_A1B/direct",
    ##   gridfile.filename = "BOKU-MM5_ECHAM5-A1Br2_DD_10km_1961-1970_tas.nc",
    ##   resolution = "10km"
    ##   ),
###########################################################################



###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++++++++DATASET: ENSEMBLES+++++++++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

### ----------------------------------------------------------------------
### ************************** SCENARIO: ERA40 ***************************
### ----------------------------------------------------------------------

###########################################################################
    'METO-HC_HadRM3Q0_ERA40' = list(
      institute = "METO-HC",
      rcm = "HadRM3",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/ERA40",
      file.name = list(
        air_temperature = c(
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1959-1960_tas.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1991-2000_tas.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_2001-2002_tas.nc'
          ),
        precipitation_amount = c(
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1959-1960_pr.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_1991-2000_pr.nc',
          'METO-HC_HadRM3Q0_CTL_ERA40_DM_25km_2001-2002_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/ERA40",
      gridfile.filename = "METO-HC_HadRM3Q0_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'METO-HC_HadRM3Q16_ERA40' = list(
      institute = "METO-HC",
      rcm = "HadRM3",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/ERA40",
      file.name = list(
        air_temperature = c(
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1959-1960_tas.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1991-2000_tas.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_2001-2002_tas.nc'
          ),
        precipitation_amount = c(
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1959-1960_pr.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_1991-2000_pr.nc',
          'METO-HadRM3Q16_CTL_ERA40_DM_25km_2001-2002_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/ERA40",
      gridfile.filename = "METO-HC_HadRM3Q0_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'METO-HC_HadRM3Q3_ERA40' = list(
      institute = "METO-HC",
      rcm = "HadRM3",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/ERA40",
      file.name = list(
        air_temperature = c(
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1959-1960_tas.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1991-2000_tas.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_2001-2002_tas.nc'
          ),
        precipitation_amount = c(
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1959-1960_pr.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_1991-2000_pr.nc',
          'METO-HadRM3Q3_CTL_ERA40_DM_25km_2001-2002_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/ERA40",
      gridfile.filename = "METO-HC_HadRM3Q0_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'ETHZ-CLM_ERA40' = list(
      institute = "ETHZ",
      rcm = "CLM",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/ERA40",
      file.name = list(
        air_temperature = c(
          'ETHZ-CLM_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'ETHZ-CLM_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'ETHZ-CLM_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'ETHZ-CLM_CTL_ERA40_DM_25km_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'ETHZ-CLM_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'ETHZ-CLM_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'ETHZ-CLM_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'ETHZ-CLM_CTL_ERA40_DM_25km_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/ERA40",
      gridfile.filename = "ETHZ-CLM_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'METNOHIRHAM_ERA40' = list(
      institute = "METNO",
      rcm = "HIRHAM",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/ERA40",
      file.name = list(
        air_temperature = c(
          'METNOHIRHAM_CTR_ERA40_DM_25km_1961-1970_tas.nc',
          'METNOHIRHAM_CTR_ERA40_DM_25km_1971-1980_tas.nc',
          'METNOHIRHAM_CTR_ERA40_DM_25km_1981-1990_tas.nc',
          'METNOHIRHAM_CTR_ERA40_DM_25km_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'METNOHIRHAM_CTR_ERA40_DM_25km_1961-1970_pr.nc',
          'METNOHIRHAM_CTR_ERA40_DM_25km_1971-1980_pr.nc',
          'METNOHIRHAM_CTR_ERA40_DM_25km_1981-1990_pr.nc',
          'METNOHIRHAM_CTR_ERA40_DM_25km_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/ERA40",
      gridfile.filename = "METNOHIRHAM_CTR_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'ICTP-REGCM3_ERA40' = list(
      institute = "ICTP",
      rcm = "RegCM",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ERA40/direct",
      file.name = list(
        air_temperature = c(
          'ICTP-REGCM3_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'ICTP-REGCM3_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'ICTP-REGCM3_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'ICTP-REGCM3_CTL_ERA40_DM_25km_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'ICTP-REGCM3_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'ICTP-REGCM3_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'ICTP-REGCM3_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'ICTP-REGCM3_CTL_ERA40_DM_25km_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ERA40/direct",
      gridfile.filename = "ICTP-REGCM3_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'MPI-M-REMO_ERA40' = list(
      institute = "MPI",
      rcm = "REMO",
      emission.scenario = "",
      gcm = "ERA40",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ERA40",
      file.name = list(
        air_temperature = c(
          'MPI-M-REMO_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'MPI-M-REMO_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'MPI-M-REMO_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'MPI-M-REMO_CTL_ERA40_DM_25km_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'MPI-M-REMO_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'MPI-M-REMO_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'MPI-M-REMO_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'MPI-M-REMO_CTL_ERA40_DM_25km_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ERA40",
      gridfile.filename = "MPI-M-REMO_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'C4IRCA3_ERA40' = list(
      institute = "C4I",
      rcm = "RCA3",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/ERA40",
      file.name = list(
        air_temperature = c(
          'C4IRCA3_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'C4IRCA3_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'C4IRCA3_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'C4IRCA3_CTL_ERA40_DM_25km_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'C4IRCA3_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'C4IRCA3_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'C4IRCA3_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'C4IRCA3_CTL_ERA40_DM_25km_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/ERA40",
      gridfile.filename = "C4IRCA3_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'CNRM-RM4.5_ERA40' = list(
      institute = "CNRM",
      rcm = "RM4.5",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ERA40",
      file.name = list(
        air_temperature = c(
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_1961-1970_tas.nc',
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_1971-1980_tas.nc',
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_1981-1990_tas.nc',
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_1961-1970_pr.nc',
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_1971-1980_pr.nc',
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_1981-1990_pr.nc',
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ERA40",
      gridfile.filename = "CNRM-RM4.5_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'DMI-HIRHAM5_ERA40' = list(
      institute = "DMI",
      rcm = "HIRHAM",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ERA40",
      file.name = list(
        air_temperature = c(
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1958-1960_tas.nc',
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1958-1960_pr.nc',
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'DMI-HIRHAM5_CTL_ERA40_DM_25km_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ERA40",
      gridfile.filename = "DMI-HIRHAM5_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'GKSS-CCLM4.8_ERA40' = list(
      institute = "GKSS",
      rcm = "CLM",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/GKSS/CLM/ERA40",
      file.name = list(
        air_temperature = c(
          'GKSS-CLM_CTL_ERA40_50km_1961-1970_DM_tas.nc',
          'GKSS-CLM_CTL_ERA40_50km_1971-1980_DM_tas.nc',
          'GKSS-CLM_CTL_ERA40_50km_1981-1990_DM_tas.nc',
          'GKSS-CLM_CTL_ERA40_50km_1991-2000_DM_tas.nc'
          ),
        precipitation_amount = c(
          'GKSS-CLM_CTL_ERA40_50km_1961-1970_DM_pr.nc',
          'GKSS-CLM_CTL_ERA40_50km_1971-1980_DM_pr.nc',
          'GKSS-CLM_CTL_ERA40_50km_1981-1990_DM_pr.nc',
          'GKSS-CLM_CTL_ERA40_50km_1991-2000_DM_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/GKSS/CLM/ERA40",
      gridfile.filename = "GKSSCLM_ERA40_50km_FIX_orog.nc",
      resolution = "50km"
      ),
###########################################################################
    'KNMI-RACMO2_ERA40' = list(
      institute = "KNMI",
      rcm = "RACMO",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ERA40",
      file.name = list(
        air_temperature = c(
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1958-1960_tas.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1991-2000_tas.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_2001-2002_tas.nc'
          ),
        precipitation_amount = c(
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1958-1960_pr.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_1991-2000_pr.nc',
          'KNMI-RACMO2_CTL_ERA40_DM_25km_2001-2002_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ERA40",
      gridfile.filename = "KNMI-RACMO2_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'OURANOSMRCC4.2.1_ERA40' = list(
      institute = "OURANOS",
      rcm = "CRCM",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/OURANOS/CRCM/ERA40",
      file.name = list(
        air_temperature = c(
          'OURANOSMRCC4.2.3_CTL_ERA40_DM_25km_CRU_1961-1970_tas.nc',
          'OURANOSMRCC4.2.3_CTL_ERA40_DM_25km_CRU_1971-1980_tas.nc',
          'OURANOSMRCC4.2.3_CTL_ERA40_DM_25km_CRU_1981-1990_tas.nc',
          'OURANOSMRCC4.2.3_CTL_ERA40_DM_25km_CRU_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'OURANOSMRCC4.2.3_CTL_ERA40_DM_25km_CRU_1961-1970_pr.nc',
          'OURANOSMRCC4.2.3_CTL_ERA40_DM_25km_CRU_1971-1980_pr.nc',
          'OURANOSMRCC4.2.3_CTL_ERA40_DM_25km_CRU_1981-1990_pr.nc',
          'OURANOSMRCC4.2.3_CTL_ERA40_DM_25km_CRU_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/OURANOS/CRCM/ERA40",
      gridfile.filename = "OURANOSMRCC4.2.1_CTL_ERA40_FIX_25km_CRU_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'SMHIRCA_ERA40' = list(
      institute = "SMHI",
      rcm = "RCA",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ERA40",
      file.name = list(
        air_temperature = c(
          'SMHIRCA_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'SMHIRCA_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'SMHIRCA_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'SMHIRCA_CTL_ERA40_DM_25km_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'SMHIRCA_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'SMHIRCA_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'SMHIRCA_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'SMHIRCA_CTL_ERA40_DM_25km_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ERA40",
      gridfile.filename = "SMHIRCA_A1B_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'UCLM-PROMES_ERA40' = list(
      institute = "UCLM",
      rcm = "PROMES",
      gcm = "ERA40",
      emission.scenario = "",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/UCLM/PROMES/ERA40",
      file.name = list(
        air_temperature = c(
          'UCLM-PROMES_CTL_ERA40_DM_25km_1961-1970_tas.nc',
          'UCLM-PROMES_CTL_ERA40_DM_25km_1971-1980_tas.nc',
          'UCLM-PROMES_CTL_ERA40_DM_25km_1981-1990_tas.nc',
          'UCLM-PROMES_CTL_ERA40_DM_25km_1991-2000_tas.nc'
          ),
        precipitation_amount = c(
          'UCLM-PROMES_CTL_ERA40_DM_25km_1961-1970_pr.nc',
          'UCLM-PROMES_CTL_ERA40_DM_25km_1971-1980_pr.nc',
          'UCLM-PROMES_CTL_ERA40_DM_25km_1981-1990_pr.nc',
          'UCLM-PROMES_CTL_ERA40_DM_25km_1991-2000_pr.nc'
          )),
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/UCLM/PROMES/ERA40",
      gridfile.filename = "UCLM-PROMES_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################

### ----------------------------------------------------------------------
### *************************** SCENARIO: A1B ****************************
### ----------------------------------------------------------------------

    'METO-HC_HadRM3Q0' = list(
      institute = "METO-HC",
      rcm = "HadRM3",
      gcm = "HadCM3Q0",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/direct",
      file.name = list(
        air_temperature = c(
          'METO-HC_HadRM3Q0_A1B_HadCM3Q0_DM_25km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-2[01][0-9]0)_tas.nc'
          ),
        precipitation_amount = c(
          'METO-HC_HadRM3Q0_A1B_HadCM3Q0_DM_25km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-2[01][0-9]0)_pr.nc'
          ),
        global_radiation = c(
          'METO-HC_HadRM3Q0_A1B_HadCM3Q0_DM_25km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-2[01][0-9]0)_rsds.nc'
          ),
        wind_speed = c(
          'METO-HC_HadRM3Q0_A1B_HadCM3Q0_DM_25km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-2[01][0-9]0)_wss.nc'
          ),
        relative_humidity= c(
          'METO-HC_HadRM3Q0_A1B_HadCM3Q0_DM_25km_(19[5-8]1-19[6-9]0|1991-2000|20[0-9]1-2[01][0-9]0)_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'METO-HC_HadRM3Q0_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'METO-HC_HadRM3Q0_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'METO-HC_HadRM3Q0_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/METO-HC_HadRM3Q0_ERA40_FIX_25km_sftls.ens_min-new.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q0/HadCM3Q0_A1B/direct",
      gridfile.filename = "METO-HC_HadRM3Q0_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'METO-HC_HadRM3Q16' = list(
      institute = "METO-HC",
      rcm = "HadRM3",
      gcm = "HadCM3Q16",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/direct",
      file.name =  list(
        air_temperature = c(
          'METO-HC_HadRM3Q16_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'METO-HC_HadRM3Q16_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'METO-HC_HadRM3Q16_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'METO-HC_HadRM3Q16_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'METO-HC_HadRM3Q16_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'METO-HC_HadRM3Q16_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'METO-HC_HadRM3Q16_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'METO-HC_HadRM3Q16_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/METO-HC_HadRM3Q0_ERA40_FIX_25km_sftls.ens_min-new.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q16/HadCM3Q16_A1B/direct",
      gridfile.filename = "METO-HC_HadRM3Q0_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'METO-HC_HadRM3Q3' = list(
      institute = "METO-HC",
      rcm = "HadRM3",
      gcm = "HadCM3Q3",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/direct",
      file.name = list(
        air_temperature = c(
          'METO-HC_HadRM3Q3_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'METO-HC_HadRM3Q3_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'METO-HC_HadRM3Q3_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'METO-HC_HadRM3Q3_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'METO-HC_HadRM3Q3_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'METO-HC_HadRM3Q3_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'METO-HC_HadRM3Q3_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'METO-HC_HadRM3Q3_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/METO-HC_HadRM3Q0_ERA40_FIX_25km_sftls.ens_min-new.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/HC/HadRM3Q3/HadCM3Q3_A1B/direct",
      gridfile.filename = "METO-HC_HadRM3Q0_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'ETHZ-CLM' = list(
      institute = "ETHZ",
      rcm = "CLM",
      gcm = "HadCM3Q0",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/direct",
      file.name = list(
        air_temperature = c(
          'ETHZ-CLM_SCN_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'ETHZ-CLM_SCN_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'ETHZ-CLM_SCN_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'ETHZ-CLM_SCN_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'ETHZ-CLM_SCN_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'ETHZ-CLM_SCN_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'ETHZ-CLM_SCN_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'ETHZ-CLM_SCN_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'ETHZ-CLM_SCN_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/ETHZ-CLM_SCN_HadCM3Q0_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ETHZ/CLM/HadCM3Q0_A1B/direct",
      gridfile.filename = "ETHZ-CLM_SCN_HadCM3Q0_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'METNOHIRHAM_HadCM3Q0' = list(
      institute = "METNO",
      rcm = "HIRHAM",
      gcm = "HadCM3Q0",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/HadCM3Q0_A1B/direct",
      file.name = list(
        air_temperature = c(
          'METNOHIRHAM_SRESA1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'METNOHIRHAM_SRESA1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'METNOHIRHAM_SRESA1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'METNOHIRHAM_SRESA1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'METNOHIRHAM_SRESA1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'METNOHIRHAM_SRESA1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'METNOHIRHAM_SRESA1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'METNOHIRHAM_SRESA1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'METNOHIRHAM_SRESA1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/METNOHIRHAM_CTR_ERA40_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/HadCM3Q0_A1B/direct",
      gridfile.filename = "METNOHIRHAM_CTR_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'METNOHIRHAM_BCM' = list(
      institute = "METNO",
      rcm = "HIRHAM",
      gcm = "BCM",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/BCM_A1B/direct",
      file.name = list(
        air_temperature = c(
          'METNOHIRHAM_SRESA1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'METNOHIRHAM_SRESA1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'METNOHIRHAM_SRESA1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'METNOHIRHAM_SRESA1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity = c(
          'METNOHIRHAM_SRESA1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux = c(
          'METNOHIRHAM_SRESA1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'METNOHIRHAM_SRESA1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'METNOHIRHAM_SRESA1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'METNOHIRHAM_SRESA1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/METNOHIRHAM_CTR_ERA40_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/METNO/HIRHAM/BCM_A1B/direct",
      gridfile.filename = "METNOHIRHAM_CTR_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'ICTP-REGCM3' = list(
      institute = "ICTP",
      rcm = "RegCM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/direct",
      file.name = list(
        air_temperature = c(
          'ICTP-REGCM3_A1B_ECHAM5_r3_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'ICTP-REGCM3_A1B_ECHAM5_r3_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'ICTP-REGCM3_A1B_ECHAM5_r3_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'ICTP-REGCM3_A1B_ECHAM5_r3_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'ICTP-REGCM3_A1B_ECHAM5_r3_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'ICTP-REGCM3_A1B_ECHAM5_r3_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'ICTP-REGCM3_A1B_ECHAM5_r3_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'ICTP-REGCM3_A1B_ECHAM5_r3_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'ICTP-REGCM3_A1B_ECHAM5_r3_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/ICTP-REGCM3_A1B_ECHAM5_r3_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/ICTP/RegCM/ECHAM5-r3_A1B/direct",
      gridfile.filename = "ICTP-REGCM3_A1B_ECHAM5_r3_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'MPI-M-REMO' = list(
      institute = "MPI",
      rcm = "REMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/direct",
      file.name = list(
        air_temperature = c(
          'MPI-M-REMO_SCN_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'MPI-M-REMO_SCN_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'MPI-M-REMO_SCN_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'MPI-M-REMO_SCN_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'MPI-M-REMO_SCN_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'MPI-M-REMO_SCN_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'MPI-M-REMO_SCN_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'MPI-M-REMO_SCN_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'MPI-M-REMO_SCN_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/MPI-M-REMO_CTL_ERA40_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/MPI/REMO/ECHAM5-r3_A1B/direct",
      gridfile.filename = "MPI-M-REMO_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'C4IRCA3' = list(
      institute = "C4I",
      rcm = "RCA3",
      gcm = "HadCM3Q16",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/direct",
      file.name = list(
        air_temperature = c(
          'C4IRCA3_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'C4IRCA3_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'C4IRCA3_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'C4IRCA3_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'C4IRCA3_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'C4IRCA3_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'C4IRCA3_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'C4IRCA3_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'C4IRCA3_A1B_HadCM3Q16_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/C4IRCA3_CTL_ERA40_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/C4I/RCA/HadCM3Q16_A1B/direct",
      gridfile.filename = "C4IRCA3_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km",
      calendar = "360_days",
      count.first.time.value = "julian"
      ),
###########################################################################
    'CNRM-RM5.1' = list(
      institute = "CNRM",
      rcm = "RM5.1",
      gcm = "ARPEGE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/direct",
      file.name = list(
        air_temperature = c(
          'CNRM-RM5.1_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'CNRM-RM5.1_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'CNRM-RM5.1_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'CNRM-RM5.1_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'CNRM-RM5.1_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'CNRM-RM5.1_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'CNRM-RM5.1_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'CNRM-RM5.1_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'CNRM-RM5.1_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/CNRM-RM4.5_SCN_ARPEGE_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE5.1_A1B/direct",
      gridfile.filename = "CNRM-RM4.5_SCN_ARPEGE_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'CNRM-RM4.5' = list(
      institute = "CNRM",
      rcm = "RM4.5",
      gcm = "ARPEGE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE4.5_A1B/direct",
      file.name = list(
        air_temperature = c(
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          NA
          ),
        air_temperature_minimum= c(
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'CNRM-RM4.5_SCN_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/CNRM-RM4.5_SCN_ARPEGE_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/CNRM/ALADIN/ARPEGE4.5_A1B/direct",
      gridfile.filename = "CNRM-RM4.5_SCN_ARPEGE_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'DMI-HIRHAM5_ARPEGE' = list(
      institute = "DMI",
      rcm = "HIRHAM",
      gcm = "ARPEGE",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/direct",
      file.name = list(
        air_temperature = c(
          'DMI-HIRHAM5_A1B_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'DMI-HIRHAM5_A1B_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'DMI-HIRHAM5_A1B_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'DMI-HIRHAM5_A1B_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'DMI-HIRHAM5_A1B_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'DMI-HIRHAM5_A1B_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'DMI-HIRHAM5_A1B_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'DMI-HIRHAM5_A1B_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'DMI-HIRHAM5_A1B_ARPEGE_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/DMI-HIRHAM5_CTL_ERA40_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ARPEGE_A1B/direct",
      gridfile.filename = "DMI-HIRHAM5_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'DMI-HIRHAM5_ECHAM5' = list(
      institute = "DMI",
      rcm = "HIRHAM",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/direct",
      file.name = list(
        air_temperature = c(
          'DMI-HIRHAM5_A1B_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'DMI-HIRHAM5_A1B_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'DMI-HIRHAM5_A1B_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'DMI-HIRHAM5_A1B_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'DMI-HIRHAM5_A1B_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'DMI-HIRHAM5_A1B_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'DMI-HIRHAM5_A1B_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'DMI-HIRHAM5_A1B_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'DMI-HIRHAM5_A1B_ECHAM5_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/DMI-HIRHAM5_CTL_ERA40_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/ECHAM5-r3_A1B/direct",
      gridfile.filename = "DMI-HIRHAM5_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'DMI-HIRHAM5_BCM' = list(
      institute = "DMI",
      rcm = "HIRHAM",
      gcm = "BCCR-BCM2.0",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/direct",
      file.name = list(
        air_temperature = c(
          'DMI-HIRHAM5_BCM_A1B_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'DMI-HIRHAM5_BCM_A1B_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'DMI-HIRHAM5_BCM_A1B_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'DMI-HIRHAM5_BCM_A1B_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'DMI-HIRHAM5_BCM_A1B_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'DMI-HIRHAM5_BCM_A1B_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'DMI-HIRHAM5_BCM_A1B_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'DMI-HIRHAM5_BCM_A1B_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'DMI-HIRHAM5_BCM_A1B_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/DMI-HIRHAM5_CTL_ERA40_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/DMI/HIRHAM/BCM_A1B/direct",
      gridfile.filename = "DMI-HIRHAM5_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
### TROUBLESOME: 1961 doesnt exist, instead its 1963!!
### VERY TROUBLESOME! date units claim to be seconds since, but that cant be, as
### those numbers are way too small and if treated as days since, the models start
### at rubbish month (march, or april or july...)
### TODO: maybe put here some of these features manually (and if not entered
### manually, then try to get it automatically)
    'GKSS-CCLM4.8' = list(
      institute = "GKSS",
      rcm = "CLM",
      gcm = "IPSL-CM4",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/GKSS/CLM/IPSL_A1B/direct",
      file.name = list(
        air_temperature = c(
          'GKSS-CCLM4.8_IPSL_DM_IPSL-25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'GKSS-CCLM4.8_IPSL_DM_IPSL-25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        wind_speed = c(
          'GKSS-CCLM4.8_IPSL_DM_IPSL-25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        global_radiation = NA,
        relative_humidity= NA,
        surface_upward_sensible_heat_flux = NA,
        air_temperature_minimum= c(
          'GKSS-CCLM4.8_IPSL_DM_IPSL-25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'GKSS-CCLM4.8_IPSL_DM_IPSL-25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/GKSS-CCLM4.8_IPSL_FIX_ipsl03_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/GKSS/CLM/IPSL_A1B/direct",
      gridfile.filename = "GKSS-CCLM4.8_IPSL_FIX_ipsl03_orog.nc",
      resolution = "25km",
      time.units = "days since 1950-01-06 00:00:00",
      count.first.time.value = "julian"
      ),
###########################################################################
    'KNMI-RACMO2' = list(
      institute = "KNMI",
      rcm = "RACMO",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/direct",
      file.name = list(
        air_temperature = c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/KNMI-RACMO2_A1B_ECHAM5-r3_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/KNMI/RACMO/ECHAM5-r3_A1B/direct",
      gridfile.filename = "KNMI-RACMO2_A1B_ECHAM5-r3_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'OURANOSMRCC4.2.1' = list(
      institute = "OURANOS",
      rcm = "CRCM",
      gcm = "CGCM3",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/OURANOS/CRCM/CGCM3_A1B/direct",
      file.name = list(
        air_temperature = c(
          'OURANOSMRCC4.2.1_A1B_CGCM3_DM_25km_CRU_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'OURANOSMRCC4.2.1_A1B_CGCM3_DM_25km_CRU_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'OURANOSMRCC4.2.1_A1B_CGCM3_DM_25km_CRU_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'OURANOSMRCC4.2.1_A1B_CGCM3_DM_25km_CRU_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'OURANOSMRCC4.2.1_A1B_CGCM3_DM_25km_CRU_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'OURANOSMRCC4.2.1_A1B_CGCM3_DM_25km_CRU_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'OURANOSMRCC4.2.1_A1B_CGCM3_DM_25km_CRU_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'OURANOSMRCC4.2.1_A1B_CGCM3_DM_25km_CRU_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'OURANOSMRCC4.2.1_A1B_CGCM3_DM_25km_CRU_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/OURANOSMRCC4.2.1_CTL_ERA40_FIX_25km-CRU_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/OURANOS/CRCM/CGCM3_A1B/direct",
      gridfile.filename = "OURANOSMRCC4.2.1_CTL_ERA40_FIX_25km_CRU_orog.nc",
      ##calendar = "365_days",
      resolution = "25km"
      ),
###########################################################################
    'SMHIRCA_BCM' = list(
      institute = "SMHI",
      rcm = "RCA",
      gcm = "BCCR-BCM2.0",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/direct",
      file.name = list(
        air_temperature =
        'SMHIRCA_A1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc',
        precipitation_amount =
        'SMHIRCA_A1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc',
        global_radiation =
        'SMHIRCA_A1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc',
        wind_speed =
        'SMHIRCA_A1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc',
        relative_humidity =
        'SMHIRCA_A1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc',
        surface_upward_sensible_heat_flux =
        'SMHIRCA_A1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc',
        air_temperature_minimum= c(
          'SMHIRCA_A1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'SMHIRCA_A1B_BCM_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/SMHIRCA_A1B_BCM_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/BCM_A1B/direct",
      gridfile.filename = "SMHIRCA_A1B_BCM_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'SMHIRCA_ECHAM5-r3' = list(
      institute = "SMHI",
      rcm = "RCA",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/direct",
      file.name = list(
        air_temperature = c(
          'SMHIRCA_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'SMHIRCA_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'SMHIRCA_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'SMHIRCA_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'SMHIRCA_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'SMHIRCA_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'SMHIRCA_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'SMHIRCA_A1B_ECHAM5-r3_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/SMHIRCA_A1B_BCM_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/ECHAM5-r3_A1B/direct",
      gridfile.filename = "SMHIRCA_A1B_BCM_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'SMHIRCA_HadCM3Q3' = list(
      institute = "SMHI",
      rcm = "RCA",
      gcm = "HadCM3Q3",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/direct",
      file.name = list(
        air_temperature = c(
          'SMHIRCA_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'SMHIRCA_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'SMHIRCA_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'SMHIRCA_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'SMHIRCA_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'SMHIRCA_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'SMHIRCA_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'SMHIRCA_A1B_HadCM3Q3_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/SMHIRCA_A1B_BCM_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/SMHI/RCA/HadCM3Q3_A1B/direct",
      gridfile.filename = "SMHIRCA_A1B_HadCM3Q3_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'UCLM-PROMES' = list(
      institute = "UCLM",
      rcm = "PROMES",
      gcm = "HadCM3Q0",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/UCLM/PROMES/HadCM3Q0_A1B/direct",
      file.name = list(
        air_temperature = c(
          'UCLM-PROMES_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'UCLM-PROMES_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'UCLM-PROMES_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'UCLM-PROMES_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'UCLM-PROMES_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'UCLM-PROMES_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'UCLM-PROMES_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'UCLM-PROMES_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'UCLM-PROMES_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/UCLM-PROMES_CTL_ERA40_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/UCLM/PROMES/HadCM3Q0_A1B/direct",
      gridfile.filename = "UCLM-PROMES_CTL_ERA40_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################
    'VMGO-RRCM' = list(
      institute = "VMGO",
      rcm = "RRCM",
      gcm = "HadCM3Q0",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES/VMGO/RRCM/HadCM3Q0_A1B/direct",
      file.name = list(
        air_temperature = c(
          'VMGO-RRCM_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'VMGO-RRCM_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'VMGO-RRCM_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'VMGO-RRCM_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'VMGO-RRCM_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'VMGO-RRCM_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'VMGO-RRCM_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'VMGO-RRCM_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'VMGO-RRCM_A1B_HadCM3Q0_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/VMGO-RRCM_A1B_HadCM3Q0_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES/VMGO/RRCM/HadCM3Q0_A1B/direct",
      gridfile.filename = "VMGO-RRCM_A1B_HadCM3Q0_FIX_25km_orog.nc",
      resolution = "25km"
      ),
###########################################################################

###########################################################################
    'KNMI-RACMO2_MIROC' = list(
      institute = "KNMI",
      rcm = "RACMO",
      gcm = "MIROC3-2",
      gcm.run = 1,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim-tmp/rcm/ENSEMBLES_from_KNMI",
      file.name = list(
        air_temperature = c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_25km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_25km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_25km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_25km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_25km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_25km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_25km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_25km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_25km_[0-9]{4}-[0-9]{4}_ts.nc'
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim-tmp/rcm/ENSEMBLES_from_KNMI/KNMI-RACMO2_A1B_MIROC3.2-hires_FIX_25km_sftls.nc",
      gridfile.path = "/data/reloclim-tmp/rcm/ENSEMBLES_from_KNMI",
      gridfile.filename = "KNMI-RACMO2_A1B_MIROC3.2-hires_FIX_25km_orog.nc",
      resolution = "25km"
      ),

      
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++++DATASET: ENSEMBLES 50km+++++++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

###########################################################################
    'KNMI-RACMO2_ECHAM5-r1_50km' = list(
      institute = "KNMI",
      rcm = "RACMO2",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 1,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_ECHAM5-r1",
      file.name = list(
        air_temperature = c(
          'KNMI-RACMO2_A1B_ECHAM5-r1_DM_50km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'KNMI-RACMO2_A1B_ECHAM5-r1_DM_50km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'KNMI-RACMO2_A1B_ECHAM5-r1_DM_50km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'KNMI-RACMO2_A1B_ECHAM5-r1_DM_50km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'KNMI-RACMO2_A1B_ECHAM5-r1_DM_50km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'KNMI-RACMO2_A1B_ECHAM5-r1_DM_50km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'KNMI-RACMO2_A1B_ECHAM5-r1_DM_50km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'KNMI-RACMO2_A1B_ECHAM5-r1_DM_50km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_ECHAM5-r1/KNMI-RACMO2_A1B_ECHAM5-r1_FIX_50km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_ECHAM5-r1",
      gridfile.filename = "KNMI-RACMO2_A1B_ECHAM5-r1_FIX_50km_orog.nc",
      resolution = "50km"
      ),
###########################################################################
    'KNMI-RACMO2_ECHAM5-r2_50km' = list(
      institute = "KNMI",
      rcm = "RACMO2",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 2,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_ECHAM5-r2",
      file.name = list(
        air_temperature = c(
          'KNMI-RACMO2_A1B_ECHAM5-r2_DM_50km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'KNMI-RACMO2_A1B_ECHAM5-r2_DM_50km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'KNMI-RACMO2_A1B_ECHAM5-r2_DM_50km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'KNMI-RACMO2_A1B_ECHAM5-r2_DM_50km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'KNMI-RACMO2_A1B_ECHAM5-r2_DM_50km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'KNMI-RACMO2_A1B_ECHAM5-r2_DM_50km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'KNMI-RACMO2_A1B_ECHAM5-r2_DM_50km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'KNMI-RACMO2_A1B_ECHAM5-r2_DM_50km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_ECHAM5-r2/KNMI-RACMO2_A1B_ECHAM5-r2_FIX_50km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_ECHAM5-r2",
      gridfile.filename = "KNMI-RACMO2_A1B_ECHAM5-r2_FIX_50km_orog.nc",
      resolution = "50km"
      ),
###########################################################################
    'KNMI-RACMO2_ECHAM5-r3_50km' = list(
      institute = "KNMI",
      rcm = "RACMO2",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_ECHAM5-r3",
      file.name = list(
        air_temperature = c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_50km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_50km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_50km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_50km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_50km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_50km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_50km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'KNMI-RACMO2_A1B_ECHAM5-r3_DM_50km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_ECHAM5-r3/KNMI-RACMO2_A1B_ECHAM5-r3_FIX_50km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_ECHAM5-r3",
      gridfile.filename = "KNMI-RACMO2_A1B_ECHAM5-r3_FIX_50km_orog.nc",
      resolution = "50km"
      ),

###########################################################################
    'KNMI-RACMO22_MIROC3-1_50km' = list(
      institute = "KNMI",
      rcm = "RACMO22",
      gcm = "MIROC3.1",
      gcm.run = 1,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_MIROC",
      file.name = list(
        air_temperature = c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_50km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_50km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_50km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_50km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_50km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_50km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_50km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'KNMI-RACMO2_A1B_MIROC3.2-hires_DM_50km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_MIROC/KNMI-RACMO2_A1B_MIROC3.2-hires_FIX_50km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES_50km/KNMI_MIROC",
      gridfile.filename = "KNMI-RACMO2_A1B_MIROC3.2-hires_FIX_50km_orog.nc",
      resolution = "50km"
      ),

###########################################################################
    'SMHIRCA_ECHAM5-r3_50km' = list(
      institute = "SMHI",
      rcm = "RCA",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcm/ENSEMBLES_50km/SMHI",
      file.name = list(
        air_temperature = c(
          'SMHIRCA_A1B_ECHAM5_DM_50km_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'SMHIRCA_A1B_ECHAM5_DM_50km_[0-9]{4}-[0-9]{4}_pr.nc'
          ),
        global_radiation = c(
          'SMHIRCA_A1B_ECHAM5_DM_50km_[0-9]{4}-[0-9]{4}_rsds.nc'
          ),
        wind_speed = c(
          'SMHIRCA_A1B_ECHAM5_DM_50km_[0-9]{4}-[0-9]{4}_wss.nc'
          ),
        relative_humidity= c(
          'SMHIRCA_A1B_ECHAM5_DM_50km_[0-9]{4}-[0-9]{4}_hurs.nc'
          ),
        surface_upward_sensible_heat_flux= c(
          'SMHIRCA_A1B_ECHAM5_DM_50km_[0-9]{4}-[0-9]{4}_hfss.nc'
          ),
        air_temperature_minimum= c(
          'SMHIRCA_A1B_ECHAM5_DM_50km_[0-9]{4}-[0-9]{4}_tasmin.nc'
          ),
        air_temperature_maximum= c(
          'SMHIRCA_A1B_ECHAM5_DM_50km_[0-9]{4}-[0-9]{4}_tasmax.nc'
          ),
        surface_temperature= c(
          NA
          )
        ),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcm/ENSEMBLES_50km/SMHI/SMHIRCA_A1B_ECHAM5_FIX_50km_sftls.nc",
      gridfile.path = "/data/reloclim/rcm/ENSEMBLES_50km/SMHI",
      gridfile.filename = "SMHIRCA_A1B_ECHAM5_FIX_50km_orog.nc",
      resolution = "50km"
      ),





###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++ DATASET: ENSEMBLES GCMs (those apart from the cmip3 ensmble)++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

    'HadCM3Q0' = list(
      rcm = "",
      gcm = "HadCM3Q0",
      gcm.run = 1,
      institute = "METO-HC",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcu/geh/data/ensembles/gcm/HadCM3Q0",
      file.name = list(
        air_temperature = c(
          'METO-HC_HadCM3Q0_A1B_DM_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'METO-HC_HadCM3Q0_A1B_DM_[0-9]{4}-[0-9]{4}_pr.nc'
          )),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/METO-HC_HadCM3Q0_A1B_FIX_sftls.nc",
      gridfile.path = "/data/reloclim/rcu/geh/data/ensembles/gcm/HadCM3Q0", 
      gridfile.filename = "METO-HC_HadCM3Q0_A1B_DM_1951-1960_tas.nc", 
      resolution = ""
      ),
###########################################################################
    'HadCM3Q3' = list(
      rcm = "",
      gcm = "HadCM3Q3",
      gcm.run = 1,
      institute = "METO-HC",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcu/geh/data/ensembles/gcm/HadCM3Q3",
      file.name = list(
        air_temperature = c(
          'METO-HC_HadCM3Q3_A1B_DM_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'METO-HC_HadCM3Q3_A1B_DM_[0-9]{4}-[0-9]{4}_pr.nc'
          )),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/METO-HC_HadCM3Q0_A1B_FIX_sftls.nc",
      gridfile.path = '/data/reloclim/rcu/geh/data/ensembles/gcm/HadCM3Q3', 
      gridfile.filename = 'METO-HC_HadCM3Q3_A1B_DM_1951-1960_tas.nc', 
      resolution = ""
      ),
###########################################################################
    'HadCM3Q16' = list(
      rcm = "",
      gcm = "HadCM3Q16",
      gcm.run = 1,
      institute = "METO-HC",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcu/geh/data/ensembles/gcm/HadCM3Q16",
      file.name = list(
        air_temperature = c(
          'METO-HC_HadCM3Q16_A1B_DM_[0-9]{4}-[0-9]{4}_tas.nc'
          ),
        precipitation_amount = c(
          'METO-HC_HadCM3Q16_A1B_DM_[0-9]{4}-[0-9]{4}_pr.nc'
          )),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/METO-HC_HadCM3Q0_A1B_FIX_sftls.nc",
      gridfile.path = "/data/reloclim/rcu/geh/data/ensembles/gcm/HadCM3Q16", 
      gridfile.filename = "METO-HC_HadCM3Q16_A1B_DM_1951-1960_tas.nc", 
      resolution = ""
      ),
###########################################################################
    'ARPEGE4.5' = list(
      rcm = "",
      gcm = "ARPEGE4.5",
      gcm.run = 1,
      institute = "CNRM",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcu/geh/data/ensembles/gcm/ARPEGE4.5",
      file.name = list(
        air_temperature = list(
          historical = "ARPEGE4.5_CTL_CNRM-CM3_MM_50km-CRU_1950-2000_tas.nc",
          scenario = "ARPEGE4.5_SCN_CNRM-CM3_MM_50km-CRU_2001-2100_tas.nc"),
        precipitation_amount = list(
          historical = "ARPEGE4.5_CTL_CNRM-CM3_MM_50km-CRU_1950-2000_pr.nc",
          scenario = "ARPEGE4.5_SCN_CNRM-CM3_MM_50km-CRU_2001-2100_pr.nc")),
      land.mask.name = "sftls",
      land.mask = "/data/reloclim/rcu/geh/data/ensembles/landmask/ARPEGE4.5_CTL_CNRM-CM3_FIX_50km-CRU_sftls.nc",
      gridfile.path = "/data/reloclim/rcu/geh/data/ensembles/gcm/ARPEGE4.5", 
      gridfile.filename = "ARPEGE4.5_CTL_CNRM-CM3_FIX_50km-CRU_orog.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'CGCM3.1' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 4,
      institute = "CCCma",
      emission.scenario = "A1B",
      file.path.default = "/data/reloclim/rcu/geh/data/ensembles/gcm/CGCM3",
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc",
          scenario = "tas_a1_sresa1b_4_cgcm3.1_t47_2001_2100.nc"),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc",
          scenario = "pr_a1_sresa1b_4_cgcm3.1_t47_2001_2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcu/geh/data/ensembles/gcm/CGCM3", 
      gridfile.filename = "orog_invariant_cgcm3.1_t47.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################






      
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++++DATASET: EUROCORDEX 0.11+++++++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 ###########################################################################

### ----------------------------------------------------------------------
### *************************** SCENARIO: rcp26 *****************************
### ----------------------------------------------------------------------
    'MPI-REMO_011_ESM-LR_rcp2.6' = list(
      institute = "CSC",
      rcm = "REMO",
      gcm = "ESM-LR",
      emission.scenario = "rcp2.6",
      file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/CSC/REMO/MPI-ESM-LR/direct/daily",
      file.name = list(
        air_temperature = list(
          historical = c(
            "europa011_remo_019_535_historical_r1i1p1_n_c167_T2M_1950_2005.nc"
            ),
          scenario = c(
            "europa011_remo_019_536_rcp26_r1i1p1_n_c167_T2M_2006_2100.nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "europa011_remo_019_535_historical_r1i1p1_n_c260_PRECIP_1950_2005.nc"
            ),
          scenario = c(
            "europa011_remo_019_536_rcp26_r1i1p1_n_c260_PRECIP_2006_2100.nc"
            )
          )
        ),
      land.mask.name = "var172",
      land.mask = "/data/reloclim-tmp/rcm/EURO-CORDEX/CSC/REMO/MPI-ESM-LR/direct/daily/europa011_cordex_172_land_sea_mask.nc",
      gridfile.path = "/data/reloclim-tmp/rcu/thm/EURO_CORDEX/CSC",
      gridfile.filename = "europa011_cordex_lat_lon.nc",
      resolution = "12.5km",
      what.timesteps = "daily",
      parameters = c(air_temperature = "var167", precipitation_amount= "var260")
      ),
################################################################################

    'EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1' = list(
      institute = "SMHI",
      rcm = "RCA4",
      gcm = "EC-EARTH",
      emission.scenario = "rcp2.6",
      file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/SMHI/RCA4/EC-EARTH/direct/daily",
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19710101-19751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19760101-19801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19810101-19851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19860101-19901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19910101-19951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19960101-20001231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20060101-20101231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20110101-20151231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20160101-20201231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20210101-20251231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20260101-20301231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20310101-20351231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20360101-20401231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20410101-20451231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20460101-20501231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20510101-20551231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20560101-20601231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20610101-20651231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20660101-20701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20710101-20751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20760101-20801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20810101-20851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20860101-20901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20910101-20951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20960101-21001231.nc" 
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19710101-19751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19760101-19801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19810101-19851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19860101-19901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19910101-19951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19960101-20001231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20060101-20101231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20110101-20151231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20160101-20201231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20210101-20251231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20260101-20301231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20310101-20351231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20360101-20401231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20410101-20451231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20460101-20501231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20510101-20551231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20560101-20601231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20610101-20651231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20660101-20701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20710101-20751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20760101-20801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20810101-20851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20860101-20901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20910101-20951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_20960101-21001231.nc" 
            )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim-tmp/rcu/rew/SMHI_CORDEX/sftlf_EUR-11_ECMWF-ERAINT_evaluation_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/SMHI/RCA4/EC-EARTH/direct/daily",
         gridfile.filename = "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc",
         resolution = "12.5km",
         what.timesteps = "daily"
      ),
  ###########################################################################

### ----------------------------------------------------------------------
### *************************** SCENARIO: rcp45 *****************************
### ----------------------------------------------------------------------
 ## REMO NOT WORKING SO FAR!
    ## 
    'MPI-REMO_011_ESM-LR_rcp4.5' = list(
      institute = "CSC",
      rcm = "REMO",
      gcm = "ESM-LR",
      emission.scenario = "rcp4.5",
      file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/CSC/REMO/MPI-ESM-LR/direct/daily",
      file.name = list(
        air_temperature = list(
          historical = c(
            "europa011_remo_019_535_historical_r1i1p1_n_c167_T2M_1950_2005.nc"
            ),
          scenario = c(
            "europa011_remo_019_537_rcp45_r1i1p1_n_c167_T2M_2006_2100.nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "europa011_remo_019_535_historical_r1i1p1_n_c260_PRECIP_1950_2005.nc"
            ),
          scenario = c(
            "europa011_remo_019_537_rcp45_r1i1p1_n_c260_PRECIP_2006_2100.nc"
            )
          )
        ),
      land.mask.name = "var172",
      land.mask = "/data/reloclim-tmp/rcm/EURO-CORDEX/CSC/REMO/MPI-ESM-LR/direct/daily/europa011_cordex_172_land_sea_mask.nc",
      gridfile.path = "/data/reloclim-tmp/rcu/thm/EURO_CORDEX/CSC",
      gridfile.filename = "europa011_cordex_lat_lon.nc",
      resolution = "12.5km",
      what.timesteps = "daily",
      parameters = c(air_temperature = "var167", precipitation_amount= "var260")
      ),
################################################################################
 'EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1' = list(
      institute = "MF",
      rcm = "ARPEGE51",
      gcm = "CNRM-CM5",
      emission.scenario = "rcp4.5",
   file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/MetFrance/ARPEGE/CNRM-CM5/direct/daily",
   file.name = list(
     air_temperature = list(
       historical = c(
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19510101-19551231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19560101-19601231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19610101-19651231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19660101-19701231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19710101-19751231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19760101-19801231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19810101-19851231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19860101-19901231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19910101-19951231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19960101-20001231.nc",
         "tas_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_20010101-20051231.nc"
         ),
       scenario = c(
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20060101-20101231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20110101-20151231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20160101-20201231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20210101-20251231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20260101-20301231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20310101-20351231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20360101-20401231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20410101-20451231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20460101-20501231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20510101-20551231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20560101-20601231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20610101-20651231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20660101-20701231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20710101-20751231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20760101-20801231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20810101-20851231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20860101-20901231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20910101-20951231.nc",
         "tas_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20960101-21001231.nc"
         )
       ),
     precipitation_amount = list(
          historical = c(
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19510101-19551231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19560101-19601231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19610101-19651231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19660101-19701231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19710101-19751231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19760101-19801231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19810101-19851231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19860101-19901231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19910101-19951231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19960101-20001231.nc",
            "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_20010101-20051231.nc"
            ),
          scenario = c(
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20060101-20101231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20110101-20151231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20160101-20201231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20210101-20251231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20260101-20301231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20310101-20351231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20360101-20401231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20410101-20451231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20460101-20501231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20510101-20551231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20560101-20601231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20610101-20651231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20660101-20701231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20710101-20751231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20760101-20801231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20810101-20851231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20860101-20901231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20910101-20951231.nc",
            "pr_EUR-11_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20960101-21001231.nc"                 )
          )
        ),
   land.mask.name = "sftlf",
   land.mask = "/data/reloclim-tmp/rcm/EURO-CORDEX/MetFrance/ARPEGE/CNRM-CM5/direct/daily/sftlf_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_FIX.nc",
   gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/MetFrance/ARPEGE/CNRM-CM5/direct/daily",
   gridfile.filename = "pr_EUR-11_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19510101-19551231.nc",
   lonlat.var.name = c(longitude="longitude", latitude="latitude"),
   resolution = "12.5km",
   what.timesteps = "daily"
   ),
  ###########################################################################
     
    'EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1' = list(
      institute = "SMHI",
      rcm = "RCA4",
      gcm = "CNRM-CM5",
      emission.scenario = "rcp4.5",
      file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/SMHI/RCA4/CNRM-CM5/direct/daily",
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19710101-19751231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19760101-19801231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19810101-19851231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19860101-19901231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19910101-19951231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19960101-20001231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20060101-20101231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20110101-20151231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20160101-20201231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20210101-20251231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20260101-20301231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20310101-20351231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20360101-20401231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20410101-20451231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20460101-20501231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20510101-20551231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20560101-20601231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20610101-20651231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20660101-20701231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20710101-20751231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20760101-20801231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20810101-20851231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20860101-20901231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20910101-20951231.nc", 
            "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20960101-21001231.nc" 
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc", 
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19710101-19751231.nc", 
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19760101-19801231.nc", 
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19810101-19851231.nc", 
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19860101-19901231.nc", 
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19910101-19951231.nc", 
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19960101-20001231.nc", 
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_20010101-20051231.nc"
            ),
           scenario = c(
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20060101-20101231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20110101-20151231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20160101-20201231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20210101-20251231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20260101-20301231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20310101-20351231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20360101-20401231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20410101-20451231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20460101-20501231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20510101-20551231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20560101-20601231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20610101-20651231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20660101-20701231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20710101-20751231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20760101-20801231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20810101-20851231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20860101-20901231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20910101-20951231.nc", 
             "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_day_20960101-21001231.nc" 
             )
          )
        ),
        land.mask.name = "sftlf",
       land.mask = "/data/reloclim-tmp/rcu/rew/SMHI_CORDEX/sftlf_EUR-11_ECMWF-ERAINT_evaluation_r0i0p0_SMHI-RCA4_v1_fx.nc",
        gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/SMHI/RCA4/CNRM-CM5/direct/daily",
        gridfile.filename = "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc",
        resolution = "12.5km",
        what.timesteps = "daily"
      ),
  ###########################################################################
   'EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1' = list(
      institute = "SMHI",
      rcm = "RCA4",
      gcm = "EC-EARTH",
      emission.scenario = "rcp4.5",
      file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/SMHI/RCA4/EC-EARTH/direct/daily",
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19710101-19751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19760101-19801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19810101-19851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19860101-19901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19910101-19951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19960101-20001231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20060101-20101231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20110101-20151231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20160101-20201231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20210101-20251231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20260101-20301231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20310101-20351231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20360101-20401231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20410101-20451231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20460101-20501231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20510101-20551231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20560101-20601231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20610101-20651231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20660101-20701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20710101-20751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20760101-20801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20810101-20851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20860101-20901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20910101-20951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20960101-21001231.nc" 
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19710101-19751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19760101-19801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19810101-19851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19860101-19901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19910101-19951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19960101-20001231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20060101-20101231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20110101-20151231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20160101-20201231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20210101-20251231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20260101-20301231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20310101-20351231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20360101-20401231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20410101-20451231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20460101-20501231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20510101-20551231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20560101-20601231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20610101-20651231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20660101-20701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20710101-20751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20760101-20801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20810101-20851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20860101-20901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20910101-20951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_20960101-21001231.nc" 
            )
          )
        ),
     land.mask.name = "sftlf",
     land.mask = "/data/reloclim-tmp/rcu/rew/SMHI_CORDEX/sftlf_EUR-11_ECMWF-ERAINT_evaluation_r0i0p0_SMHI-RCA4_v1_fx.nc",
        gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/SMHI/RCA4/EC-EARTH/direct/daily",
        gridfile.filename = "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc",
        resolution = "12.5km",
        what.timesteps = "daily"
      ),
  ###########################################################################
     'EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1' = list(
       institute = "SMHI",
       rcm = "RCA4",
       gcm = "HadGEM2-ES",
       emission.scenario = "rcp4.5",
       file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily",
           scenario =  "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily",
           scenario =  "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily")),
       file.name = list(
         air_temperature = list(
           historical = c(
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19700101-19701230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19710101-19751230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19760101-19801230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19810101-19851230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19860101-19901230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19910101-19951230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19960101-20001230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_20010101-20051230.nc" 
             ),
           scenario = c(
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20060101-20101230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20110101-20151230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20160101-20201230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20210101-20251230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20260101-20301230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20310101-20351230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20360101-20401230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20410101-20451230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20460101-20501230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20510101-20551230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20560101-20601230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20610101-20651230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20660101-20701230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20710101-20751230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20760101-20801230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20810101-20851230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20860101-20901230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20910101-20951230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20960101-20991130.nc" 
             )
           ),
         precipitation_amount = list(
           historical = c(
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19700101-19701230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19710101-19751230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19760101-19801230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19810101-19851230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19860101-19901230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19910101-19951230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19960101-20001230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_20010101-20051230.nc" 
             ),
           scenario = c(
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20060101-20101230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20110101-20151230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20160101-20201230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20210101-20251230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20260101-20301230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20310101-20351230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20360101-20401230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20410101-20451230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20460101-20501230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20510101-20551230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20560101-20601230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20610101-20651230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20660101-20701230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20710101-20751230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20760101-20801230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20810101-20851230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20860101-20901230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20910101-20951230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_20960101-20991130.nc" 
             )
          )
        ),
       land.mask.name = "sftlf",
       land.mask = "/data/reloclim-tmp/rcu/rew/SMHI_CORDEX/sftlf_EUR-11_ECMWF-ERAINT_evaluation_r0i0p0_SMHI-RCA4_v1_fx.nc",
       gridfile.path = "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily",
       gridfile.filename = "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19700101-19701230.nc",
        resolution = "12.5km",
        what.timesteps = "daily"
      ),
  ###########################################################################
    'EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1' = list(
      institute = "KNMI",
      rcm = "RACMO22E",
      gcm = "EC-EARTH",
      emission.scenario = "rcp4.5",
      file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/KNMI/RACMO22E/EC-EARTH/direct/daily",
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19500101-19501231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19510101-19551231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19560101-19601231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19610101-19651231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19660101-19701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19710101-19751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19760101-19801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19810101-19851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19860101-19901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19910101-19951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19960101-20001231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20060101-20101231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20110101-20151231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20160101-20201231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20210101-20251231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20260101-20301231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20310101-20351231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20360101-20401231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20410101-20451231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20460101-20501231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20510101-20551231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20560101-20601231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20610101-20651231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20660101-20701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20710101-20751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20760101-20801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20810101-20851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20860101-20901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20910101-20951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20960101-21001231.nc" 
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19500101-19501231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19510101-19551231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19560101-19601231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19610101-19651231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19660101-19701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19710101-19751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19760101-19801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19810101-19851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19860101-19901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19910101-19951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19960101-20001231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20060101-20101231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20110101-20151231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20160101-20201231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20210101-20251231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20260101-20301231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20310101-20351231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20360101-20401231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20410101-20451231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20460101-20501231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20510101-20551231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20560101-20601231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20610101-20651231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20660101-20701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20710101-20751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20760101-20801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20810101-20851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20860101-20901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20910101-20951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20960101-21001231.nc" 
            )
          )
        ),
      gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/KNMI/RACMO22E/EC-EARTH/direct/daily",
        gridfile.filename = "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19500101-19501231.nc",
        resolution = "12.5km",
        what.timesteps = "daily"
      ),
  ###########################################################################
    ## COORDINATES MISSING
    ## 
      'EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17' = list(
       institute = "CLMcom",
       rcm = "CCLM4",
       gcm = "MPI-ESM-LR",
       emission.scenario = "rcp4.5",
       file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/BTU/CCLM/MPI-ESM-LR/direct/daily",
        file.name = list(
          air_temperature = list(
          historical = c(
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19491201-19501231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19510101-19551231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19560101-19601231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19610101-19651231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19660101-19701231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19710101-19751231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19760101-19801231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19810101-19851231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19860101-19901231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19910101-19951231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19960101-20001231.nc", 
            "tas_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20060101-20101231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20110101-20151231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20160101-20201231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20210101-20251231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20260101-20301231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20310101-20351231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20360101-20401231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20410101-20451231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20460101-20501231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20510101-20551231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20560101-20601231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20610101-20651231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20660101-20701231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20710101-20751231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20760101-20801231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20810101-20851231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20860101-20901231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20910101-20951231.nc", 
            "tas_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20960101-21001231.nc" 
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19491201-19501231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19510101-19551231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19560101-19601231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19610101-19651231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19660101-19701231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19710101-19751231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19760101-19801231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19810101-19851231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19860101-19901231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19910101-19951231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_19960101-20001231.nc", 
            "pr_EUR-11_MPI-ESM-LR_historical_r1i1p1_CCLM4-8-17_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20060101-20101231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20110101-20151231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20160101-20201231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20210101-20251231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20260101-20301231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20310101-20351231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20360101-20401231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20410101-20451231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20460101-20501231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20510101-20551231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20560101-20601231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20610101-20651231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20660101-20701231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20710101-20751231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20760101-20801231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20810101-20851231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20860101-20901231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20910101-20951231.nc", 
            "pr_EUR-11_MPI-ESM-LR_rcp45_r1i1p1_CCLM4-8-17_v1_day_20960101-21001231.nc" 
            )
          )
        ),
        gridfile.path = "/data/reloclim-tmp/rcu/thm/EURO_CORDEX/BTU",
        gridfile.filename = "coord_EUR-11.nc",
        resolution = "12.5km",
        what.timesteps = "daily"
      ),
  ###########################################################################

    'EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2' = list(
      institute = "IPSL",
      rcm = "WRF331F",
      gcm = "IPSL-CM5A-MR",
      emission.scenario = "rcp4.5",
      file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/IPSL/WRF/IPSL-CM5A-MR/direct/daily",
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19710101_19751231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19760101_19801231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19810101_19851231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19860101_19901231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19910101_19951231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19960101_20001231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20010101_20051231.nc" 
            ),
          scenario = c(
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20060101_20101231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20110101_20151231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20160101_20201231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20210101_20251231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20260101_20301231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20310101_20351231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20360101_20401231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20410101_20451231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20460101_20501231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20510101_20551231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20560101_20601231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20610101_20651231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20660101_20701231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20710101_20751231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20760101_20801231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20810101_20851231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20860101_20901231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20910101_20951231.nc", 
            "tas_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20960101_21001231.nc" 
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19710101_19751231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19760101_19801231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19810101_19851231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19860101_19901231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19910101_19951231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19960101_20001231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20010101_20051231.nc" 
            ),
          scenario = c(
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20060101_20101231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20110101_20151231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20160101_20201231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20210101_20251231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20260101_20301231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20310101_20351231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20360101_20401231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20410101_20451231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20460101_20501231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20510101_20551231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20560101_20601231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20610101_20651231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20660101_20701231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20710101_20751231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20760101_20801231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20810101_20851231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20860101_20901231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20910101_20951231.nc", 
            "pr_EUR-11_IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v2_day_20960101_21001231.nc" 
            )
          )
        ),
        gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/IPSL/WRF/IPSL-CM5A-MR/direct/daily",
        gridfile.filename = "pr_EUR-11_IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v2_day_19710101_19751231.nc",
        resolution = "12.5km",
        what.timesteps = "daily"
      ),
### ----------------------------------------------------------------------
### *************************** SCENARIO: rcp85 *****************************
### ----------------------------------------------------------------------

###########################################################################
     'EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1' = list(
       institute = "SMHI",
       rcm = "RCA4",
       gcm = "HadGEM2-ES",
       emission.scenario = "rcp8.5",
       file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily",
           scenario =  "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily",
           scenario =  "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily")),
       file.name = list(
         air_temperature = list(
           historical = c(
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19700101-19701230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19710101-19751230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19760101-19801230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19810101-19851230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19860101-19901230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19910101-19951230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19960101-20001230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_20010101-20051230.nc" 
             ),
           scenario = c(
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20060101-20101230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20110101-20151230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20160101-20201230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20210101-20251230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20260101-20301230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20310101-20351230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20360101-20401230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20410101-20451230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20460101-20501230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20510101-20551230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20560101-20601230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20610101-20651230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20660101-20701230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20710101-20751230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20760101-20801230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20810101-20851230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20860101-20901230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20910101-20951230.nc", 
             "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20960101-20991130.nc" 
             )
           ),
         precipitation_amount = list(
           historical = c(
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19700101-19701230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19710101-19751230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19760101-19801230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19810101-19851230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19860101-19901230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19910101-19951230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19960101-20001230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_20010101-20051230.nc" 
             ),
           scenario = c(
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20060101-20101230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20110101-20151230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20160101-20201230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20210101-20251230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20260101-20301230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20310101-20351230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20360101-20401230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20410101-20451230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20460101-20501230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20510101-20551230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20560101-20601230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20610101-20651230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20660101-20701230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20710101-20751230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20760101-20801230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20810101-20851230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20860101-20901230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20910101-20951230.nc", 
             "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_20960101-20991130.nc" 
             )
          )
        ),
       land.mask.name = "sftlf",
       land.mask = "/data/reloclim-tmp/rcu/rew/SMHI_CORDEX/sftlf_EUR-11_ECMWF-ERAINT_evaluation_r0i0p0_SMHI-RCA4_v1_fx.nc",
       gridfile.path = "/data/reloclim/rcm/EURO-CORDEX/SMHI/RCA4/HadGEM2-ES/direct/daily",
       gridfile.filename = "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_19700101-19701230.nc",
        resolution = "12.5km",
        what.timesteps = "daily"
      ),
  ###########################################################################
   'EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1' = list(
      institute = "SMHI",
      rcm = "RCA4",
      gcm = "EC-EARTH",
      emission.scenario = "rcp8.5",
      file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/SMHI/RCA4/EC-EARTH/direct/daily",
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19710101-19751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19760101-19801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19810101-19851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19860101-19901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19910101-19951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19960101-20001231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20060101-20101231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20110101-20151231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20160101-20201231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20210101-20251231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20260101-20301231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20310101-20351231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20360101-20401231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20410101-20451231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20460101-20501231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20510101-20551231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20560101-20601231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20610101-20651231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20660101-20701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20710101-20751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20760101-20801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20810101-20851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20860101-20901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20910101-20951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20960101-21001231.nc" 
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19710101-19751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19760101-19801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19810101-19851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19860101-19901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19910101-19951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19960101-20001231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20060101-20101231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20110101-20151231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20160101-20201231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20210101-20251231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20260101-20301231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20310101-20351231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20360101-20401231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20410101-20451231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20460101-20501231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20510101-20551231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20560101-20601231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20610101-20651231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20660101-20701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20710101-20751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20760101-20801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20810101-20851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20860101-20901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20910101-20951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_20960101-21001231.nc" 
            )
          )
        ),
     land.mask.name = "sftlf",
     land.mask = "/data/reloclim-tmp/rcu/rew/SMHI_CORDEX/sftlf_EUR-11_ECMWF-ERAINT_evaluation_r0i0p0_SMHI-RCA4_v1_fx.nc",
        gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/SMHI/RCA4/EC-EARTH/direct/daily",
        gridfile.filename = "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_19700101-19701231.nc",
        resolution = "12.5km",
        what.timesteps = "daily"
      ),

   ###########################################################################
    'EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1' = list(
      institute = "KNMI",
      rcm = "RACMO22E",
      gcm = "EC-EARTH",
      emission.scenario = "rcp8.5",
      file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/KNMI/RACMO22E/EC-EARTH/direct/daily",
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19500101-19501231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19510101-19551231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19560101-19601231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19610101-19651231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19660101-19701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19710101-19751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19760101-19801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19810101-19851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19860101-19901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19910101-19951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19960101-20001231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20060101-20101231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20110101-20151231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20160101-20201231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20210101-20251231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20260101-20301231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20310101-20351231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20360101-20401231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20410101-20451231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20460101-20501231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20510101-20551231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20560101-20601231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20610101-20651231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20660101-20701231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20710101-20751231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20760101-20801231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20810101-20851231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20860101-20901231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20910101-20951231.nc", 
            "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20960101-21001231.nc" 
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19500101-19501231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19510101-19551231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19560101-19601231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19610101-19651231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19660101-19701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19710101-19751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19760101-19801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19810101-19851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19860101-19901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19910101-19951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19960101-20001231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_20010101-20051231.nc" 
            ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20060101-20101231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20110101-20151231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20160101-20201231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20210101-20251231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20260101-20301231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20310101-20351231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20360101-20401231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20410101-20451231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20460101-20501231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20510101-20551231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20560101-20601231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20610101-20651231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20660101-20701231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20710101-20751231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20760101-20801231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20810101-20851231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20860101-20901231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20910101-20951231.nc", 
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_20960101-21001231.nc" 
            )
          )
        ),
      gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/KNMI/RACMO22E/EC-EARTH/direct/daily",
        gridfile.filename = "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19500101-19501231.nc",
        resolution = "12.5km",
        what.timesteps = "daily"
      ),   
###########################################################################
   
###########################################################################
    
###########################################################################

###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###++++++++++++++++++++++ DATASET: EUROCORDEX 0.11 - QuantileMapped +++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

### ----------------------------------------------------------------------
### *************************** SCENARIO: rcp26 *****************************
### ----------------------------------------------------------------------


  'EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9' =  list(
      rcm = "RCA4",
      gcm = "EC-EARTH",
      emission.scenario = "rcp2.6",
      institute = "SMHI",
      corrected.data = "TRUE",
      gcm.run = 12, 
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp26/QM_EOBSv9.0_A1Bcalib7105"
           ),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp26/QM_EOBSv9.0_A1Bcalib7105"
           ),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp26/QM_EOBSv9.0_A1Bcalib7105"
           ),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
         scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp26/QM_EOBSv9.0_A1Bcalib7105"
           )
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),

      #-------------------------------------------------------------------------------------------
    
     'EUR-11_MPI-CSC-REMO-MPI-M-ESM-LR-rcp26_v1-bc-qm-eobs9' =  list(
      rcm = "REMO",
       gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp2.6",
      institute = "CSC",
      corrected.data = "TRUE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/rcp26/QM_EOBSv9.0_A1Bcalib7105"),
         air_temperature_minimum= list(
           historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp26"),
         air_temperature_maximum= list(
          historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp26"),
         precipitation_amount = list(
          historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp26")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_rcp26_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_rcp26_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_rcp26_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_rcp26_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
### ----------------------------------------------------------------------
### *************************** SCENARIO: rcp45 *****************************
### ----------------------------------------------------------------------
    'EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9' =  list(
      rcm = "RCA4",
      gcm = "HadGEM2_ES",
     gcm.run = 1,
       emission.scenario = "rcp4.5",
      institute = "SMHI",
      corrected.data = "TRUE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
          air_temperature_minimum = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
          air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp45/QM_EOBSv9.0_A1Bcalib7105")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
    #---------------------------------------------------------------------------------------------
    'EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9' =  list(
      rcm = "RCA4",
      gcm = "EC-EARTH",
      emission.scenario = "rcp4.5",
      gcm.run = 12,
      institute = "SMHI",
       corrected.data = "TRUE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp45/QM_EOBSv9.0_A1Bcalib7105"
           ),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp45/QM_EOBSv9.0_A1Bcalib7105"
           ),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp45/QM_EOBSv9.0_A1Bcalib7105"
           ),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
         scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp45/QM_EOBSv9.0_A1Bcalib7105"
           )
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
     #---------------------------------------------------------------------------------------------
    'EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9' =  list(
      rcm = "RACMO22E",
      gcm = "EC-EARTH",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      institute = "KNMI",
       corrected.data = "TRUE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/QM_EOBSv9.0_A1Bcalib7105")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario= c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_2006.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
    #-------------------------------------------------------------------------------------------
    
     'EUR-11_MPI-CSC-REMO-MPI-M-ESM-LR-rcp45_v1-bc-qm-eobs9' =  list(
      rcm = "REMO",
       gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      institute = "CSC",
      corrected.data = "TRUE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
         air_temperature_maximum= list(
           historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp45"),
         air_temperature_minimum= list(
           historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp45"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp45")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
     #-------------------------------------------------------------------------------------------
    
     'EUR-11_IPSL-IPSL-CM5A-MR_rcp45_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9' =  list(
      rcm = "WRF331F",
      gcm.run = 1,
      gcm = "IPSL-CM5A-MR",
      emission.scenario = "rcp4.5",
      institute = "IPSL-INERIS",
        corrected.data = "TRUE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
         air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
         air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/rcp45/QM_EOBSv9.0_A1Bcalib7105"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/rcp45/QM_EOBSv9.0_A1Bcalib7105")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9_day_(197[1-9]|19[8-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9_day_(197[1-9]|19[8-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmax_EUR-11-bc_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9_day_(197[1-9]|19[8-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9_day_(197[1-9]|19[8-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
      #land.mask.name = "var172",
      #land.mask = "/data/reloclim-tmp/rcm/EURO-CORDEX/CSC/REMO/IPSL-CM5A-MR/direct/daily/europa011_cordex_172_land_sea_mask.nc",
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1-bc-qm-eobs9_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
    
    
    ### ----------------------------------------------------------------------


    
### *************************** SCENARIO: rcp85 *****************************
### ----------------------------------------------------------------------
    'EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9' =  list(
      rcm = "RCA4",
      gcm = "HadGEM2_ES",
      emission.scenario = "rcp8.5",
      institute = "SMHI",
      corrected.data = "TRUE",
      gcm.run = 1,     
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp85/QM_EOBSv9.0_A1Bcalib7105"),
          air_temperature_minimum = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp85/QM_EOBSv9.0_A1Bcalib7105"),
          air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp85/QM_EOBSv9.0_A1Bcalib7105"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp85/QM_EOBSv9.0_A1Bcalib7105")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc"
            )
          )
        ),
     
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
      #-------------------------------------------------------------------------------------------
    
     'EUR-11_MPI-CSC-REMO-MPI-M-ESM-LR-rcp85_v1-bc-qm-eobs9' =  list(
      rcm = "REMO",
       gcm = "MPI-ESM-LR",
      emission.scenario = "rcp8.5",
     gcm.run = 1,
       institute = "CSC",
        corrected.data = "TRUE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/rcp85/QM_EOBSv9.0_A1Bcalib7105"),
         air_temperature_minimum= list(
          historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp85"),
         air_temperature_maximum= list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp85"),
         precipitation_amount = list(
          historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp85")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1-bc-qm-eobs9_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
      #------------------------------------------------------------------
      'EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9' =  list(
      rcm = "RCA4",
      gcm = "EC-EARTH",
      gcm.run = 12,
      emission.scenario = "rcp8.5",
      institute = "SMHI",
         corrected.data = "TRUE",
     
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp85/QM_EOBSv9.0_A1Bcalib7105"
           ),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp85/QM_EOBSv9.0_A1Bcalib7105"
           ),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp85/QM_EOBSv9.0_A1Bcalib7105"
           ),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
         scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp85/QM_EOBSv9.0_A1Bcalib7105"
           )
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1-bc-qm-eobs9_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),

    #--------------------------------------------------------------------------------------
    'EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9' =  list(
      rcm = "RACMO22E",
      gcm = "EC-EARTH",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      institute = "KNMI",
       corrected.data = "TRUE",
     
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/QM_EOBSv9.0_A1Bcalib7105"),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/QM_EOBSv9.0_A1Bcalib7105"),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/QM_EOBSv9.0_A1Bcalib7105"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/QM_EOBSv9.0_A1Bcalib7105",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/QM_EOBSv9.0_A1Bcalib7105")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario= c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/QM_EOBSv9.0_A1Bcalib7105",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1-bc-qm-eobs9_day_2006.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),


###########################################################################
   
###########################################################################
    
###########################################################################

###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###++++++++++++++++++++++ DATASET: EUROCORDEX 0.11 - Regridded (E-OBS) ++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

### ----------------------------------------------------------------------
### *************************** SCENARIO: rcp26 *****************************
### ----------------------------------------------------------------------

  'EUR-11_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1-regridded-eobs9' =  list(
      rcm = "RCA4",
      gcm = "EC-EARTH",
      gcm.run = 12,
      emission.scenario = "rcp2.6",
      institute = "SMHI",
      corrected.data = "FALSE",
     
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp26/regridded_to_EOBSv9.0"
           ),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp26/regridded_to_EOBSv9.0"
           ),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp26/regridded_to_EOBSv9.0"
           ),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
         scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp26/regridded_to_EOBSv9.0"
           )
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp26_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),

      #-------------------------------------------------------------------------------------------
    
     'EUR-11_MPI-CSC-REMO-MPI-M-ESM-LR-rcp26_v1-regridded-eobs9' =  list(
      rcm = "REMO",
       gcm = "MPI-ESM-LR",
      emission.scenario = "rcp2.6",
      gcm.run = 1,
      institute = "CSC",
      corrected.data = "FALSE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/rcp26/regridded_to_EOBSv9.0"),
         air_temperature_minimum= list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp26"),
         air_temperature_maximum= list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp26"),
         precipitation_amount = list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp26")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_rcp26_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_rcp26_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_rcp26_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_rcp26_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
### ----------------------------------------------------------------------
### *************************** SCENARIO: rcp45 *****************************
### ----------------------------------------------------------------------
    'EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1-regridded-eobs9' =  list(
      rcm = "RCA4",
      gcm = "HadGEM2_ES",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      institute = "SMHI",
      corrected.data = "FALSE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp45/regridded_to_EOBSv9.0"),
          air_temperature_minimum = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp45/regridded_to_EOBSv9.0"),
          air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp45/regridded_to_EOBSv9.0"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp45/regridded_to_EOBSv9.0")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
    #---------------------------------------------------------------------------------------------
    'EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1-regridded-eobs9' =  list(
      rcm = "RCA4",
      gcm = "EC-EARTH",
      emission.scenario = "rcp4.5",
     gcm.run = 12,
       institute = "SMHI",
       corrected.data = "FALSE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp45/regridded_to_EOBSv9.0"
           ),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp45/regridded_to_EOBSv9.0"
           ),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp45/regridded_to_EOBSv9.0"
           ),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
         scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp45/regridded_to_EOBSv9.0"
           )
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
     #---------------------------------------------------------------------------------------------
    'EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1-regridded-eobs9' =  list(
      rcm = "RACMO22E",
     gcm.run = 1,
       gcm = "EC-EARTH",
      emission.scenario = "rcp4.5",
      institute = "KNMI",
       corrected.data = "FALSE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/regridded_to_EOBSv9.0"),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/regridded_to_EOBSv9.0"),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/regridded_to_EOBSv9.0"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/regridded_to_EOBSv9.0")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario= c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp45/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_2006.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
    #-------------------------------------------------------------------------------------------
    
     'EUR-11_MPI-CSC-REMO-MPI-M-ESM-LR-rcp45_v1-regridded-eobs9' =  list(
      rcm = "REMO",
       gcm = "MPI-ESM-LR",
      emission.scenario = "rcp4.5",
      gcm.run = 1,
      institute = "CSC",
      corrected.data = "FALSE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/rcp45/regridded_to_EOBSv9.0"),
         air_temperature_maximum= list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp45"),
         air_temperature_minimum= list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp45"),
         precipitation_amount = list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp45")
        ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
     #-------------------------------------------------------------------------------------------
    
     'EUR-11_IPSL-IPSL-CM5A-MR_rcp45_IPSL-INERIS-WRF331F_v1-regridded-eobs9' =  list(
      rcm = "WRF331F",
      gcm.run = 1,
      gcm = "IPSL-CM5A-MR",
      emission.scenario = "rcp4.5",
      institute = "IPSL-INERIS",
        corrected.data = "FALSE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/rcp45/regridded_to_EOBSv9.0"),
         air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/rcp45/regridded_to_EOBSv9.0"),
         air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/rcp45/regridded_to_EOBSv9.0"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/rcp45/regridded_to_EOBSv9.0")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_day_(197[1-9]|19[8-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_day_(197[1-9]|19[8-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmax_EUR-11-bc_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_day_(197[1-9]|19[8-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_day_(197[1-9]|19[8-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
      #land.mask.name = "var172",
      #land.mask = "/data/reloclim-tmp/rcm/EURO-CORDEX/CSC/REMO/IPSL-CM5A-MR/direct/daily/europa011_cordex_172_land_sea_mask.nc",
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/IPSL/WRF/IPSL-CM5A-MR/historical/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
    
    
    ### ----------------------------------------------------------------------


    
### *************************** SCENARIO: rcp85 *****************************
### ----------------------------------------------------------------------
    'EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1-regridded-eobs9' =  list(
      rcm = "RCA4",
      gcm = "HadGEM2_ES",
      emission.scenario = "rcp8.5",
      institute = "SMHI",
      corrected.data = "FALSE",
     gcm.run = 1,      
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp85/regridded_to_EOBSv9.0"),
          air_temperature_minimum = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp85/regridded_to_EOBSv9.0"),
          air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp85/regridded_to_EOBSv9.0"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/rcp85/regridded_to_EOBSv9.0")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-8]).nc"
            )
          )
        ),
     
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/HadGEM2-ES/historical/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
      #-------------------------------------------------------------------------------------------
    
     'EUR-11_MPI-CSC-REMO-MPI-M-ESM-LR-rcp85_v1-regridded-eobs9' =  list(
      rcm = "REMO",
       gcm = "MPI-ESM-LR",
     gcm.run = 1,
       emission.scenario = "rcp8.5",
      institute = "CSC",
        corrected.data = "FALSE",
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/rcp85/regridded_to_EOBSv9.0"),
         air_temperature_minimum= list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp85"),
         air_temperature_maximum= list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp85"),
         precipitation_amount = list(
         historical = "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/historical",
           scenario =  "/data/reloclim/rcu/msw/Impact2c/CSC/REMO2009/postproc/rcp85")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_MPI-M-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
         air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmax_EUR-11-bc_MPI-M-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_(19[5-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_MPI-M-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/CSC/REMO2009/MPI-ESM-LR-r1/historical/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),
      #------------------------------------------------------------------
      'EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1-regridded-eobs9' =  list(
      rcm = "RCA4",
      gcm = "EC-EARTH",
     gcm.run = 12,
       emission.scenario = "rcp8.5",
      institute = "SMHI",
         corrected.data = "FALSE",
     
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp85/regridded_to_EOBSv9.0"
           ),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp85/regridded_to_EOBSv9.0"
           ),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
          scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp85/regridded_to_EOBSv9.0"
           ),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
         scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/rcp85/regridded_to_EOBSv9.0"
           )
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"),
          scenario = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc")
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_(19[7-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/SMHI/RCA4/EC-EARTH-r12/historical/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_day_2000.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),

    #--------------------------------------------------------------------------------------
    'EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1-regridded-eobs9' =  list(
      rcm = "RACMO22E",
      gcm = "EC-EARTH",
      emission.scenario = "rcp8.5",
      institute = "KNMI",
       corrected.data = "FALSE",
     gcm.run = 1,     
      file.path.alt = list(
         air_temperature = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/regridded_to_EOBSv9.0"),
        air_temperature_minimum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/regridded_to_EOBSv9.0"),
        air_temperature_maximum= list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/regridded_to_EOBSv9.0"),
         precipitation_amount = list(
           historical = "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/historical/regridded_to_EOBSv9.0",
           scenario =  "/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/regridded_to_EOBSv9.0")
      ),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        air_temperature_maximum= list(
          historical = c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario= c(
            "tasmax_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        air_temperature_minimum= list(
          historical = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "tasmin_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          ),
        precipitation_amount= list(
          historical = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_(195[1-9]|19[6-9][0-9]|200[0-5]).nc"
            ),
          scenario = c(
            "pr_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_(200[6-9]|20[1-8][0-9]|209[0-9]|2100).nc"
            )
          )
        ),
            land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcd/e-obs/data/eobs_0.25deg_reg_v5.0_landseamask.nc",
      gridfile.path ="/data/reloclim/rcm/IMPACT2C/esg_formated/slowtrack/KNMI/RACMO22E/EC-EARTH-r1/rcp85/regridded_to_EOBSv9.0",
      gridfile.filename = "tas_EUR-11-bc_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_day_2006.nc",
      resolution = "25km",
      what.timesteps = "daily",
      parameters = c(air_temperature ="tas", precipitation_amount= "pr",air_temperature_minimum='tasmin',air_temperature_maximum='tasmax')
      ),






















    
    
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++++DATASET: EUROCORDEX 0.44+++++++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

### ----------------------------------------------------------------------
### *************************** SCENARIO: rcp26 *****************************
### ----------------------------------------------------------------------

### ----------------------------------------------------------------------
### *************************** SCENARIO: rcp45 *****************************
### ----------------------------------------------------------------------

    ## DATA NOT AVAILABLE YET
    ## 
    ## 'EUR-44_MPI-ESM-LR_rcp45_REMO' = list(
    ##   institute = "CSC",
    ##   rcm = "REMO",
    ##   gcm = "MPI-ESM-LR",
    ##   emission.scenario = "rcp4.5",
    ##   file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/CSC/REMO/MPI-ESM-LR/direct/daily",
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c(
    ##         ""
    ##         ),
    ##       scenario = c(
    ##         ""
    ##         )
    ##       ),
    ##         air_temperature = list(
    ##       historical = c(
    ##         ""
    ##         ),
    ##       scenario = c(
    ##         ""
    ##         )
    ##       )
    ##     ),
    ##   land.mask.name = "var172",
    ##   land.mask = "",
    ##   gridfile.path = "",
    ##   gridfile.filename = "europa011_cordex_172_land_sea_mask.nc",
    ##   resolution = "50km",
    ##   what.timesteps = "daily",
    ##   parameters = c(air_temperature = "var167")
    ##   ),
################################################################################

    ## CORRUPT NETCDF FILE
    ## 
    ## 'EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17' = list(
    ##    institute = "CLMcom",
    ##    rcm = "CCLM4",
    ##    gcm = "MPI-ESM-LR",
    ##    emission.scenario = "rcp4.5",
    ##    file.path.default = "/data/reloclim-tmp/rcu/rew/CLM_CORDEX",
    ##     file.name = list(
    ##       air_temperature = list(
    ##       historical = c(
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19591201_19601231.nc", 
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19610101_19651231.nc", 
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19660101_19701231.nc", 
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19710101_19751231.nc", 
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19760101_19801231.nc", 
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19810101_19851231.nc", 
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19860101_19901231.nc", 
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19910101_19951231.nc", 
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19960101_20001231.nc", 
    ##         "tas_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_20010101_20051231.nc" 
    ##         ),
    ##         scenario = c(
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20060101_20101231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20110101_20151231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20160101_20201231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20210101_20251231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20260101_20301231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20310101_20351231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20360101_20401231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20410101_20451231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20460101_20501231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20510101_20551231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20560101_20601231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20610101_20651231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20660101_20701231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20710101_20751231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20760101_20801231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20810101_20851231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20860101_20901231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20910101_20951231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20960101_21001231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20060101_20101231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20110101_20151231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20160101_20201231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20210101_20251231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20260101_20301231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20310101_20351231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20360101_20401231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20410101_20451231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20460101_20501231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20510101_20551231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20560101_20601231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20610101_20651231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20660101_20701231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20710101_20751231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20760101_20801231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20810101_20851231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20860101_20901231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20910101_20951231.nc", 
    ##           "tas_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20960101_21001231.nc" 
    ##           )
    ##         ),
    ##       precipitation_amount = list(
    ##         historical = c(
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19591201_19601231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19610101_19651231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19660101_19701231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19710101_19751231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19760101_19801231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19810101_19851231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19860101_19901231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19910101_19951231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19960101_20001231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_20010101_20051231.nc" 
    ##           ),
    ##         scenario = c(
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20060101_20101231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20110101_20151231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20160101_20201231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20210101_20251231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20260101_20301231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20310101_20351231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20360101_20401231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20410101_20451231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20460101_20501231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20510101_20551231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20560101_20601231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20610101_20651231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20660101_20701231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20710101_20751231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20760101_20801231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20810101_20851231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20860101_20901231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20910101_20951231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp45_r1i1p1_CCLM_4-8-17_day_20960101_21001231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20060101_20101231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20110101_20151231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20160101_20201231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20210101_20251231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20260101_20301231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20310101_20351231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20360101_20401231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20410101_20451231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20460101_20501231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20510101_20551231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20560101_20601231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20610101_20651231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20660101_20701231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20710101_20751231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20760101_20801231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20810101_20851231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20860101_20901231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20910101_20951231.nc", 
    ##           "pr_EUR-44_MPI-ESM-LR_rcp85_r1i1p1_CCLM_4-8-17_day_20960101_21001231.nc" 
    ##           )
    ##         )
    ##     ),
    ##    gridfile.path = "/data/reloclim-tmp/rcu/rew/CLM_CORDEX",
    ##    gridfile.filename = "pr_EUR-44_MPI-ESM-LR_historical_r1i1p1_CCLM_4-8-17_day_19591201_19601231.nc",
    ##     resolution = "50km",
    ##     what.timesteps = "daily"
    ##   ),
  ###########################################################################
    'EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1' = list(
       institute = "MF",
       rcm = "ARPEGE51",
       gcm = "CNRM-CM5",
       emission.scenario = "rcp4.5",
       file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/MetFrance/ARPEGE/CNRM-CM5/direct/daily",
        file.name = list(
          air_temperature = list(
          historical = c(
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19510101-19551231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19560101-19601231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19610101-19651231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19660101-19701231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19710101-19751231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19760101-19801231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19810101-19851231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19860101-19901231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19910101-19951231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19960101-20001231.nc",
            "tas_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_20010101-20051231.nc"
            ),
            scenario = c(
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20060101-20101231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20110101-20151231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20160101-20201231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20210101-20251231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20260101-20301231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20310101-20351231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20360101-20401231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20410101-20451231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20460101-20501231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20510101-20551231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20560101-20601231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20610101-20651231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20660101-20701231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20710101-20751231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20760101-20801231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20810101-20851231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20860101-20901231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20910101-20951231.nc",
              "tas_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20960101-21001231.nc"
              )
            ),
          precipitation_amount = list(
            historical = c(
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19510101-19551231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19560101-19601231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19610101-19651231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19660101-19701231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19710101-19751231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19760101-19801231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19810101-19851231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19860101-19901231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19910101-19951231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19960101-20001231.nc",
              "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_20010101-20051231.nc"
              ),
            scenario = c(
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20060101-20101231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20110101-20151231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20160101-20201231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20210101-20251231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20260101-20301231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20310101-20351231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20360101-20401231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20410101-20451231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20460101-20501231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20510101-20551231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20560101-20601231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20610101-20651231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20660101-20701231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20710101-20751231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20760101-20801231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20810101-20851231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20860101-20901231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20910101-20951231.nc",
              "pr_EUR-44_CNRM-CM5_rcp45_r8i1p1_CNRM-ARPEGE51_v1_day_20960101-21001231.nc"
              )
            )
        ),
      gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/MetFrance/ARPEGE/CNRM-CM5/direct/daily",
      gridfile.filename = "pr_EUR-44_CNRM-CM5_historical_r8i1p1_CNRM-ARPEGE51_v1_day_19510101-19551231.nc",
      lonlat.var.name = c(longitude="longitude", latitude="latitude"),
      resolution = "50km",
      what.timesteps = "daily"
      ),
  ###########################################################################
    'EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1' = list(
       institute = "KNMI",
       rcm = "RACMO",
       gcm = "EC-EARTH",
       emission.scenario = "rcp4.5",
       file.path.default = "/data/reloclim/rcm/EURO-CORDEX/KNMI/RACMO22E/EC-EARTH/direct/daily",
        file.name = list(
          air_temperature = list(
          historical = c(
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19500101-19501231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19510101-19551231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19560101-19601231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19610101-19651231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19660101-19701231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19710101-19751231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19760101-19801231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19810101-19851231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19860101-19901231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19910101-19951231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19960101-20001231.nc", 
            "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_20010101-20051231.nc" 
            ),
            scenario = c(
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20060101-20101231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20110101-20151231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20160101-20201231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20210101-20251231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20260101-20301231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20310101-20351231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20360101-20401231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20410101-20451231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20460101-20501231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20510101-20551231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20560101-20601231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20610101-20651231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20660101-20701231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20710101-20751231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20760101-20801231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20810101-20851231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20860101-20901231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20910101-20951231.nc", 
              "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20960101-21001231.nc" 
              )
            ),
          precipitation_amount = list(
            historical = c(
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19500101-19501231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19510101-19551231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19560101-19601231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19610101-19651231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19660101-19701231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19710101-19751231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19760101-19801231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19810101-19851231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19860101-19901231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19910101-19951231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19960101-20001231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_20010101-20051231.nc"
               ),
            scenario = c(
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20060101-20101231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20110101-20151231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20160101-20201231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20210101-20251231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20260101-20301231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20310101-20351231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20360101-20401231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20410101-20451231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20460101-20501231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20510101-20551231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20560101-20601231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20610101-20651231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20660101-20701231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20710101-20751231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20760101-20801231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20810101-20851231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20860101-20901231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20910101-20951231.nc", 
              "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_day_20960101-21001231.nc" 
              )
            )
        ),
      gridfile.path = "/data/reloclim/rcm/EURO-CORDEX/KNMI/RACMO22E/EC-EARTH/direct/daily",
      gridfile.filename = "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_day_19610101-19651231.nc",
      resolution = "50km",
      what.timesteps = "daily"
      ),
  
  ###########################################################################

    ## KAPUTT, GRIDFILE GEH NET
    
##     'EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2' = list(
##       institute = "CUNI",
##       rcm = "RegCM4-2",
##       gcm = "CNRM-CM5",
##       emission.scenario = "rcp4.5",
##       file.path.default = "/data/reloclim-tmp/rcm/EURO-CORDEX/CUNI/RegCM42/CNRM-CM5/direct/daily",
##       file.name = list(
##         air_temperature = list(
##           historical = c(
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1960010100_1960123100.nc", 
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1961010100_1965123100.nc", 
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1966010100_1970123100.nc", 
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1971010100_1975123100.nc", 
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1976010100_1980123100.nc", 
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1981010100_1985123100.nc", 
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1986010100_1990123100.nc", 
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1991010100_1995123100.nc", 
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1996010100_2000123100.nc", 
##             "tas_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_2001010100_2005123100.nc" 
##             ),
##           scenario = c(
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2006010100_2010123100.nc",
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2011010100_2015123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2016010100_2020123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2021010100_2025123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2026010100_2030123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2031010100_2035123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2036010100_2040123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2041010100_2045123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2046010100_2050123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2051010100_2055123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2056010100_2060123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2061010100_2065123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2066010100_2070123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2071010100_2075123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2076010100_2080123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2081010100_2085123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2086010100_2090123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2091010100_2095123100.nc", 
##             "tas_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2096010100_2100123100.nc" 
##             )
##           ),
##         precipitation_amount = list(
##           historical = c(
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1960010100_1960123100.nc", 
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1961010100_1965123100.nc", 
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1966010100_1970123100.nc", 
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1971010100_1975123100.nc", 
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1976010100_1980123100.nc", 
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1981010100_1985123100.nc", 
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1986010100_1990123100.nc", 
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1991010100_1995123100.nc", 
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_1996010100_2000123100.nc", 
##             "pr_EUR-44_CNRM-CM5_historical_r1i1p1_CUNI-RegCM4-2_day_2001010100_2005123100.nc"            ),
##           scenario = c(
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2006010100_2010123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2011010100_2015123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2016010100_2020123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2021010100_2025123100.nc", 
##             "pr_EUR-44_CNR+M-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2026010100_2030123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2031010100_2035123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2036010100_2040123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2041010100_2045123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2046010100_2050123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2051010100_2055123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2056010100_2060123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2061010100_2065123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2066010100_2070123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2071010100_2075123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2076010100_2080123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2081010100_2085123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2086010100_2090123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2091010100_2095123100.nc", 
##             "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2096010100_2100123100.nc" 
##             )
##           )
##         ),
##       land.mask.name = "lsmask",
##       land.mask = "/data/reloclim-tmp/rcm/EURO-CORDEX/CUNI/RegCM42/CNRM-CM5/direct/lsmask_EUR-50_ERAINT_historical_r1i1p1_CUNI-RegCM_v1_fx.nc",
##       gridfile.path = "/data/reloclim-tmp/rcm/EURO-CORDEX/CUNI/RegCM42/CNRM-CM5/direct/daily",
##       gridfile.filename = "pr_EUR-44_CNRM-CM5_rcp45_r1i1p1_CUNI-RegCM4-2_day_2006010100_2010123100.nc",
## ##      lonlat.var.name = c(longitude="xlon", latitude="xlat"),
##       resolution = "50km",
##       what.timesteps = "daily"
##       ),
##########################################################################


    
 
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++ DATASET: EURO-CORDEX 0.11 & 0.44 +++++++++++++++++++
###++++++++++++++++++  monthly dataset (more complete that daily) +++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

### ----------------------------------------------------------------------
### *************************** SCENARIO: RCP45 **************************
### ----------------------------------------------------------------------


    'EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon' = list(
      institute = "MPI",
      rcm = "MPI-CSC-REMO2009",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_195002-195012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_195101-196012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_196101-197012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_197101-198012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_198101-199012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_199101-200012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_200101-200512.nc"
            ),
          scenario = c(
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_200601-201012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_201101-202012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_202101-203012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_203101-204012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_204101-205012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_205101-206012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_206101-207012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_207101-208012.nc",
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_208101-209012.nc",
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_209101-210012.nc"
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_195002-195012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_195101-196012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_196101-197012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_197101-198012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_198101-199012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_199101-200012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_200101-200512.nc"
            ),
          scenario = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_200601-201012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_201101-202012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_202101-203012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_203101-204012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_204101-205012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_205101-206012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_206101-207012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_207101-208012.nc",
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_208101-209012.nc",
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_MPI-CSC-REMO2009_v1_mon_209101-210012.nc"
            )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "CNRM-CM5",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

  ###########################################################################

    'EUR-44_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "CNRM-CM5",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_CNRM-CERFACS-CNRM-CM5_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################


  ###########################################################################

    'EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "EC-EARTH",
      gcm.run = 12,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_ICHEC-EC-EARTH_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

  ###########################################################################

    'EUR-44_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "EC-EARTH",
      gcm.run = 12,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_ICHEC-EC-EARTH_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_mon' = list(
      institute = "KNMI",
      rcm = "KNMI-RACMO22E",
      gcm = "EC-EARTH",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_mon' = list(
      institute = "KNMI",
      rcm = "KNMI-RACMO22E",
      gcm = "EC-EARTH",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################




  ###########################################################################

    'EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_CLMcom-CCLM4-8-17_v1_mon' = list(
      institute = "CLMcom",
      rcm = "CLMcom-CCLM4-8-17",
      gcm = "EC-EARTH",
      gcm.run = 12,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_ICHEC-EC-EARTH_historical_r0i0p0_CLMcom-CCLM4-8-17_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-11_ICHEC-EC-EARTH_rcp45_r3i1p1_DMI-HIRHAM5_v1_mon' = list(
      institute = "DMI",
      rcm = "DMI-HIRHAM5",
      gcm = "EC-EARTH",
      gcm.run = 3,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_ICHEC-EC-EARTH_rcp45_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp45_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################



    'EUR-44_ICHEC-EC-EARTH_rcp45_r3i1p1_DMI-HIRHAM5_v1_mon' = list(
      institute = "DMI",
      rcm = "DMI-HIRHAM5",
      gcm = "EC-EARTH",
      gcm.run = 3,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_ICHEC-EC-EARTH_rcp45_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_ICHEC-EC-EARTH_rcp45_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################


 ###########################################################################

    'EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "HadGEM2-ES",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_MOHC-HadGEM2-ES_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-44_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "HadGEM2-ES",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_MOHC-HadGEM2-ES_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_MOHC-HadGEM2-ES_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################
###########################################################################

    'EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_CLMcom-CCLM4-8-17_v1_mon' = list(
      institute = "CLMcom",
      rcm = "CLMcom-CCLM4-8-17",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_MPI-M-MPI-ESM-LR_historical_r0i0p0_CLMcom-CCLM4-8-17_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-44_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_CLMcom-CCLM4-8-17_v1_mon' = list(
      institute = "CLMcom",
      rcm = "CLMcom-CCLM4-8-17",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_MPI-M-MPI-ESM-LR_historical_r0i0p0_CLMcom-CCLM4-8-17_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_CLMcom-CCLM4-8-17_v1_mon' = list(
      institute = "CLMcom",
      rcm = "CLMcom-CCLM4-8-17",
      gcm = "CNRM-CM5",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp45_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r0i0p0_CLMcom-CCLM4-8-17_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),

 ###########################################################################


    'EUR-11_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_mon' = list(
      institute = "IPSL-INERIS",
      rcm = "IPSL-INERIS-WRF331F",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_IPSL-IPSL-CM5A-MR_historical_r0i0p0_IPSL-INERIS-WRF331F_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),


###########################################################################


    'EUR-44_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_mon' = list(
      institute = "IPSL-INERIS",
      rcm = "IPSL-INERIS-WRF331F",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_IPSL-IPSL-CM5A-MR_historical_r0i0p0_IPSL-INERIS-WRF331F_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),


###########################################################################


    'EUR-44_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_IPSL-IPSL-CM5A-MR_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_IPSL-IPSL-CM5A-MR_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),



###########################################################################


    'EUR-44_NOAA-GFDL-GFDL-ESM2M_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "GFDL-ESM2M",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_NOAA-GFDL-GFDL-ESM2M_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_NOAA-GFDL-GFDL-ESM2M_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_NOAA-GFDL-GFDL-ESM2M_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_NOAA-GFDL-GFDL-ESM2M_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_NOAA-GFDL-GFDL-ESM2M_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_NOAA-GFDL-GFDL-ESM2M_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),



###########################################################################


    'EUR-44_NCC-NorESM1-M_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "NorESM1-M",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_NCC-NorESM1-M_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_NCC-NorESM1-M_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_NCC-NorESM1-M_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_NCC-NorESM1-M_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_NCC-NorESM1-M_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_NCC-NorESM1-M_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
###########################################################################

    'EUR-44_MIROC-MIROC5_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "MIROC5",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_MIROC-MIROC5_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_MIROC-MIROC5_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_MIROC-MIROC5_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),



###########################################################################

    'EUR-44_CCCma-CanESM2_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "CanESM2",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_CCCma-CanESM2_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_CCCma-CanESM2_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_CCCma-CanESM2_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),



###########################################################################

    'EUR-44_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp4.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_MPI-M-MPI-ESM-LR_rcp45_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_MPI-M-MPI-ESM-LR_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),





################################################################################
###################################  RCP 8.5  ###################################
################################################################################
    



    'EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon' = list(
      institute = "MPI",
      rcm = "MPI-CSC-REMO2009",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_195002-195012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_195101-196012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_196101-197012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_197101-198012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_198101-199012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_199101-200012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_200101-200512.nc"
            ),
          scenario = c(
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_200601-201012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_201101-202012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_202101-203012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_203101-204012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_204101-205012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_205101-206012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_206101-207012.nc", 
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_207101-208012.nc",
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_208101-209012.nc",
            "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_209101-210012.nc"
            )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_195002-195012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_195101-196012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_196101-197012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_197101-198012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_198101-199012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_199101-200012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_200101-200512.nc"
            ),
          scenario = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_200601-201012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_201101-202012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_202101-203012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_203101-204012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_204101-205012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_205101-206012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_206101-207012.nc", 
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_207101-208012.nc",
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_208101-209012.nc",
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_MPI-CSC-REMO2009_v1_mon_209101-210012.nc"
            )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_MPI-CSC-REMO2009_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-11_CNRM-CERFACS-CNRM-CM5_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "CNRM-CM5",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

  ###########################################################################

    'EUR-44_CNRM-CERFACS-CNRM-CM5_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "CNRM-CM5",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_CNRM-CERFACS-CNRM-CM5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_CNRM-CERFACS-CNRM-CM5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_CNRM-CERFACS-CNRM-CM5_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################


  ###########################################################################

    'EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "EC-EARTH",
      gcm.run = 12,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_ICHEC-EC-EARTH_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

  ###########################################################################

    'EUR-44_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "EC-EARTH",
      gcm.run = 12,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_ICHEC-EC-EARTH_rcp85_r12i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_ICHEC-EC-EARTH_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_ICHEC-EC-EARTH_historical_r12i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_mon' = list(
      institute = "KNMI",
      rcm = "KNMI-RACMO22E",
      gcm = "EC-EARTH",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-44_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_mon' = list(
      institute = "KNMI",
      rcm = "KNMI-RACMO22E",
      gcm = "EC-EARTH",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_ICHEC-EC-EARTH_rcp85_r1i1p1_KNMI-RACMO22E_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_ICHEC-EC-EARTH_historical_r1i1p1_KNMI-RACMO22E_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################




  ###########################################################################

    'EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_CLMcom-CCLM4-8-17_v1_mon' = list(
      institute = "CLMcom",
      rcm = "CLMcom-CCLM4-8-17",
      gcm = "EC-EARTH",
      gcm.run = 12,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_ICHEC-EC-EARTH_historical_r0i0p0_CLMcom-CCLM4-8-17_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_ICHEC-EC-EARTH_historical_r12i1p1_CLMcom-CCLM4-8-17_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-11_ICHEC-EC-EARTH_rcp85_r3i1p1_DMI-HIRHAM5_v1_mon' = list(
      institute = "DMI",
      rcm = "DMI-HIRHAM5",
      gcm = "EC-EARTH",
      gcm.run = 3,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_ICHEC-EC-EARTH_rcp85_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_ICHEC-EC-EARTH_rcp85_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################



    'EUR-44_ICHEC-EC-EARTH_rcp85_r3i1p1_DMI-HIRHAM5_v1_mon' = list(
      institute = "DMI",
      rcm = "DMI-HIRHAM5",
      gcm = "EC-EARTH",
      gcm.run = 3,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_ICHEC-EC-EARTH_rcp85_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_ICHEC-EC-EARTH_rcp85_r3i1p1_DMI-HIRHAM5_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_ICHEC-EC-EARTH_historical_r3i1p1_DMI-HIRHAM5_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################


 ###########################################################################

    'EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "HadGEM2-ES",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_MOHC-HadGEM2-ES_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-44_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "HadGEM2-ES",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_MOHC-HadGEM2-ES_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_MOHC-HadGEM2-ES_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_MOHC-HadGEM2-ES_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################
###########################################################################

    'EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_CLMcom-CCLM4-8-17_v1_mon' = list(
      institute = "CLMcom",
      rcm = "CLMcom-CCLM4-8-17",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_MPI-M-MPI-ESM-LR_historical_r0i0p0_CLMcom-CCLM4-8-17_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-44_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_CLMcom-CCLM4-8-17_v1_mon' = list(
      institute = "CLMcom",
      rcm = "CLMcom-CCLM4-8-17",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_MPI-M-MPI-ESM-LR_historical_r0i0p0_CLMcom-CCLM4-8-17_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
  ###########################################################################

    'EUR-11_CNRM-CERFACS-CNRM-CM5_rcp85_r1i1p1_CLMcom-CCLM4-8-17_v1_mon' = list(
      institute = "CLMcom",
      rcm = "CLMcom-CCLM4-8-17",
      gcm = "CNRM-CM5",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp85_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_CNRM-CERFACS-CNRM-CM5_rcp85_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r0i0p0_CLMcom-CCLM4-8-17_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_CNRM-CERFACS-CNRM-CM5_historical_r1i1p1_CLMcom-CCLM4-8-17_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),

 ###########################################################################



    'EUR-44_IPSL-IPSL-CM5A-MR_rcp85_r1i1p1_IPSL-INERIS-WRF331F_v1_mon' = list(
      institute = "IPSL-INERIS",
      rcm = "IPSL-INERIS-WRF331F",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_IPSL-IPSL-CM5A-MR_rcp85_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_IPSL-IPSL-CM5A-MR_rcp85_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_IPSL-IPSL-CM5A-MR_historical_r0i0p0_IPSL-INERIS-WRF331F_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_IPSL-INERIS-WRF331F_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),


###########################################################################


    'EUR-11_IPSL-IPSL-CM5A-MR_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_IPSL-IPSL-CM5A-MR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_IPSL-IPSL-CM5A-MR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_IPSL-IPSL-CM5A-MR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_IPSL-IPSL-CM5A-MR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_IPSL-IPSL-CM5A-MR_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_IPSL-IPSL-CM5A-MR_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),

###########################################################################


    'EUR-44_IPSL-IPSL-CM5A-MR_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "IPSL-CM5A-MR",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_IPSL-IPSL-CM5A-MR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_IPSL-IPSL-CM5A-MR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_IPSL-IPSL-CM5A-MR_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_IPSL-IPSL-CM5A-MR_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),



###########################################################################


    'EUR-44_NOAA-GFDL-GFDL-ESM2M_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "GFDL-ESM2M",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_NOAA-GFDL-GFDL-ESM2M_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_NOAA-GFDL-GFDL-ESM2M_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_NOAA-GFDL-GFDL-ESM2M_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_NOAA-GFDL-GFDL-ESM2M_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_NOAA-GFDL-GFDL-ESM2M_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_NOAA-GFDL-GFDL-ESM2M_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),



###########################################################################


    'EUR-44_NCC-NorESM1-M_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "NorESM1-M",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_NCC-NorESM1-M_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_NCC-NorESM1-M_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_NCC-NorESM1-M_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_NCC-NorESM1-M_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_NCC-NorESM1-M_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_NCC-NorESM1-M_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),
###########################################################################

    'EUR-44_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "MIROC5",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_MIROC-MIROC5_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_MIROC-MIROC5_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_MIROC-MIROC5_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),



###########################################################################

    'EUR-44_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "CanESM2",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_CCCma-CanESM2_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_CCCma-CanESM2_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_CCCma-CanESM2_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),


###########################################################################

    'EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-11_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-11_MPI-M-MPI-ESM-LR_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-11_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "12.5km",
         what.timesteps = "monthly"
      ),


###########################################################################

    'EUR-44_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon' = list(
      institute = "SMHI",
      rcm = "SMHI-RCA4",
      gcm = "MPI-ESM-LR",
      gcm.run = 1,
      emission.scenario = "rcp8.5",
      file.path.default = list(
        historical = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
        scenario = "/data/reloclim/rcu/thm/EURO-CORDEX/data"),
      file.name = list(
        air_temperature = list(
          historical = c(
         "tas_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
            ),
          scenario = c(
         "tas_EUR-44_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc" 
               )
          ),
        precipitation_amount = list(
          historical = c(
            "pr_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
          ),
          scenario = c(
            "pr_EUR-44_MPI-M-MPI-ESM-LR_rcp85_r1i1p1_SMHI-RCA4_v1_mon_[0-9]{6}-[0-9]{6}.nc"
             )
          )
        ),
         land.mask.name = "sftlf",
         land.mask = "/data/reloclim/rcu/thm/EURO-CORDEX/data/sftlf_EUR-44_MPI-M-MPI-ESM-LR_historical_r0i0p0_SMHI-RCA4_v1_fx.nc",
         gridfile.path = "/data/reloclim/rcu/thm/EURO-CORDEX/data",
         gridfile.filename = "tas_EUR-44_MPI-M-MPI-ESM-LR_historical_r1i1p1_SMHI-RCA4_v1_mon_200101-200512.nc",
         resolution = "50km",
         what.timesteps = "monthly"
      ),














    


    
    
 
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###++++++++++++++++++++++++++++ DATASET: CMIP3 ++++++++++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

### ----------------------------------------------------------------------
### *************************** SCENARIO: A1B ****************************
### ----------------------------------------------------------------------

    'bccr_bcm2_0-r1' = list(
      ## this model is not mentioned in the doc but has just one run,
      ## thus being uniquely relatable
      rcm = "",
      gcm = "BCCR-BCM2.0",
      gcm.run = 1,
      institute = "BCCR",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/bccr_bcm2_0/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/bccr_bcm2_0/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/bccr_bcm2_0/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/bccr_bcm2_0/run1"),
        global_radiation =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/rsds/bccr_bcm2_0/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/rsds/bccr_bcm2_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1_1.nc", "tas_A1_2.nc"),
          scenario = c("tas_A1_1.nc")),
        precipitation_amount = list(
          historical = c("pr_A1_1.nc", "pr_A1_2.nc"),
          scenario = "pr_A1_1.nc"),
        global_radiation = list(
          historical = c("rsds_A1_1.nc", "rsds_A1_2.nc"),
          scenario = "rsds_A1_1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/bccr_bcm2_0/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/bccr_bcm2_0/run1", 
      gridfile.filename = "tas_A1_2.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'cccma_cgcm3_1-r1' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 1,
      institute = "CCCMA",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cccma_cgcm3_1/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/cccma_cgcm3_1/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_1_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa1b_1_cgcm3.1_t47_2001_2100.nc", "tas_a1_sresa1b_1_cgcm3.1_t47_2101_2250.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_1_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa1b_1_cgcm3.1_t47_2001_2100.nc", "pr_a1_sresa1b_1_cgcm3.1_t47_2101_2250.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run1", 
      gridfile.filename = "tas_a1_20c3m_1_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-r2' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 2,
      institute = "CCCMA",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run2",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cccma_cgcm3_1/run2"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run2",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/cccma_cgcm3_1/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_2_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa1b_2_cgcm3.1_t47_2001_2100.nc", "tas_a1_sresa1b_2_cgcm3.1_t47_2101_2200.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_2_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa1b_2_cgcm3.1_t47_2001_2100.nc", "pr_a1_sresa1b_2_cgcm3.1_t47_2101_2200.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run2", 
      gridfile.filename = "tas_a1_20c3m_2_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-r3' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 3,
      institute = "CCCMA",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run3",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cccma_cgcm3_1/run3"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run3",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/cccma_cgcm3_1/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_3_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa1b_3_cgcm3.1_t47_2001_2100.nc", "tas_a1_sresa1b_3_cgcm3.1_t47_2101_2200.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_3_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa1b_3_cgcm3.1_t47_2001_2100.nc", "pr_a1_sresa1b_3_cgcm3.1_t47_2101_2200.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run3", 
      gridfile.filename = "tas_a1_20c3m_3_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-r4' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 4,
      institute = "CCCMA",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run4",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cccma_cgcm3_1/run4"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run4",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/cccma_cgcm3_1/run4")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa1b_4_cgcm3.1_t47_2001_2100.nc", "tas_a1_sresa1b_4_cgcm3.1_t47_2101_2150.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa1b_4_cgcm3.1_t47_2001_2100.nc", "pr_a1_sresa1b_4_cgcm3.1_t47_2101_2150.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run4", 
      gridfile.filename = "tas_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-r5' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 5,
      institute = "CCCMA",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run5",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cccma_cgcm3_1/run5"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run5",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/cccma_cgcm3_1/run5")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_5_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa1b_5_cgcm3.1_t47_2001_2100.nc", "tas_a1_sresa1b_5_cgcm3.1_t47_2101_2150.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_5_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa1b_5_cgcm3.1_t47_2001_2100.nc", "pr_a1_sresa1b_5_cgcm3.1_t47_2101_2150.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run5", 
      gridfile.filename = "tas_a1_20c3m_5_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'cccma_cgcm3_1_t63-r1' = list(
      rcm = "",
      gcm = "CGCM3.1(T63)",
      gcm.run = 1,
      institute = "CCCMA",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1_t63/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cccma_cgcm3_1_t63/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1_t63/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/cccma_cgcm3_1_t63/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_1_cgcm3.1_t63_1850_2000.nc",
          scenario = "tas_a1_sresa1b_1_cgcm3.1_t63_2001_2100.nc"),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_1_cgcm3.1_t63_1850_2000.nc",
          scenario = c("pr_a1_sresa1b_1_cgcm3.1_t63_2001_2100.nc", "pr_a1_sresa1b_1_cgcm3.1_t63_2101_2180.nc",
            "pr_a1_sresa1b_1_cgcm3.1_t63_2181_2300.nc"))),
      ##    file.name = "_1_cgcm3.1_t63_", whats this?? delete?
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1_t63/run1/sftlf_a1_20c3m_cgcm3.1_t63.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cccma_cgcm3_1_t63/run1", 
      gridfile.filename = "tas_a1_sresa1b_1_cgcm3.1_t63_2001_2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'cnrm_cm3-r1' = list(
      rcm = "",
      gcm = "CNRM-CM3",
      gcm.run = 1,
      institute = "CNRM",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cnrm_cm3/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cnrm_cm3/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cnrm_cm3/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/cnrm_cm3/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1_2000_2299.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cnrm_cm3/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cnrm_cm3/run1", 
      gridfile.filename = "tas_A1.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'csiro_mk3_0-r1' = list(
      rcm = "",
      gcm = "CSIRO-Mk3.0",
      gcm.run = 1,
      institute = "CSIRO",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/csiro_mk3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/csiro_mk3_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/csiro_mk3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/csiro_mk3_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/csiro_mk3_0/run1/sftlf_A1b_20C3M_run1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/csiro_mk3_0/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'csiro_mk3_5-r1' = list(
      rcm = "",
      gcm = "CSIRO-Mk3.5",
      gcm.run = 1,
      institute = "CSIRO",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/csiro_mk3_5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/csiro_mk3_5/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/csiro_mk3_5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/csiro_mk3_5/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_1871_2000.nc",
          scenario = "tas_A1_2001_2100.nc"),
        precipitation_amount = list(
          historical = "pr_A1_1871_2000.nc",
          scenario = "pr_A1_2001_2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/csiro_mk3_5/run1/sftlf_A1b_20C3M_mk3.5_run1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/csiro_mk3_5/run1", 
      gridfile.filename = "tas_A1_2001_2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'gfdl_cm2_0-r1' = list(
      rcm = "",
      gcm = "GFDL-CM2.0",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/gfdl_cm2_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/gfdl_cm2_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/gfdl_cm2_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/gfdl_cm2_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.186101-200012.nc",
          scenario = "tas_A1.200101-220012.nc"),
        precipitation_amount = list(
          historical = "pr_A1.186101-200012.nc",
          scenario = "pr_A1.200101-220012.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/gfdl_cm2_0/run1/sftlf_A1.static.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/gfdl_cm2_0/run1", 
      gridfile.filename = "tas_A1.200101-220012.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'gfdl_cm2_1-r1' = list(
      ## watch out, this model has different reference-scenario runs
      rcm = "",
      gcm = "GFDL-CM2.1",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/gfdl_cm2_1/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/gfdl_cm2_1/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/gfdl_cm2_1/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/gfdl_cm2_1/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.186101-200012.nc",
          scenario = "tas_A1.200101-210012.nc"),
        precipitation_amount = list(
          historical = "pr_A1.186101-200012.nc",
          scenario = "pr_A1.200101-210012.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/gfdl_cm2_1/run1/sftlf_A1.static.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/gfdl_cm2_1/run1", 
      gridfile.filename = "tas_A1.200101-210012.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'giss_aom-r1' = list(
      rcm = "",
      gcm = "GISS-AOM",
      gcm.run = 1,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_aom/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_aom/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_aom/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/giss_aom/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_aom/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_aom/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'giss_aom-r2' = list(
      rcm = "",
      gcm = "GISS-AOM",
      gcm.run = 2,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_aom/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_aom/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_aom/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/giss_aom/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_aom/run2/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_aom/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'giss_model_e_h-r1' = list(
      rcm = "",
      gcm = "GISS-EH",
      gcm.run = 1,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_h/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_h/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_model_e_h/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/giss_model_e_h/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS3.20C3M.run1.nc",
          scenario = "tas_A1.GISS3.SRESA1B.run1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.GISS3.20C3M.run1.nc",
          scenario = "pr_A1.GISS3.SRESA1B.run1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_h/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_h/run1", 
      gridfile.filename = "tas_A1.GISS3.SRESA1B.run1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'giss_model_e_h-r2' = list(
      rcm = "",
      gcm = "GISS-EH",
      gcm.run = 2,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_h/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_h/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_model_e_h/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/giss_model_e_h/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS3.20C3M.run2.nc",
          scenario = "tas_A1.GISS3.SRESA1B.run2.nc"),
        precipitation_amount = list(
          historical = "pr_A1.GISS3.20C3M.run2.nc",
          scenario = "pr_A1.GISS3.SRESA1B.run2.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_h/run2/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_h/run2", 
      gridfile.filename = "tas_A1.GISS3.SRESA1B.run2.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'giss_model_e_h-r3' = list(
      rcm = "",
      gcm = "GISS-EH",
      gcm.run = 3,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_h/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_h/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_model_e_h/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/giss_model_e_h/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS3.20C3M.run3.nc",
          scenario = "tas_A1.GISS3.SRESA1B.run3.nc"),
        precipitation_amount = list(
          historical = "pr_A1.GISS3.20C3M.run3.nc",
          scenario = "pr_A1.GISS3.SRESA1B.run3.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_h/run3/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_h/run3", 
      gridfile.filename = "tas_A1.GISS3.SRESA1B.run3.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    ## ATTENTION: SCENARIO RUN1 FOR PRECIPITATION DOESN'T EXIST
    'giss_model_e_r-r1' = list(
      rcm = "",
      gcm = "GISS-ER",
      gcm.run = 1,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_r/run3",
          scenario = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run1"),
        precipitation_amount = NA),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS1.20C3M.run3.nc",
          scenario = "tas_A1.GISS1.SRESA1B.run1.nc"),
        precipitation_amount = NA),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_r/run1/sftlf_A1.GISS.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run1", 
      gridfile.filename = "tas_A1.GISS1.SRESA1B.run1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'giss_model_e_r-r2' = list(
      rcm = "",
      gcm = "GISS-ER",
      gcm.run = 2,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_r/run6",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_model_e_r/run6",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/giss_model_e_r/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS1.20C3M.run6.nc",
          scenario = "tas_A1.GISS1.SRESA1B.run2.nc"),
        precipitation_amount = list(
          historical = "pr_A1.GISS1.20C3M.run6.nc",
          scenario = "pr_A1.GISS1.SRESA1B.run2.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_r/run2/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run2", 
      gridfile.filename = "tas_A1.GISS1.SRESA1B.run2.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    ## ATTENTION: SCENARIO RUN3 FOR PRECIPITATION DOESN'T EXIST
    'giss_model_e_r-r3' = list(
      rcm = "",
      gcm = "GISS-ER",
      gcm.run = 3,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_r/run7",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run3"),
        precipitation_amount = NA),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS1.20C3M.run7.nc",
          scenario = "tas_A1.GISS1.SRESA1B.run3.nc"),
        precipitation_amount = NA),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_r/run3/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run3", 
      gridfile.filename = "tas_A1.GISS1.SRESA1B.run3.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'giss_model_e_r-r4' = list(
      rcm = "",
      gcm = "GISS-ER",
      gcm.run = 4,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_r/run8",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run4"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_model_e_r/run8",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/giss_model_e_r/run4")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS1.20C3M.run8.nc",
          scenario = "tas_A1.GISS1.SRESA1B.run4.nc"),
        precipitation_amount = list(
          historical = "pr_A1.GISS1.20C3M.run8.nc",
          scenario = "pr_A1.GISS1.SRESA1B.run4.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_r/run4/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run4", 
      gridfile.filename = "tas_A1.GISS1.SRESA1B.run4.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    ## ATTENTION: SCENARIO RUN5 FOR PRECIPITATION DOESN'T EXIST
    'giss_model_e_r-r5' = list(
      rcm = "",
      gcm = "GISS-ER",
      gcm.run = 5,
      institute = "GISS",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_r/run9",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run5"),
        precipitation_amount = NA),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS1.20C3M.run9.nc",
          scenario = "tas_A1.GISS1.SRESA1B.run5.nc"),
        precipitation_amount = NA),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_r/run5/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/giss_model_e_r/run5", 
      gridfile.filename = "tas_A1.GISS1.SRESA1B.run5.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'iap_fgoals1_0_g-r1' = list(
      rcm = "",
      gcm = "FGOALS-g1.0",
      gcm.run = 1,
      institute = "LASG",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/iap_fgoals1_0_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/iap_fgoals1_0_g/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/iap_fgoals1_0_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/iap_fgoals1_0_g/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1_2000_2199.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/iap_fgoals1_0_g/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/iap_fgoals1_0_g/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'iap_fgoals1_0_g-r2' = list(
      rcm = "",
      gcm = "FGOALS-g1.0",
      gcm.run = 2,
      institute = "LASG",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/iap_fgoals1_0_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/iap_fgoals1_0_g/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/iap_fgoals1_0_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/iap_fgoals1_0_g/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/iap_fgoals1_0_g/run2/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/iap_fgoals1_0_g/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'iap_fgoals1_0_g-r3' = list(
      rcm = "",
      gcm = "FGOALS-g1.0",
      gcm.run = 3,
      institute = "LASG",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/iap_fgoals1_0_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/iap_fgoals1_0_g/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/iap_fgoals1_0_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/iap_fgoals1_0_g/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/iap_fgoals1_0_g/run3/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/iap_fgoals1_0_g/run3", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'ingv_echam4-r1' = list(
      rcm = "",
      gcm = "INGV-SXG",
      gcm.run = 1,
      institute = "INGV",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ingv_echam4/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ingv_echam4/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ingv_echam4/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ingv_echam4/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ingv_echam4/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ingv_echam4/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'inmcm3_0-r1' = list(
      rcm = "",
      gcm = "INM-CM3.0",
      gcm.run = 1,
      institute = "INM",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/inmcm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/inmcm3_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/inmcm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/inmcm3_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/inmcm3_0/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/inmcm3_0/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'ipsl_cm4-r1' = list(
      ## run2 of 20c3m is used as in ENSEMBLES
      rcm = "",
      gcm = "IPSL-CM4",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ipsl_cm4/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ipsl_cm4/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ipsl_cm4/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ipsl_cm4/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_1961-2000.nc",
          scenario = "tas_A1_2000-2100.nc"),
        precipitation_amount = list(
          historical = "pr_A1_1961-2000.nc",
          scenario = "pr_A1_2000-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ipsl_cm4/run1/sftlf_A1_1860-2000.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ipsl_cm4/run1",
      gridfile.filename = "tas_A1_2000-2100.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'miroc3_2_hires-r1' = list(
      rcm = "",
      gcm = "MIROC3.2(hires)",
      gcm.run = 1,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_hires/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miroc3_2_hires/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_hires/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/miroc3_2_hires/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_hires/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miroc3_2_hires/run1",
      gridfile.filename = "tas_A1.nc",
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'miroc3_2_medres-r1' = list(
      rcm = "",
      gcm = "MIROC3.2(medres)",
      gcm.run = 1,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_medres/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miroc3_2_medres/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_medres/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/miroc3_2_medres/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_medres/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miroc3_2_medres/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miroc3_2_medres-r2' = list(
      rcm = "",
      gcm = "MIROC3.2(medres)",
      gcm.run = 2,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_medres/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miroc3_2_medres/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_medres/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/miroc3_2_medres/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_medres/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miroc3_2_medres/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miroc3_2_medres-r3' = list(
      rcm = "",
      gcm = "MIROC3.2(medres)",
      gcm.run = 3,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_medres/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miroc3_2_medres/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_medres/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/miroc3_2_medres/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_medres/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miroc3_2_medres/run3", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'miub_echo_g-r1' = list(
      rcm = "",
      gcm = "ECHO-G",
      gcm.run = 1,
      institute = "MIUB",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miub_echo_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miub_echo_g/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miub_echo_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/miub_echo_g/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_a42_0007-0147.nc",
          scenario = "tas_A1_a52_0148-0447.nc"),
        precipitation_amount = list(
          historical = "pr_A1_a42_0007-0147.nc",
          scenario = "pr_A1_a52_0148-0447.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miub_echo_g/run1/sftlf_A1_a42.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miub_echo_g/run1", 
      gridfile.filename = "tas_A1_a52_0148-0447.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miub_echo_g-r2' = list(
      rcm = "",
      gcm = "ECHO-G",
      gcm.run = 2,
      institute = "MIUB",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miub_echo_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miub_echo_g/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miub_echo_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/miub_echo_g/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_a43_0007-0147.nc",
          scenario = "tas_A1_a53_0148-0347.nc"),
        precipitation_amount = list(
          historical = "pr_A1_a43_0007-0147.nc",
          scenario = "pr_A1_a53_0148-0347.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miub_echo_g/run2/sftlf_A1_a43.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miub_echo_g/run2", 
      gridfile.filename = "tas_A1_a53_0148-0347.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miub_echo_g-r3' = list(
      rcm = "",
      gcm = "ECHO-G",
      gcm.run = 3,
      institute = "MIUB",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miub_echo_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miub_echo_g/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miub_echo_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/miub_echo_g/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_a44_0007-0147.nc",
          scenario = "tas_A1_a54_0148-0347.nc"),
        precipitation_amount = list(
          historical = "pr_A1_a44_0007-0147.nc",
          scenario = "pr_A1_a54_0148-0347.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miub_echo_g/run3/sftlf_A1_a44.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/miub_echo_g/run3", 
      gridfile.filename = "tas_A1_a54_0148-0347.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'mpi_echam5-r1' = list(
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 1,
      institute = "MPI",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mpi_echam5/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/mpi_echam5/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mpi_echam5/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mpi_echam5-r2' = list(
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 2,
      institute = "MPI",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mpi_echam5/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/mpi_echam5/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run2/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mpi_echam5/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mpi_echam5-r3' = list(
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      institute = "MPI",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mpi_echam5/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/mpi_echam5/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run3/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mpi_echam5/run3", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mpi_echam5-r4' = list(
      ## THIS MODEL RUN IS NOT LISTED IN THE CMIP3 CORRESPONDENCE-SUMMARY FILE,
      ## BUT IS STILL AVAILABLE TO DOWNLOAD... INSERTING NONTHELESS
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 4,
      institute = "MPI",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mpi_echam5/run4"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/mpi_echam5/run4")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_1860-2000.nc",
          scenario = "tas_A1_2001-2100.nc"),
        precipitation_amount = list(
          historical = "pr_A1_1860-2000.nc",
          scenario = "pr_A1_2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run3/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mpi_echam5/run4", 
      gridfile.filename = "tas_A1_2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'mri_cgcm2_3_2a-r1' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 1,
      institute = "MRI",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/mri_cgcm2_3_2a/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run1", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-r2' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 2,
      institute = "MRI",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/mri_cgcm2_3_2a/run2")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run2", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-r3' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 3,
      institute = "MRI",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/mri_cgcm2_3_2a/run3")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run3", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-r4' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 4,
      institute = "MRI",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run4"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/mri_cgcm2_3_2a/run4")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run4", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-r5' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 5,
      institute = "MRI",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run5"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/mri_cgcm2_3_2a/run5")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/mri_cgcm2_3_2a/run5", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'ncar_ccsm3_0-r1' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 1,
      institute = "NCAR",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_ccsm3_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_A1.20C3M_1.CCSM.atmm.1950-01_cat_1959-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1960-01_cat_1969-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1970-01_cat_1979-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1980-01_cat_1989-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESA1B_1.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c(
            "pr_A1.20C3M_1.CCSM.atmm.1950-01_cat_1959-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1960-01_cat_1969-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1970-01_cat_1979-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1980-01_cat_1989-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESA1B_1.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run1", 
      gridfile.filename = "tas_A1.SRESA1B_1.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-r2' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 2,
      institute = "NCAR",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_ccsm3_0/run2")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_2.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESA1B_2.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_2.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESA1B_2.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run2", 
      gridfile.filename = "tas_A1.SRESA1B_2.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-r3' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 3,
      institute = "NCAR",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_ccsm3_0/run3")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_A1.20C3M_3.CCSM.atmm.1950-01_cat_1959-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1960-01_cat_1969-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1970-01_cat_1979-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1980-01_cat_1989-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESA1B_3.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c(
            "pr_A1.20C3M_3.CCSM.atmm.1950-01_cat_1959-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1960-01_cat_1969-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1970-01_cat_1979-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1980-01_cat_1989-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESA1B_3.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run3", 
      gridfile.filename = "tas_A1.SRESA1B_3.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-r5' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 5,
      institute = "NCAR",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run5"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_ccsm3_0/run5")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_A1.20C3M_5.CCSM.atmm.1950-01_cat_1959-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1960-01_cat_1969-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1970-01_cat_1979-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1980-01_cat_1989-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESA1B_5.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c(
            "pr_A1.20C3M_5.CCSM.atmm.1950-01_cat_1959-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1960-01_cat_1969-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1970-01_cat_1979-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1980-01_cat_1989-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESA1B_5.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run5", 
      gridfile.filename = "tas_A1.SRESA1B_5.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-r6' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 6,
      institute = "NCAR",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run6",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run6"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run6",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_ccsm3_0/run6")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_6.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESA1B_6.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_6.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESA1B_6.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run6", 
      gridfile.filename = "tas_A1.SRESA1B_6.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-r7' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 7,
      institute = "NCAR",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run7",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run7"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run7",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_ccsm3_0/run7")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_7.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESA1B_7.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_7.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESA1B_7.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run7", 
      gridfile.filename = "tas_A1.SRESA1B_7.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-r9' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 9,
      institute = "NCAR",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run9",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run9"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run9",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_ccsm3_0/run9")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_9.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESA1B_9.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_9.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESA1B_9.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_ccsm3_0/run9", 
      gridfile.filename = "tas_A1.SRESA1B_9.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    ## ncar_pcm1 not used, because of this statement in the documentation:
    ## B06.20; this run did not branch directly from the control run, but
    ## from January 1, 2000 of a ghg+sulfate+ozone run, which began in 1870
    ## and branched from year 140 of the Picntrl Run 1.  Thus, year 2000 of
    ## this run correponds to year 270 of the control run, but presumably has
    ## already strayed from the control run because of the 130 years under
    ## ghg+sulfate+ozone forcing. NO 20c3m SIMULATION AVAILABLE!!!

    ## 'ncar_pcm1-r1' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 1,
    ##   institute = "NCAR",
    ##   emission.scenario = "A1B",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run1",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_pcm1/run1"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run1",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_pcm1/run1")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.20C3M_1.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = "tas_A1.SRESA1B_1.PCM1.atmm.2000-01_cat_2099-10.nc"),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.20C3M_1.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = "pr_A1.SRESA1B_1.PCM1.atmm.2000-01_cat_2099-10.nc")),
    ##   land.mask.name = "sftlf",
    ##   land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/",
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_pcm1/run1", 
    ##   gridfile.filename = "tas_A1.SRESA1B_1.PCM1.atmm.2000-01_cat_2099-10.nc", 
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###--------------------------------------------------------------------------
    ## 'ncar_pcm1-r2' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 2,
    ##   institute = "NCAR",
    ##   emission.scenario = "A1B",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run2",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_pcm1/run2"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run2",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_pcm1/run2")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.20C3M_2.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = c(
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2000-01_cat_2009-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2010-01_cat_2019-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2020-01_cat_2029-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2030-01_cat_2039-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2040-01_cat_2049-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2050-01_cat_2059-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2060-01_cat_2069-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2070-01_cat_2079-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2080-01_cat_2089-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2090-01_cat_2099-12.nc",
    ##         "tas_A1.SRESA1B_2.PCM1.atmm.2100-01_cat_2109-12.nc")),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.20C3M_2.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = c(
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2000-01_cat_2009-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2010-01_cat_2019-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2020-01_cat_2029-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2030-01_cat_2039-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2040-01_cat_2049-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2050-01_cat_2059-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2060-01_cat_2069-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2070-01_cat_2079-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2080-01_cat_2089-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2090-01_cat_2099-12.nc",
    ##         "pr_A1.SRESA1B_2.PCM1.atmm.2100-01_cat_2109-12.nc"))),
    ##   land.mask.name = "sftlf",
    ##   land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/",
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_pcm1/run2", 
    ##   gridfile.filename = "tas_A1.SRESA1B_2.PCM1.atmm.2000-01_cat_2009-12.nc", 
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###--------------------------------------------------------------------------
    ##  'ncar_pcm1-r3' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 3,
    ##   institute = "NCAR",
    ##   emission.scenario = "A1B",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run3",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_pcm1/run3"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run3",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_pcm1/run3")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.nc"),
    ##       scenario = "tas_A1.SRESA1B_3.PCM1.atmm.2000-01_cat_2199-12.nc"),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.nc"),
    ##       scenario = "pr_A1.SRESA1B_3.PCM1.atmm.2000-01_cat_2199-12.nc")),
    ##   land.mask.name = "sftlf",
    ##   land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/",
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_pcm1/run3", 
    ##   gridfile.filename = "tas_A1.SRESA1B_3.PCM1.atmm.2000-01_cat_2199-12.nc", 
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###--------------------------------------------------------------------------
    ##  'ncar_pcm1-r4' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 4,
    ##   institute = "NCAR",
    ##   emission.scenario = "A1B",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run4",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_pcm1/run4"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run4",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ncar_pcm1/run4")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.nc"),
    ##       scenario = "tas_A1.SRESA1B_4.PCM1.atmm.2000-01_cat_2099-12.nc"),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.nc"),
    ##       scenario = "pr_A1.SRESA1B_4.PCM1.atmm.2000-01_cat_2099-12.nc")),
    ##   land.mask.name = "sftlf",
    ##   land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/",
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ncar_pcm1/run4", 
    ##   gridfile.filename = "tas_A1.SRESA1B_4.PCM1.atmm.2000-01_cat_2099-12.nc", 
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###########################################################################
    'ukmo_hadcm3-r1' = list(
      rcm = "",
      gcm = "UKMO-HadCM3",
      gcm.run = 1,
      institute = "Met Office",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ukmo_hadcm3/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ukmo_hadcm3/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ukmo_hadcm3/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ukmo_hadcm3/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.nc"),
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.nc"),
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ukmo_hadcm3/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ukmo_hadcm3/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'ukmo_hadgem1-r1' = list(
      rcm = "",
      gcm = "UKMO-HadGEM1",
      gcm.run = 1,
      institute = "Met Office",
      emission.scenario = "A1B",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ukmo_hadgem1/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ukmo_hadgem1/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ukmo_hadgem1/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/ukmo_hadgem1/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.nc"),
          scenario = c("tas_A1_2000_to_2099_Nov.nc", "tas_A1_2099_to_2199_Nov.nc")),
        precipitation_amount = list(
          historical = c("pr_A1.nc"),
          scenario = c("pr_A1_2000_Jan_to_2099_Nov.nc", "pr_A1_2099_Dec_to_2199_Nov.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ukmo_hadgem1/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/ukmo_hadgem1/run1", 
      gridfile.filename = "tas_A1_2000_to_2099_Nov.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################

### ----------------------------------------------------------------------
### *************************** SCENARIO: A2 *****************************
### ----------------------------------------------------------------------

    'bccr_bcm2_0-sresa2-r1' = list(
      rcm = "",
      gcm = "BCCR-BCM2.0",
      gcm.run = 1,
      institute = "BCCR",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/bccr_bcm2_0/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/bccr_bcm2_0/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/bccr_bcm2_0/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/bccr_bcm2_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1_1.nc", "tas_A1_2.nc"),
          scenario = c("tas_A1_1.nc")),
        precipitation_amount = list(
          historical = c("pr_A1_1.nc", "pr_A1_2.nc"),
          scenario = "pr_A1_1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/bccr_bcm2_0/run1/sftlf_A1.nc", 
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/bccr_bcm2_0/run1", 
      gridfile.filename = "tas_A1_2.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'cccma_cgcm3_1-sresa2-r1' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 1,
      institute = "CCCMA",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/cccma_cgcm3_1/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/cccma_cgcm3_1/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_1_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa2_1_cgcm3.1_t47_2001_2100.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_1_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa2_1_cgcm3.1_t47_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run1", 
      gridfile.filename = "tas_a1_20c3m_1_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-sresa2-r2' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 2,
      institute = "CCCMA",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run2",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/cccma_cgcm3_1/run2"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run2",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/cccma_cgcm3_1/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_2_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa2_2_cgcm3.1_t47_2001_2100.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_2_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa2_2_cgcm3.1_t47_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run2", 
      gridfile.filename = "tas_a1_20c3m_2_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-sresa2-r3' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 3,
      institute = "CCCMA",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run3",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/cccma_cgcm3_1/run3"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run3",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/cccma_cgcm3_1/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_3_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa2_3_cgcm3.1_t47_2001_2100.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_3_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa2_3_cgcm3.1_t47_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run3", 
      gridfile.filename = "tas_a1_20c3m_3_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-sresa2-r4' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 4,
      institute = "CCCMA",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run4",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/cccma_cgcm3_1/run4"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run4",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/cccma_cgcm3_1/run4")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa2_4_cgcm3.1_t47_2001_2100.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa2_4_cgcm3.1_t47_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run4", 
      gridfile.filename = "tas_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-sresa2-r5' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 5,
      institute = "CCCMA",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run5",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/cccma_cgcm3_1/run5"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run5",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/cccma_cgcm3_1/run5")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_5_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresa2_5_cgcm3.1_t47_2001_2100.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_5_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresa2_5_cgcm3.1_t47_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run5", 
      gridfile.filename = "tas_a1_20c3m_5_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'cnrm_cm3-sresa2-r1' = list(
      rcm = "",
      gcm = "CNRM-CM3",
      gcm.run = 1,
      institute = "CNRM",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cnrm_cm3/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/cnrm_cm3/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cnrm_cm3/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/cnrm_cm3/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cnrm_cm3/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/cnrm_cm3/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'csiro_mk3_0-sresa2-r1' = list(
      rcm = "",
      gcm = "CSIRO-Mk3.0",
      gcm.run = 1,
      institute = "CSIRO",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/csiro_mk3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/csiro_mk3_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/csiro_mk3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/csiro_mk3_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/csiro_mk3_0/run1/sftlf_A1b_20C3M_run1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/csiro_mk3_0/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'csiro_mk3_5-sresa2-r1' = list(
      rcm = "",
      gcm = "CSIRO-Mk3.5",
      gcm.run = 1,
      institute = "CSIRO",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/csiro_mk3_5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/csiro_mk3_5/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/csiro_mk3_5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/csiro_mk3_5/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_1871_2000.nc",
          scenario = "tas_A1_2001_2100.nc"),
        precipitation_amount = list(
          historical = "pr_A1_1871_2000.nc",
          scenario = "pr_A1_2001_2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/csiro_mk3_5/run1/sftlf_A1b_20C3M_mk3.5_run1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/csiro_mk3_5/run1", 
      gridfile.filename = "tas_A1_2001_2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'gfdl_cm2_0-sresa2-r1' = list(
      rcm = "",
      gcm = "GFDL-CM2.0",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/gfdl_cm2_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/gfdl_cm2_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/gfdl_cm2_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/gfdl_cm2_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.186101-200012.nc",
          scenario = "tas_A1.200101-210012.nc"),
        precipitation_amount = list(
          historical = "pr_A1.186101-200012.nc",
          scenario = "pr_A1.200101-210012.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/gfdl_cm2_0/run1/sftlf_A1.static.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/gfdl_cm2_0/run1", 
      gridfile.filename = "tas_A1.200101-210012.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'gfdl_cm2_1-sresa2-r1' = list(
      rcm = "",
      gcm = "GFDL-CM2.1",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/gfdl_cm2_1/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/gfdl_cm2_1/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/gfdl_cm2_1/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/gfdl_cm2_1/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.186101-200012.nc",
          scenario = "tas_A1.200101-210012.nc"),
        precipitation_amount = list(
          historical = "pr_A1.186101-200012.nc",
          scenario = "pr_A1.200101-210012.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/gfdl_cm2_1/run1/sftlf_A1.static.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/gfdl_cm2_1/run1", 
      gridfile.filename = "tas_A1.200101-210012.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'giss_model_e_r-sresa2-r1' = list(
      rcm = "",
      gcm = "GISS-ER",
      gcm.run = 1,
      institute = "GISS",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_r/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/giss_model_e_r/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_model_e_r/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/giss_model_e_r/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS1.20C3M.run3.nc",
          scenario = "tas_A1.GISS1.SRESA2.nc"),
        precipitation_amount = list(
          historical = "pr_A1.GISS1.20C3M.run3.nc",
          scenario = "pr_A1.GISS1.SRESA2.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_r/run1/sftlf_A1.GISS.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/giss_model_e_r/run1", 
      gridfile.filename = "tas_A1.GISS1.SRESA2.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'ingv_echam4-sresa2-r1' = list(
      rcm = "",
      gcm = "INGV-SXG",
      gcm.run = 1,
      institute = "INGV",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ingv_echam4/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ingv_echam4/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ingv_echam4/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ingv_echam4/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ingv_echam4/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ingv_echam4/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'inmcm3_0-sresa2-r1' = list(
      rcm = "",
      gcm = "INM-CM3.0",
      gcm.run = 1,
      institute = "INM",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/inmcm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/inmcm3_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/inmcm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/inmcm3_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/inmcm3_0/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/inmcm3_0/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'ipsl_cm4-sresa2-r1' = list(
      ## run2 of 20c3m is used as in ENSEMBLES
      rcm = "",
      gcm = "IPSL-CM4",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ipsl_cm4/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ipsl_cm4/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ipsl_cm4/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ipsl_cm4/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_1961-2000.nc",
          scenario = "tas_A1_2000-2100.nc"),
        precipitation_amount = list(
          historical = "pr_A1_1961-2000.nc",
          scenario = "pr_A1_2000-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ipsl_cm4/run1/sftlf_A1_1860-2000.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ipsl_cm4/run1", 
      gridfile.filename = "tas_A1_2000-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'miroc3_2_medres-sresa2-r1' = list(
      rcm = "",
      gcm = "MIROC3.2(medres)",
      gcm.run = 1,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_medres/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miroc3_2_medres/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_medres/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/miroc3_2_medres/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_medres/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miroc3_2_medres/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miroc3_2_medres-sresa2-r2' = list(
      rcm = "",
      gcm = "MIROC3.2(medres)",
      gcm.run = 2,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_medres/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miroc3_2_medres/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_medres/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/miroc3_2_medres/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_medres/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miroc3_2_medres/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miroc3_2_medres-sresa2-r3' = list(
      rcm = "",
      gcm = "MIROC3.2(medres)",
      gcm.run = 3,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_medres/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miroc3_2_medres/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_medres/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/miroc3_2_medres/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_medres/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miroc3_2_medres/run3", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'miub_echo_g-sresa2-r1' = list(
      rcm = "",
      gcm = "ECHO-G",
      gcm.run = 1,
      institute = "MIUB",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miub_echo_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miub_echo_g/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miub_echo_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/miub_echo_g/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_a42_0007-0147.nc",
          scenario = "tas_A1_a72_0148-0247.nc"),
        precipitation_amount = list(
          historical = "pr_A1_a42_0007-0147.nc",
          scenario = "pr_A1_a72_0148-0247.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miub_echo_g/run1/sftlf_A1_a42.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miub_echo_g/run1", 
      gridfile.filename = "tas_A1_a72_0148-0247.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miub_echo_g-sresa2-r2' = list(
      rcm = "",
      gcm = "ECHO-G",
      gcm.run = 2,
      institute = "MIUB",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miub_echo_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miub_echo_g/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miub_echo_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/miub_echo_g/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_a43_0007-0147.nc",
          scenario = "tas_A1_a73_0148-0247.nc"),
        precipitation_amount = list(
          historical = "pr_A1_a43_0007-0147.nc",
          scenario = "pr_A1_a73_0148-0247.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miub_echo_g/run2/sftlf_A1_a43.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miub_echo_g/run2", 
      gridfile.filename = "tas_A1_a73_0148-0247.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miub_echo_g-sresa2-r3' = list(
      rcm = "",
      gcm = "ECHO-G",
      gcm.run = 3,
      institute = "MIUB",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miub_echo_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miub_echo_g/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miub_echo_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/miub_echo_g/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_a44_0007-0147.nc",
          scenario = "tas_A1_a74_0148-0247.nc"),
        precipitation_amount = list(
          historical = "pr_A1_a44_0007-0147.nc",
          scenario = "pr_A1_a74_0148-0247.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miub_echo_g/run3/sftlf_A1_a44.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/miub_echo_g/run3", 
      gridfile.filename = "tas_A1_a74_0148-0247.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    ## ECHAM5 initialization simulation only referenced to without mentioning
    ## the run, thus assigning run1 to run1, run2 to run2, etc.
    'mpi_echam5-sresa2-r1' = list(
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 1,
      institute = "MPI",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mpi_echam5/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/mpi_echam5/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mpi_echam5/run1",
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mpi_echam5-sresa2-r2' = list(
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 2,
      institute = "MPI",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mpi_echam5/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/mpi_echam5/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run2/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mpi_echam5/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mpi_echam5-sresa2-r3' = list(
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      institute = "MPI",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mpi_echam5/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/mpi_echam5/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run3/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mpi_echam5/run3", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'mri_cgcm2_3_2a-sresa2-r1' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 1,
      institute = "MRI",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/mri_cgcm2_3_2a/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run1", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-sresa2-r2' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 2,
      institute = "MRI",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/mri_cgcm2_3_2a/run2")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run2", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-sresa2-r3' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 3,
      institute = "MRI",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/mri_cgcm2_3_2a/run3")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run3", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-sresa2-r4' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 4,
      institute = "MRI",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run4"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/mri_cgcm2_3_2a/run4")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run4", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-sresa2-r5' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 5,
      institute = "MRI",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run5"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/mri_cgcm2_3_2a/run5")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/mri_cgcm2_3_2a/run5", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'ncar_ccsm3_0-sresa2-r1' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 1,
      institute = "NCAR",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ncar_ccsm3_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_A1.20C3M_1.CCSM.atmm.1950-01_cat_1959-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1960-01_cat_1969-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1970-01_cat_1979-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1980-01_cat_1989-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = c(
            "pr_A1.20C3M_1.CCSM.atmm.1950-01_cat_1959-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1960-01_cat_1969-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1970-01_cat_1979-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1980-01_cat_1989-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresa2-r2' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 2,
      institute = "NCAR",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ncar_ccsm3_0/run2")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_2.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_2.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresa2-r3' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 3,
      institute = "NCAR",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ncar_ccsm3_0/run3")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_A1.20C3M_3.CCSM.atmm.1950-01_cat_1959-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1960-01_cat_1969-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1970-01_cat_1979-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1980-01_cat_1989-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = c(
            "pr_A1.20C3M_3.CCSM.atmm.1950-01_cat_1959-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1960-01_cat_1969-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1970-01_cat_1979-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1980-01_cat_1989-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run3", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresa2-r4' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 4,
      institute = "NCAR",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run4"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ncar_ccsm3_0/run4")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_4.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_4.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run4", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresa2-r5' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 5,
      institute = "NCAR",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run5"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ncar_ccsm3_0/run5")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_A1.20C3M_5.CCSM.atmm.1950-01_cat_1959-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1960-01_cat_1969-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1970-01_cat_1979-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1980-01_cat_1989-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = c(
            "pr_A1.20C3M_5.CCSM.atmm.1950-01_cat_1959-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1960-01_cat_1969-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1970-01_cat_1979-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1980-01_cat_1989-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_ccsm3_0/run5", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    ## ncar_pcm1 not used, because of this statement in the documentation:
    ## B06.20; this run did not branch directly from the control run, but
    ## from January 1, 2000 of a ghg+sulfate+ozone run, which began in 1870
    ## and branched from year 140 of the Picntrl Run 1.  Thus, year 2000 of
    ## this run correponds to year 270 of the control run, but presumably has
    ## already strayed from the control run because of the 130 years under
    ## ghg+sulfate+ozone forcing. NO 20c3m SIMULATION AVAILABLE!!!

    ## 'ncar_pcm1-sresa2-r1' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 1,
    ##   institute = "NCAR",
    ##   emission.scenario = "A2",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run1",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_pcm1/run1"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run1",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ncar_pcm1/run1")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.20C3M_1.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = "tas_A1.SRESA2_1.PCM1.atmm.2000-01_cat_2099-10.nc"),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.20C3M_1.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = "pr_A1.SRESA2_1.PCM1.atmm.2000-01_cat_2099-10.nc")),
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_pcm1/run1",
    ##   gridfile.filename = "tas_A1.SRESA2_1.PCM1.atmm.2000-01_cat_2099-10.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###--------------------------------------------------------------------------
    ## 'ncar_pcm1-sresa2-r2' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 2,
    ##   institute = "NCAR",
    ##   emission.scenario = "A2",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run2",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_pcm1/run2"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run2",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ncar_pcm1/run2")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.20C3M_2.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = c(
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2000-01_cat_2009-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2010-01_cat_2019-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2020-01_cat_2029-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2030-01_cat_2039-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2040-01_cat_2049-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2050-01_cat_2059-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2060-01_cat_2069-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2070-01_cat_2079-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2080-01_cat_2089-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2090-01_cat_2099-12.nc",
    ##         "tas_A1.SRESA2_2.PCM1.atmm.2100-01_cat_2109-12.nc")),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.20C3M_2.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = c("pr_A1.SRESA2_2.PCM1.atmm.2000-01_cat_2009-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2010-01_cat_2019-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2020-01_cat_2029-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2030-01_cat_2039-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2040-01_cat_2049-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2050-01_cat_2059-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2060-01_cat_2069-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2070-01_cat_2079-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2080-01_cat_2089-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2090-01_cat_2099-12.nc",
    ##         "pr_A1.SRESA2_2.PCM1.atmm.2100-01_cat_2109-12.nc"))),
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_pcm1/run2",
    ##   gridfile.filename = "tas_A1.SRESA2_2.PCM1.atmm.2000-01_cat_2009-12.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###--------------------------------------------------------------------------
    ##  'ncar_pcm1-sresa2-r3' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 3,
    ##   institute = "NCAR",
    ##   emission.scenario = "A2",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run3",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_pcm1/run3"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run3",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ncar_pcm1/run3")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.nc"),
    ##       scenario = "tas_A1.SRESA2_3.PCM1.atmm.2000-01_cat_2199-12.nc"),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.nc"),
    ##       scenario = "pr_A1.SRESA2_3.PCM1.atmm.2000-01_cat_2199-12.nc")),
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_pcm1/run3",
    ##   gridfile.filename = "tas_A1.SRESA2_3.PCM1.atmm.2000-01_cat_2199-12.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###--------------------------------------------------------------------------
    ##  'ncar_pcm1-sresa2-r4' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 4,
    ##   institute = "NCAR",
    ##   emission.scenario = "A2",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run4",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_pcm1/run4"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run4",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ncar_pcm1/run4")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.nc"),
    ##       scenario = "tas_A1.SRESA2_4.PCM1.atmm.2000-01_cat_2099-12.nc"),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.nc"),
    ##       scenario = "pr_A1.SRESA2_4.PCM1.atmm.2000-01_cat_2099-12.nc")),
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ncar_pcm1/run4",
    ##   gridfile.filename = "tas_A1.SRESA2_4.PCM1.atmm.2000-01_cat_2099-12.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##    ),
##############################################################################
    'ukmo_hadcm3-sresa2-r1' = list(
      rcm = "",
      gcm = "UKMO-HadCM3",
      gcm.run = 1,
      institute = "Met Office",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ukmo_hadcm3/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ukmo_hadcm3/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ukmo_hadcm3/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ukmo_hadcm3/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.nc"),
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.nc"),
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ukmo_hadcm3/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ukmo_hadcm3/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'ukmo_hadgem1-sresa2-r1' = list(
      rcm = "",
      gcm = "UKMO-HadGEM1",
      gcm.run = 1,
      institute = "Met Office",
      emission.scenario = "A2",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ukmo_hadgem1/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ukmo_hadgem1/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ukmo_hadgem1/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/pr/ukmo_hadgem1/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.nc"),
          scenario = c("tas_A1_2000_Jan_to_2099_Nov.nc")),
        precipitation_amount = list(
          historical = c("pr_A1.nc"),
          scenario = c("pr_A1_2000_Jan_to_2099_Nov.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ukmo_hadgem1/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa2/atm/mo/tas/ukmo_hadgem1/run1", 
      gridfile.filename = "tas_A1_2000_Jan_to_2099_Nov.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################

### ----------------------------------------------------------------------
### *************************** SCENARIO: B1 *****************************
### ----------------------------------------------------------------------

    'bccr_bcm2_0-sresb1-r1' = list(
      rcm = "",
      gcm = "BCCR-BCM2.0",
      gcm.run = 1,
      institute = "BCCR",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/bccr_bcm2_0/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/bccr_bcm2_0/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/bccr_bcm2_0/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/bccr_bcm2_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1_1.nc", "tas_A1_2.nc"),
          scenario = c("tas_A1_1.nc")),
        precipitation_amount = list(
          historical = c("pr_A1_1.nc", "pr_A1_2.nc"),
          scenario = "pr_A1_1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/bccr_bcm2_0/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/bccr_bcm2_0/run1", 
      gridfile.filename = "tas_A1_2.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'cccma_cgcm3_1-sresb1-r1' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 1,
      institute = "CCCMA",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/cccma_cgcm3_1/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/cccma_cgcm3_1/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_1_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresb1_1_cgcm3.1_t47_2001_2300.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_1_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresb1_1_cgcm3.1_t47_2001_2300.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run1", 
      gridfile.filename = "tas_a1_20c3m_1_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-sresb1-r2' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 2,
      institute = "CCCMA",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run2",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/cccma_cgcm3_1/run2"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run2",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/cccma_cgcm3_1/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_2_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresb1_2_cgcm3.1_t47_2001_2100.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_2_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresb1_2_cgcm3.1_t47_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run2", 
      gridfile.filename = "tas_a1_20c3m_2_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-sresb1-r3' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 3,
      institute = "CCCMA",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run3",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/cccma_cgcm3_1/run3"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run3",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/cccma_cgcm3_1/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_3_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresb1_3_cgcm3.1_t47_2001_2100.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_3_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresb1_3_cgcm3.1_t47_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run3", 
      gridfile.filename = "tas_a1_20c3m_3_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-sresb1-r4' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 4,
      institute = "CCCMA",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run4",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/cccma_cgcm3_1/run4"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run4",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/cccma_cgcm3_1/run4")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresb1_4_cgcm3.1_t47_2001_2100.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresb1_4_cgcm3.1_t47_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run4", 
      gridfile.filename = "tas_a1_20c3m_4_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'cccma_cgcm3_1-sresb1-r5' = list(
      rcm = "",
      gcm = "CGCM3.1(T47)",
      gcm.run = 5,
      institute = "CCCMA",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run5",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/cccma_cgcm3_1/run5"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1/run5",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/cccma_cgcm3_1/run5")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_5_cgcm3.1_t47_1850_2000.nc",
          scenario = c("tas_a1_sresb1_5_cgcm3.1_t47_2001_2100.nc")),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_5_cgcm3.1_t47_1850_2000.nc",
          scenario = c("pr_a1_sresb1_5_cgcm3.1_t47_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1/run1/sftlf_a1_20c3m_cgcm3.1_t47.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1/run5", 
      gridfile.filename = "tas_a1_20c3m_5_cgcm3.1_t47_1850_2000.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'cccma_cgcm3_1_t63-sresb1-r1' = list(
      rcm = "",
      gcm = "CGCM3.1(T63)",
      gcm.run = 1,
      institute = "CCCMA",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cccma_cgcm3_1_t63/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cccma_cgcm3_1_t63/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cccma_cgcm3_1_t63/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/pr/cccma_cgcm3_1_t63/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_a1_20c3m_1_cgcm3.1_t63_1850_2000.nc",
          scenario = "tas_a1_sresa1b_1_cgcm3.1_t63_2001_2100.nc"),
        precipitation_amount = list(
          historical = "pr_a1_20c3m_1_cgcm3.1_t63_1850_2000.nc",
          scenario = c("pr_a1_sresa1b_1_cgcm3.1_t63_2001_2100.nc"))),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cccma_cgcm3_1_t63/run1/sftlf_a1_20c3m_cgcm3.1_t63.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresa1b/atm/mo/tas/cccma_cgcm3_1_t63/run1", 
      gridfile.filename = "tas_a1_sresa1b_1_cgcm3.1_t63_2001_2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'cnrm_cm3-sresb1-r1' = list(
      rcm = "",
      gcm = "CNRM-CM3",
      gcm.run = 1,
      institute = "CNRM",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/cnrm_cm3/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/cnrm_cm3/run1"),
        precipitation_amount =
        list(historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/cnrm_cm3/run1",
             scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/cnrm_cm3/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/cnrm_cm3/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/cnrm_cm3/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'csiro_mk3_0-sresb1-r1' = list(
      rcm = "",
      gcm = "CSIRO-Mk3.0",
      gcm.run = 1,
      institute = "CSIRO",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/csiro_mk3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/csiro_mk3_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/csiro_mk3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/csiro_mk3_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/csiro_mk3_0/run1/sftlf_A1b_20C3M_run1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/csiro_mk3_0/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'csiro_mk3_5-sresb1-r1' = list(
      rcm = "",
      gcm = "CSIRO-Mk3.5",
      gcm.run = 1,
      institute = "CSIRO",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/csiro_mk3_5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/csiro_mk3_5/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/csiro_mk3_5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/csiro_mk3_5/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_1871_2000.nc",
          scenario = "tas_A1_2001_2200.nc"),
        precipitation_amount = list(
          historical = "pr_A1_1871_2000.nc",
          scenario = "pr_A1_2001_2200.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/csiro_mk3_5/run1/sftlf_A1b_20C3M_mk3.5_run1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/csiro_mk3_5/run1", 
      gridfile.filename = "tas_A1_2001_2200.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'gfdl_cm2_0-sresb1-r1' = list(
      rcm = "",
      gcm = "GFDL-CM2.0",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/gfdl_cm2_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/gfdl_cm2_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/gfdl_cm2_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/gfdl_cm2_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.186101-200012.nc",
          scenario = "tas_A1.200101-220012.nc"),
        precipitation_amount = list(
          historical = "pr_A1.186101-200012.nc",
          scenario = "pr_A1.200101-220012.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/gfdl_cm2_0/run1/sftlf_A1.static.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/gfdl_cm2_0/run1", 
      gridfile.filename = "tas_A1.200101-220012.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'gfdl_cm2_1-sresb1-r1' = list(
      rcm = "",
      gcm = "GFDL-CM2.1",
      gcm.run = 1,
      institute = "NOAA GFDL",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/gfdl_cm2_1/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/gfdl_cm2_1/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/gfdl_cm2_1/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/gfdl_cm2_1/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.186101-200012.nc",
          scenario = "tas_A1.200101-210012.nc"),
        precipitation_amount = list(
          historical = "pr_A1.186101-200012.nc",
          scenario = "pr_A1.200101-210012.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/gfdl_cm2_1/run1/sftlf_A1.static.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/gfdl_cm2_1/run1", 
      gridfile.filename = "tas_A1.200101-210012.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'giss_aom-sresb1-r1' = list(
      rcm = "",
      gcm = "GISS-AOM",
      gcm.run = 1,
      institute = "GISS",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_aom/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/giss_aom/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_aom/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/giss_aom/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_aom/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/giss_aom/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'giss_aom-sresb1-r2' = list(
      rcm = "",
      gcm = "GISS-AOM",
      gcm.run = 2,
      institute = "GISS",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_aom/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/giss_aom/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_aom/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/giss_aom/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_aom/run2/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/giss_aom/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'giss_model_e_r-sresb1-r1' = list(
      rcm = "",
      gcm = "GISS-ER",
      gcm.run = 1,
      institute = "GISS",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/giss_model_e_r/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/giss_model_e_r/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/giss_model_e_r/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/giss_model_e_r/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.GISS1.20C3M.run3.nc",
          scenario = "tas_A1.GISS1.SRESB1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.GISS1.20C3M.run3.nc",
          scenario = "pr_A1.GISS1.SRESB1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/giss_model_e_r/run1/sftlf_A1.GISS.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/giss_model_e_r/run1", 
      gridfile.filename = "tas_A1.GISS1.SRESB1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'iap_fgoals1_0_g-sresb1-r1' = list(
      rcm = "",
      gcm = "FGOALS-g1.0",
      gcm.run = 1,
      institute = "LASG",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/iap_fgoals1_0_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/iap_fgoals1_0_g/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/iap_fgoals1_0_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/iap_fgoals1_0_g/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/iap_fgoals1_0_g/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/iap_fgoals1_0_g/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'iap_fgoals1_0_g-sresb1-r2' = list(
      rcm = "",
      gcm = "FGOALS-g1.0",
      gcm.run = 2,
      institute = "LASG",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/iap_fgoals1_0_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/iap_fgoals1_0_g/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/iap_fgoals1_0_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/iap_fgoals1_0_g/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/iap_fgoals1_0_g/run2/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/iap_fgoals1_0_g/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'iap_fgoals1_0_g-sresb1-r3' = list(
      rcm = "",
      gcm = "FGOALS-g1.0",
      gcm.run = 3,
      institute = "LASG",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/iap_fgoals1_0_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/iap_fgoals1_0_g/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/iap_fgoals1_0_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/iap_fgoals1_0_g/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/iap_fgoals1_0_g/run3/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/iap_fgoals1_0_g/run3", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'inmcm3_0-sresb1-r1' = list(
      rcm = "",
      gcm = "INM-CM3.0",
      gcm.run = 1,
      institute = "INM",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/inmcm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/inmcm3_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/inmcm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/inmcm3_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/inmcm3_0/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/inmcm3_0/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'ipsl_cm4-sresb1-r1' = list(
      ## run2 of 20c3m is used as in ENSEMBLES
      rcm = "",
      gcm = "IPSL-CM4",
      gcm.run = 1,
      institute = "IPSL",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ipsl_cm4/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ipsl_cm4/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ipsl_cm4/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ipsl_cm4/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_1961-2000.nc",
          scenario = "tas_A1_2000-2100.nc"),
        precipitation_amount = list(
          historical = "pr_A1_1961-2000.nc",
          scenario = "pr_A1_2000-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ipsl_cm4/run1/sftlf_A1_1860-2000.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ipsl_cm4/run1",
      gridfile.filename = "tas_A1_2000-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'miroc3_2_hires-sresb1-r1' = list(
      rcm = "",
      gcm = "MIROC3.2(hires)",
      gcm.run = 1,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_hires/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miroc3_2_hires/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_hires/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/miroc3_2_hires/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_hires/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miroc3_2_hires/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'miroc3_2_medres-sresb1-r1' = list(
      rcm = "",
      gcm = "MIROC3.2(medres)",
      gcm.run = 1,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_medres/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miroc3_2_medres/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_medres/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/miroc3_2_medres/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_medres/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miroc3_2_medres/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miroc3_2_medres-sresb1-r2' = list(
      rcm = "",
      gcm = "MIROC3.2(medres)",
      gcm.run = 2,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_medres/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miroc3_2_medres/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_medres/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/miroc3_2_medres/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_medres/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miroc3_2_medres/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miroc3_2_medres-sresb1-r3' = list(
      rcm = "",
      gcm = "MIROC3.2(medres)",
      gcm.run = 3,
      institute = "CCSR/NIES/FRCGC",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miroc3_2_medres/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miroc3_2_medres/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miroc3_2_medres/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/miroc3_2_medres/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miroc3_2_medres/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miroc3_2_medres/run3", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'miub_echo_g-sresb1-r1' = list(
      rcm = "",
      gcm = "ECHO-G",
      gcm.run = 1,
      institute = "MIUB",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miub_echo_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miub_echo_g/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miub_echo_g/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/miub_echo_g/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_a42_0007-0147.nc",
          scenario = "tas_A1_a62_0148-0347.nc"),
        precipitation_amount = list(
          historical = "pr_A1_a42_0007-0147.nc",
          scenario = "pr_A1_a62_0148-0347.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miub_echo_g/run1/sftlf_A1_a42.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miub_echo_g/run1", 
      gridfile.filename = "tas_A1_a62_0148-0347.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miub_echo_g-sresb1-r2' = list(
      rcm = "",
      gcm = "ECHO-G",
      gcm.run = 2,
      institute = "MIUB",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miub_echo_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miub_echo_g/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miub_echo_g/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/miub_echo_g/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_a43_0007-0147.nc",
          scenario = "tas_A1_a63_0148-0347.nc"),
        precipitation_amount = list(
          historical = "pr_A1_a43_0007-0147.nc",
          scenario = "pr_A1_a63_0148-0347.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miub_echo_g/run2/sftlf_A1_a43.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miub_echo_g/run2", 
      gridfile.filename = "tas_A1_a63_0148-0347.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'miub_echo_g-sresb1-r3' = list(
      rcm = "",
      gcm = "ECHO-G",
      gcm.run = 3,
      institute = "MIUB",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/miub_echo_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miub_echo_g/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/miub_echo_g/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/miub_echo_g/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1_a44_0007-0147.nc",
          scenario = "tas_A1_a64_0148-0347.nc"),
        precipitation_amount = list(
          historical = "pr_A1_a44_0007-0147.nc",
          scenario = "pr_A1_a64_0148-0347.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/miub_echo_g/run3/sftlf_A1_a44.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/miub_echo_g/run3", 
      gridfile.filename = "tas_A1_a64_0148-0347.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    ## ECHAM5 initialization simulation only referenced to without mentioning
    ## the run, thus assigning run1 to run1, run2 to run2, etc.
    'mpi_echam5-sresb1-r1' = list(
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 1,
      institute = "MPI",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mpi_echam5/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/mpi_echam5/run1")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mpi_echam5/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mpi_echam5-sresb1-r2' = list(
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 2,
      institute = "MPI",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mpi_echam5/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/mpi_echam5/run2")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run2/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mpi_echam5/run2", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mpi_echam5-sresb1-r3' = list(
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      gcm.run = 3,
      institute = "MPI",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mpi_echam5/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mpi_echam5/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mpi_echam5/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/mpi_echam5/run3")),
      file.name = list(
        air_temperature = list(
          historical = "tas_A1.nc",
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = "pr_A1.nc",
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mpi_echam5/run3/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mpi_echam5/run3", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###########################################################################
    'mri_cgcm2_3_2a-sresb1-r1' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 1,
      institute = "MRI",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/mri_cgcm2_3_2a/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run1", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-sresb1-r2' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 2,
      institute = "MRI",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/mri_cgcm2_3_2a/run2")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run2", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-sresb1-r3' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 3,
      institute = "MRI",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/mri_cgcm2_3_2a/run3")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run3", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-sresb1-r4' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 4,
      institute = "MRI",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run4"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/mri_cgcm2_3_2a/run4")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run4", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'mri_cgcm2_3_2a-sresb1-r5' = list(
      rcm = "",
      gcm = "MRI-CGCM2.3.2",
      gcm.run = 5,
      institute = "MRI",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/mri_cgcm2_3_2a/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run5"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/mri_cgcm2_3_2a/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/mri_cgcm2_3_2a/run5")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.1901-2000.nc"),
          scenario = "tas_A1.2001-2100.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.1901-2000.nc"),
          scenario = "pr_A1.2001-2100.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/mri_cgcm2_3_2a/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/mri_cgcm2_3_2a/run5", 
      gridfile.filename = "tas_A1.2001-2100.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    'ncar_ccsm3_0-sresb1-r1' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 1,
      institute = "NCAR",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run1",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_ccsm3_0/run1")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_A1.20C3M_1.CCSM.atmm.1950-01_cat_1959-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1960-01_cat_1969-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1970-01_cat_1979-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1980-01_cat_1989-12.nc",
            "tas_A1.20C3M_1.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESB1_1.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c(
            "pr_A1.20C3M_1.CCSM.atmm.1950-01_cat_1959-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1960-01_cat_1969-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1970-01_cat_1979-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1980-01_cat_1989-12.nc",
            "pr_A1.20C3M_1.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESB1_1.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run1", 
      gridfile.filename = "tas_A1.SRESB1_1.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresb1-r2' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 2,
      institute = "NCAR",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run2"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_ccsm3_0/run2")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_2.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESB1_2.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_2.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESB1_2.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run2", 
      gridfile.filename = "tas_A1.SRESB1_2.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresb1-r3' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 3,
      institute = "NCAR",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run3"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run3",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_ccsm3_0/run3")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_A1.20C3M_3.CCSM.atmm.1950-01_cat_1959-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1960-01_cat_1969-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1970-01_cat_1979-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1980-01_cat_1989-12.nc",
            "tas_A1.20C3M_3.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESB1_3.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c(
            "pr_A1.20C3M_3.CCSM.atmm.1950-01_cat_1959-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1960-01_cat_1969-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1970-01_cat_1979-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1980-01_cat_1989-12.nc",
            "pr_A1.20C3M_3.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESB1_3.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run3", 
      gridfile.filename = "tas_A1.SRESB1_3.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresb1-r4' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 4,
      institute = "NCAR",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run4"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run4",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_ccsm3_0/run4")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_4.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESB1_4.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_4.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESB1_4.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run4", 
      gridfile.filename = "tas_A1.SRESB1_4.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresb1-r5' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 5,
      institute = "NCAR",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run5"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run5",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_ccsm3_0/run5")),
      file.name = list(
        air_temperature = list(
          historical = c(
            "tas_A1.20C3M_5.CCSM.atmm.1950-01_cat_1959-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1960-01_cat_1969-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1970-01_cat_1979-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1980-01_cat_1989-12.nc",
            "tas_A1.20C3M_5.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESB1_5.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c(
            "pr_A1.20C3M_5.CCSM.atmm.1950-01_cat_1959-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1960-01_cat_1969-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1970-01_cat_1979-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1980-01_cat_1989-12.nc",
            "pr_A1.20C3M_5.CCSM.atmm.1990-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESB1_5.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run5", 
      gridfile.filename = "tas_A1.SRESB1_5.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresb1-r6' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 6,
      institute = "NCAR",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run6",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run6"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run6",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_ccsm3_0/run6")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_6.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESB1_6.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_6.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESB1_6.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run6", 
      gridfile.filename = "tas_A1.SRESB1_6.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresb1-r7' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 7,
      institute = "NCAR",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run7",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run7"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run7",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_ccsm3_0/run7")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_7.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESB1_7.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_7.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESB1_7.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run7", 
      gridfile.filename = "tas_A1.SRESB1_7.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
###--------------------------------------------------------------------------
    'ncar_ccsm3_0-sresb1-r9' = list(
      rcm = "",
      gcm = "CCSM3",
      gcm.run = 9,
      institute = "NCAR",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_ccsm3_0/run9",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run9"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_ccsm3_0/run9",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_ccsm3_0/run9")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.20C3M_9.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "tas_A1.SRESB1_9.CCSM.atmm.2000-01_cat_2099-12.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.20C3M_9.CCSM.atmm.1870-01_cat_1999-12.nc"),
          scenario = "pr_A1.SRESB1_9.CCSM.atmm.2000-01_cat_2099-12.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ncar_ccsm3_0/run5/sftlf_A1.20C3M.CCSM.atmm.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_ccsm3_0/run9", 
      gridfile.filename = "tas_A1.SRESB1_9.CCSM.atmm.2000-01_cat_2099-12.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################
    ## ncar_pcm1 not used, because of this statement in the documentation:
    ## B06.20; this run did not branch directly from the control run, but
    ## from January 1, 2000 of a ghg+sulfate+ozone run, which began in 1870
    ## and branched from year 140 of the Picntrl Run 1.  Thus, year 2000 of
    ## this run correponds to year 270 of the control run, but presumably has
    ## already strayed from the control run because of the 130 years under
    ## ghg+sulfate+ozone forcing. NO 20c3m SIMULATION AVAILABLE!!!

    ## 'ncar_pcm1-sresb1-r1' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 1,
    ##   institute = "NCAR",
    ##   emission.scenario = "B1",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run1",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_pcm1/run1"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run1",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_pcm1/run1")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.20C3M_1.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = "tas_A1.SRESB1_1.PCM1.atmm.2000-01_cat_2099-10.nc"),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.20C3M_1.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = "pr_A1.SRESB1_1.PCM1.atmm.2000-01_cat_2099-10.nc")),
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_pcm1/run1",
    ##   gridfile.filename = "tas_A1.SRESB1_1.PCM1.atmm.2000-01_cat_2099-10.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###--------------------------------------------------------------------------
    ## 'ncar_pcm1-sresb1-r2' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 2,
    ##   institute = "NCAR",
    ##   emission.scenario = "B1",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run2",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_pcm1/run2"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run2",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_pcm1/run2")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.20C3M_2.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = c(
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2000-01_cat_2009-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2010-01_cat_2019-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2020-01_cat_2029-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2030-01_cat_2039-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2040-01_cat_2049-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2050-01_cat_2059-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2060-01_cat_2069-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2070-01_cat_2079-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2080-01_cat_2089-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2090-01_cat_2099-12.nc",
    ##         "tas_A1.SRESB1_2.PCM1.atmm.2100-01_cat_2109-12.nc")),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.20C3M_2.PCM1.atmm.1890-01_cat_1999-12.nc"),
    ##       scenario = c("pr_A1.SRESB1_2.PCM1.atmm.2000-01_cat_2009-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2010-01_cat_2019-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2020-01_cat_2029-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2030-01_cat_2039-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2040-01_cat_2049-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2050-01_cat_2059-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2060-01_cat_2069-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2070-01_cat_2079-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2080-01_cat_2089-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2090-01_cat_2099-12.nc",
    ##         "pr_A1.SRESB1_2.PCM1.atmm.2100-01_cat_2109-12.nc"))),
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_pcm1/run2",
    ##   gridfile.filename = "tas_A1.SRESB1_2.PCM1.atmm.2000-01_cat_2009-12.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###--------------------------------------------------------------------------
    ##  'ncar_pcm1-sresb1-r3' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 3,
    ##   institute = "NCAR",
    ##   emission.scenario = "B1",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run3",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_pcm1/run3"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run3",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_pcm1/run3")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.nc"),
    ##       scenario = "tas_A1.SRESB1_3.PCM1.atmm.2000-01_cat_2199-12.nc"),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.nc"),
    ##       scenario = "pr_A1.SRESB1_3.PCM1.atmm.2000-01_cat_2199-12.nc")),
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_pcm1/run3",
    ##   gridfile.filename = "tas_A1.SRESB1_3.PCM1.atmm.2000-01_cat_2199-12.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##   ),
###--------------------------------------------------------------------------
    ##  'ncar_pcm1-sresb1-r4' = list(
    ##   rcm = "",
    ##   gcm = "PCM",
    ##   gcm.run = 4,
    ##   institute = "NCAR",
    ##   emission.scenario = "B1",
    ##   file.path.alt = list(
    ##     air_temperature = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ncar_pcm1/run4",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_pcm1/run4"),
    ##     precipitation_amount = list(
    ##       historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ncar_pcm1/run4",
    ##       scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ncar_pcm1/run4")),
    ##   file.name = list(
    ##     air_temperature = list(
    ##       historical = c("tas_A1.nc"),
    ##       scenario = "tas_A1.SRESB1_4.PCM1.atmm.2000-01_cat_2099-12.nc"),
    ##     precipitation_amount = list(
    ##       historical = c("pr_A1.nc"),
    ##       scenario = "pr_A1.SRESB1_4.PCM1.atmm.2000-01_cat_2099-12.nc")),
    ##   gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ncar_pcm1/run4",
    ##   gridfile.filename = "tas_A1.SRESB1_4.PCM1.atmm.2000-01_cat_2099-12.nc",
    ##   resolution = "",
    ##   what.timesteps = "monthly"
    ##    ),
##############################################################################
    'ukmo_hadcm3-sresb1-r1' = list(
      rcm = "",
      gcm = "UKMO-HadCM3",
      gcm.run = 1,
      institute = "Met Office",
      emission.scenario = "B1",
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/tas/ukmo_hadcm3/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ukmo_hadcm3/run1"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/cmip3/ipcc/20c3m/atm/mo/pr/ukmo_hadcm3/run2",
          scenario =  "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/pr/ukmo_hadcm3/run1")),
      file.name = list(
        air_temperature = list(
          historical = c("tas_A1.nc"),
          scenario = "tas_A1.nc"),
        precipitation_amount = list(
          historical = c("pr_A1.nc"),
          scenario = "pr_A1.nc")),
      land.mask.name = "sftlf",
      land.mask = "/data/reloclim/rcm/cmip3/ipcc/20c3m/land/fixed/sftlf/ukmo_hadcm3/run1/sftlf_A1.nc",
      gridfile.path = "/data/reloclim/rcm/cmip3/ipcc/sresb1/atm/mo/tas/ukmo_hadcm3/run1", 
      gridfile.filename = "tas_A1.nc", 
      resolution = "",
      what.timesteps = "monthly"
      ),
##############################################################################


###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
###+++++++++++++++++++++ DATASET: RemoUBA ++++++++++++ ++++++++++++++++++++++
###++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


################################################################################
   'RemoUBA_A1B' = list(
      institute = "MPI-M",
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      emission.scenario = "A1B",
      
      file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/RemoUBA/MPI/C20/direct",
          scenario = "/data/reloclim/rcm/RemoUBA/MPI/ECHAM5_A1B/direct"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/RemoUBA/MPI/C20/direct",
          scenario = "/data/reloclim/rcm/RemoUBA/MPI/ECHAM5_A1B/direct")
        ),

       file.name = list(
        air_temperature = list(
          historical = c(
            "RE_UBA_C20_D3_MM_1960-2000_tas.nc"
            ),
          scenario ="RE_UBA_A1B_D3_MM_2001-2100_tas.nc"
          ),
        precipitation_amount = list(
          historical = c(
             "RE_UBA_C20_D3_DS_1960-2000_prt.nc"
            ),
          scenario = "RE_UBA_A1B_D3_DS_2001-2100_prt.nc" 
            )
          ),

     
      parameters = c(
         air_temperature = "tas",
        precipitation_amount = "prt"
        ),
                   
      gridfile.path = "/data/reloclim/rcm/RemoUBA/MPI/ECHAM5_A1B/direct",
      gridfile.filename = "RE_UBA_A1B_D3_MM_2001-2100_tas.nc",
      resolution = "10km",
      time.units="minutes since 1960-01-01 00:00:00"
     
     
      ),
###----------------------------------------------------------------------------------
     'RemoUBA_A2' = list(
      institute = "MPI-M",
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      emission.scenario = "A2",
       file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/RemoUBA/MPI/C20/direct",
          scenario = "/data/reloclim/rcm/RemoUBA/MPI/ECHAM5_A2/direct"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/RemoUBA/MPI/C20/direct",
          scenario = "/data/reloclim/rcm/RemoUBA/MPI/ECHAM5_A2/direct")
        ),

       file.name = list(
        air_temperature = list(
          historical = c(
            "RE_UBA_C20_D3_MM_1960-2000_tas.nc"
            ),
          scenario ="RE_UBA_A2_D3_MM_2001-2100_tas.nc"
          ),
        precipitation_amount = list(
          historical = c(
             "RE_UBA_C20_D3_DS_1960-2000_prt.nc"
            ),
          scenario = "RE_UBA_A2_D3_DS_2001-2100_prt.nc" 
            )
          ),

       
      parameters = c(
         air_temperature = "tas",
        precipitation_amount = "prt"
        ),
        gridfile.path = "/data/reloclim/rcm/RemoUBA/MPI/ECHAM5_A1B/direct",
      gridfile.filename = "RE_UBA_A1B_D3_MM_2001-2100_tas.nc",            
     
      resolution = "10km",
      time.units="minutes since 1960-01-01 00:00:00"
      ),
 ###----------------------------------------------------------------------------------
     'RemoUBA_B1' = list(
      institute = "MPI-M",
      rcm = "",
      gcm = "ECHAM5/MPI-OM",
      emission.scenario = "B1",
       file.path.alt = list(
        air_temperature = list(
          historical = "/data/reloclim/rcm/RemoUBA/MPI/C20/direct",
          scenario = "/data/reloclim/rcm/RemoUBA/MPI/ECHAM5_B1/direct"),
        precipitation_amount = list(
          historical = "/data/reloclim/rcm/RemoUBA/MPI/C20/direct",
          scenario = "/data/reloclim/rcm/RemoUBA/MPI/ECHAM5_B1/direct")
        ),

       file.name = list(
        air_temperature = list(
          historical = c(
             "RE_UBA_C20_D3_MM_1960-2000_tas.nc"
            ),
          scenario ="RE_UBA_B1_D3_MM_2001-2100_tas.nc"
          ),
        precipitation_amount = list(
          historical = c(
             "RE_UBA_C20_D3_DS_1960-2000_prt.nc"
            ),
          scenario = "RE_UBA_B1_D3_DS_2001-2100_prt.nc" 
            )
          ),

       
      parameters = c(
         air_temperature = "tas",
        precipitation_amount = "prt"
        ),
                   
      gridfile.path = "/data/reloclim/rcm/RemoUBA/MPI/ECHAM5_A1B/direct",
      gridfile.filename = "RE_UBA_A1B_D3_MM_2001-2100_tas.nc",
      resolution = "10km",
      time.units="minutes since 1960-01-01 00:00:00"
      )
    )

  return(model.input)
}
